package br.ufpr.mityba.arquitetura;

import java.io.BufferedWriter;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Vector;

import br.ufpr.mityba.controller.GerenteConsultaConsulta;
import br.ufpr.mityba.controller.GerenteConsultaHistoricoPaciente;
import br.ufpr.mityba.controller.GerenteConsultaMensagem;
import br.ufpr.mityba.controller.GerenteConsultaPaciente;
import br.ufpr.mityba.dao.PacienteDAO;
import br.ufpr.mityba.model.Consulta;
import br.ufpr.mityba.model.HistoricoPaciente;
import br.ufpr.mityba.model.Mensagem;
import br.ufpr.mityba.model.Paciente;
import br.ufpr.mityba.util.Constantes;
import br.ufpr.mityba.util.ControlePrincipal;
import br.ufpr.mityba.util.SendMail;

/**
 * 
 * @author Mityba
 * @since 28/10/2008
 * @version 1.0 28/10/2008
 * @version 1.1 03/11/2008
 * @version 1.2 12/11/2008
 * @version 1.3 19/11/2008
 * @version 1.4 04/12/2008
 *
 */

public class ProcessoBatch {

	private ControlePrincipal controle;
	
	private Mensagem mensagem;
	
	private Vector<Mensagem> mensagens;
	private Vector<Paciente> pacientes;
	
	private String dataBase;
	private String email;
	
	private SendMail enviarEmail;
	
	private PrintWriter saida;
	
	/**
	 * 
	 * @param data
	 * @throws IOException
	 */

	public ProcessoBatch(String data) throws IOException{
				
		this.dataBase = data;
		
		abreArquivoLog("processo" + dataBase.replace("/", "") + ".log");
		
		geraLog("Inicio do processo batch - data base = " + dataBase + "\r\n");
		
		instanciaObjetos();
		
		geraLog("Executando Ativos e inativos\r\n");
		
		if(!ativosInativos())
			geraLog("Erro ao executar ativos e inativos\r\n");
		
		geraLog("Executando emails aniversariantes\r\n");
		
		if(!emailsAniversario())
			geraLog("Erro ao enviar e-mails de aniversrio\r\n");
		
		geraLog("Executando emails dia do profissional\r\n");
		
		if(!emailsDiaProfissional())
			geraLog("Erro ao enviar e-mails de dia do profissional\r\n");
		
		geraLog("Executando emails consulta\r\n");
		
		if(!emailsAvisoConsulta())
			geraLog("Erro ao enviar e-mails de aviso de consulta\r\n");
		
		fechaArquivoLog();
	}
	
	/**
	 * 
	 */
	
	private void instanciaObjetos(){
		
		controle 	= new ControlePrincipal();
		
		enviarEmail = new SendMail();
		
	}
	
	/**
	 * 
	 * @return flag
	 * @throws IOException 
	 */

	@SuppressWarnings("deprecation")
	private boolean ativosInativos() throws IOException{		
		
		GerenteConsultaPaciente.todosPacientes(controle);
		
		Vector<Paciente> pacientes			= controle.getPacientes();
		Vector<HistoricoPaciente> historico	= null;
		HistoricoPaciente ultHistorico		= null;
		
		PacienteDAO pacienteDAO				= new PacienteDAO(controle);
		
		for(int i = 0; i < pacientes.size(); i++){
			
			try{
				GerenteConsultaHistoricoPaciente.historicoPorCodigoPaciente(controle, pacientes.get(i).getIdPaciente());
				
				historico = controle.getHistoricoPacientes();
				
				if(historico.size() > 0){
					
					ultHistorico = historico.get(0);
					
					int idConsulta = ultHistorico.getIdConsultaHistoricoPaciente();
					
					GerenteConsultaConsulta.consultaPorCodigo(controle, idConsulta);
					
					String data = controle.getConsultas().get(0).getDataConsulta();
					
					Date dataUltimaConsulta = new Date();
					dataUltimaConsulta.setDate	(Integer.parseInt(data.substring(0,2)));
					dataUltimaConsulta.setMonth	(Integer.parseInt(data.substring(3,5)));
					dataUltimaConsulta.setYear	(Integer.parseInt(data.substring(6)));
					
					if((System.currentTimeMillis() - dataUltimaConsulta.getTime()) > (60 * Constantes.MILISEGUNDOS_DIA)){					
						pacientes.get(i).setAtivo("n");					
						pacienteDAO.alteraPaciente(pacientes.get(i));
					}
				}
			}catch (Exception e) {
				//Em caso de exceo somente rejeita o registro do paciente
			}
		}
		
		return true;
	}
	
	/**
	 * 
	 * @return flag
	 */
	
	private boolean emailsAniversario() throws IOException{
		
		if(GerenteConsultaMensagem.mensagensAniversario(controle)){
			
			mensagens 	= controle.getMensagens();
			
			if(mensagens != null && mensagens.size() > 0){
				
				mensagem = mensagens.get(0);
				
				if(GerenteConsultaPaciente.pacientePorDataAniversario(controle, dataBase)){
					
					pacientes = controle.getPacientes();
					
					if(pacientes != null && pacientes.size() > 0){
						
						for(int i = 0; i < pacientes.size(); i++){
							
							email = pacientes.get(i).getEmail();
							
							if(email != null && ! email.equals(""))							
								enviarEmail.sendMail(
									Constantes.USUARIO_EMAIL_COMPLETO, 
									email, 
									mensagem.getTituloMensagem(),
									mensagem.getDescricaoMensagem());
						}
					} else
						return true;					
				} else
					return false;				
			} else				
				return true;			
		} else
			return false;
		
		return true;
	}

	/**
	 * 
	 * @return flag
	 * @throws IOException 
	 */
	
	private boolean emailsDiaProfissional() throws IOException{
		
		if(GerenteConsultaMensagem.mensagensDiaProfissional(controle)){
			
			mensagens 	= controle.getMensagens();		
				
			for(int j = 0; j < mensagens.size(); j++){
			
				if(GerenteConsultaPaciente.pacientePorProfissao(controle, mensagens.get(j).getIdProfissaoMensagem())){
					
					pacientes = controle.getPacientes();
					
					if(pacientes != null && pacientes.size() > 0){
						
						for(int i = 0; i < pacientes.size(); i++){
							
							email = pacientes.get(i).getEmail();
							
							if(email != null && ! email.equals(""))							
								enviarEmail.sendMail(
									Constantes.USUARIO_EMAIL_COMPLETO, 
									email, 
									mensagens.get(j).getTituloMensagem(),
									mensagens.get(j).getDescricaoMensagem());
						}
					} else
						return true;
				} else				
					return true;
			}
		} else
			return false;
		
		return true;
	}
	
	/**
	 * 
	 * @return flag
	 */

	private boolean emailsAvisoConsulta() throws IOException{
		
		if(GerenteConsultaMensagem.mensagensConsulta(controle)){
			
			mensagens 	= controle.getMensagens();			
			
			if(mensagens != null && mensagens.size() > 0){
				
				mensagem = mensagens.get(0);
				
				int qdeDias = mensagem.getQdeDiasAntesMensagem();
				
				String dataProxima = new SimpleDateFormat("dd/MM/yyyy").format(new Date(System.currentTimeMillis() + (qdeDias * Constantes.MILISEGUNDOS_DIA)));
								
				Paciente paciente;
				
				GerenteConsultaConsulta.consultaPorData(controle, dataProxima);
				
				Vector<Consulta> consultas = controle.getConsultas();
				
				for(int i = 0; i < consultas.size(); i++){
					
					GerenteConsultaPaciente.pacientePorCodigo(controle, consultas.get(i).getIdPacienteConsulta());
					
					paciente = controle.getPacientes().get(0);
					
					email = paciente.getEmail();
					
					if(email != null && ! email.equals(""))							
						enviarEmail.sendMail(
							Constantes.USUARIO_EMAIL_COMPLETO, 
							email, 
							mensagem.getTituloMensagem(),
							mensagem.getDescricaoMensagem());
									
				}
				return true;
				
			} else	
				return true;			
		} else
			return false;
	}
	
	/**
	 * 
	 * @param path 
	 * @param mensagem
	 * @throws IOException 
	 */
	
	private void abreArquivoLog(String path) throws IOException{
		saida = new PrintWriter(new BufferedWriter(new FileWriter(path)));
	}
	
	/**
	 * 
	 * @throws IOException 
	 */
	
	private void fechaArquivoLog() throws IOException{
		saida.close();
	}
	
	/**
	 * 
	 * @param mensagem
	 */
	
	private void geraLog(String mensagem){
		saida.print(new SimpleDateFormat("dd/MM/yyyy HH:mm:ss").format(new Date()) + " " + mensagem);
	}
}