package br.ufpr.mityba.dao;

import java.io.IOException;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Vector;

import br.ufpr.mityba.model.Alimento;
import br.ufpr.mityba.util.Conexao;
import br.ufpr.mityba.util.ControlePrincipal;

/**
 * @author Mityba
 * @since 11/11/2008
 * @version 1.0 
 */

public class AlimentoDAO {
 
	private Connection connection;
	private Statement statement;
	private ResultSet retorno;
	private ControlePrincipal controle;

	/**
	 * 
	 * @param controle
	 */

	public AlimentoDAO(ControlePrincipal controle) {
		this.controle 	= controle;
	}
	
	/**
	 * 
	 */

	public AlimentoDAO() {
	}
	
	/**
	 * 
	 * @param where
	 * @return flag
	 * @throws IOException
	 */

	public boolean carregaAlimentos(String where) throws IOException {
		
		Vector<Alimento> vector = new Vector<Alimento>();

		try {

			connection = Conexao.getConnection();

			vector.removeAllElements();

			statement = connection.createStatement();

			String sql = "select * from alimento " + where;

			retorno = statement.executeQuery(sql);

			while (retorno.next()) {

				vector.add(new Alimento(
					retorno.getInt 		("id_alimento"),
					retorno.getInt		("id_grupo_alimenticio_alimento"),
					retorno.getString	("descr_alimento").trim(),
					retorno.getString	("valores_alimento").trim()));
			}
			
			controle.setAlimentos(vector);
			
			Conexao.stopConnection(connection);

			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();

			return false;

		} catch (Exception e) {
		
			e.printStackTrace();
			
			return false;
		}
	}
	
	/**
	 * 
	 * @param alimento
	 * @return flag
	 * @throws IOException
	 */

	public boolean incluiAlimento(Alimento alimento) throws IOException{

		try {
			
			connection = Conexao.getConnection();

			StringBuffer sql = new StringBuffer();
			
			sql.append("insert into alimento (id_grupo_alimenticio_alimento, valores_alimento, descr_alimento) ")
				.append("values(?,?,?)");				

			PreparedStatement pstmt = connection.prepareStatement(sql.toString());
			
			pstmt.setInt	(1, alimento.getIdGrupoAlimenticioAlimento());
			pstmt.setString	(2, alimento.getValoresAlimento());
			pstmt.setString	(3, alimento.getNomeAlimento());

			if (pstmt.executeUpdate() != 1) {
				return false;
			}

			Conexao.stopConnection(connection);
			
			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();
				
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
				
			return false;
		}
	}

	/**
	 * 
	 * @param alimento
	 * @return flag
	 * @throws IOException
	 */

	public boolean alteraAlimento(Alimento alimento) throws IOException {

		try {

			connection = Conexao.getConnection();

			StringBuffer sql = new StringBuffer();
			
			sql.append("update alimento set id_grupo_alimenticio_alimento=?, valores_alimento=?, descr_alimento=? ")
				.append("where id_alimento=?");

			PreparedStatement pstmt = connection.prepareStatement(sql.toString());
			
			pstmt.setInt   (1, alimento.getIdGrupoAlimenticioAlimento());
			pstmt.setString(2, alimento.getValoresAlimento());
			pstmt.setString(3, alimento.getNomeAlimento());
			pstmt.setInt   (4, alimento.getIdAlimento());
	
			if (pstmt.executeUpdate() != 1) {
				return false;
			}
	
			Conexao.stopConnection(connection);
				
			return true;

		} catch (SQLException e) {

			e.printStackTrace();
			
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
			
			return false;
		}
	}
	
	/**
	 * 
	 * @param idAlimento
	 * @return flag
	 * @throws IOException
	 */

	public boolean excluiAlimento(int idAlimento) throws IOException {
		
		try {
			
			connection = Conexao.getConnection();

			statement = connection.createStatement();

			String sql = "delete from alimento where id_alimento=" + idAlimento;

			if (statement.executeUpdate(sql) != 1) {
				return false;
			}

			statement.close();
			Conexao.stopConnection(connection);

			return true;

		} catch (SQLException e) {

			e.printStackTrace();

			return false;
		
		} catch (Exception e) {
		
			e.printStackTrace();
		
			return false;
		}
	}
}