package br.ufpr.mityba.dao;

import java.io.IOException;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Vector;

import br.ufpr.mityba.model.Convenio;
import br.ufpr.mityba.util.Conexao;
import br.ufpr.mityba.util.ControlePrincipal;

/**
 * @author Mityba
 * @since 03/11/2008
 * @version 1.0 03/11/2008
 * @version 1.1 06/11/2008
 */

public class ConvenioDAO {

	private Connection connection;
	private Statement statement;
	private ResultSet retorno;
	private ControlePrincipal controle;

	/**
	 * 
	 * @param controle
	 */

	public ConvenioDAO(ControlePrincipal controle) {
		this.controle 	= controle;
	}

	/**
	 * 
	 */

	public ConvenioDAO() {
	}

	/**
	 * 
	 * @param where
	 * @return flag
	 * @throws IOException
	 */

	public boolean carregaConvenios(String where) throws IOException {
		
		Vector<Convenio> vector = new Vector<Convenio>();

		try {

			connection = Conexao.getConnection();

			vector.removeAllElements();

			statement = connection.createStatement();

			String sql = "select * from convenio " + where;

			retorno = statement.executeQuery(sql);

			while (retorno.next()) {
				
				vector.add(new Convenio(
					retorno.getInt		("id_convenio"),
					retorno.getDouble	("valor_consulta_convenio"),
					retorno.getString	("nome_convenio").trim(),
					retorno.getString	("cep_convenio").trim(),
					retorno.getString	("logradouro_convenio").trim(),
					retorno.getString	("num_logradouro_convenio").trim(),
					retorno.getString	("complemento_convenio").trim(),
					retorno.getString	("bairro_convenio").trim(),
					retorno.getString	("cidade_convenio").trim(),
					retorno.getString	("uf_convenio").trim(),
					retorno.getString	("contato_1_convenio").trim(),
					retorno.getString	("contato_2_convenio").trim(),
					retorno.getString	("setor_contato_1_convenio").trim(),
					retorno.getString	("setor_contato_2_convenio").trim(),
					retorno.getString	("telefone_1_convenio").trim(),
					retorno.getString	("telefone_2_convenio").trim(),
					retorno.getString	("email_1_convenio").trim(),
					retorno.getString	("email_2_convenio").trim(),
					retorno.getString	("solitar_senha_convenio").equals("S")));
			}

			statement.close();
			Conexao.stopConnection(connection);
									
			controle.setConvenios(vector);
	
			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();

			return false;

		} catch (Exception e) {

			e.printStackTrace();
		
			return false;
		}
	}
	
	/**
	 * 
	 * @param convenio
	 * @return flag
	 * @throws IOException
	 */

	public boolean incluiConvenio(Convenio convenio) throws IOException{

		try {
			
			connection = Conexao.getConnection();
			
			statement = connection.createStatement();
			
			StringBuffer sql = new StringBuffer();
			sql.append("insert into convenio (valor_consulta_convenio, nome_convenio, cep_convenio, logradouro_convenio, num_logradouro_convenio, ")
			   	.append("complemento_convenio, bairro_convenio, cidade_convenio, uf_convenio, contato_1_convenio, contato_2_convenio, ")
			   	.append("setor_contato_1_convenio, setor_contato_2_convenio, telefone_1_convenio, ")
			   	.append("telefone_2_convenio, email_1_convenio, email_2_convenio, solitar_senha_convenio) ")
			   	.append("values (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)");
			
			PreparedStatement pstmt = connection.prepareStatement(sql.toString());
			
			pstmt.setDouble(1,  convenio.getValorConsultaConvenio());
			pstmt.setString(2,  convenio.getNomeConvenio());
			pstmt.setString(3,  convenio.getCepConvenio());
			pstmt.setString(4,  convenio.getLogradouroConvenio());
			pstmt.setString(5,  convenio.getNumLogradouroConvenio());
			pstmt.setString(6,  convenio.getComplementoConvenio());
			pstmt.setString(7,  convenio.getBairroConvenio());
			pstmt.setString(8,  convenio.getCidadeConvenio());
			pstmt.setString(9,  convenio.getUfConvenio());
			pstmt.setString(10, convenio.getContato1Convenio());
			pstmt.setString(11, convenio.getContato2Convenio());
			pstmt.setString(12, convenio.getSetorContato1Convenio());
			pstmt.setString(13, convenio.getSetorContato2Convenio());
			pstmt.setString(14, convenio.getTelefone1Convenio());
			pstmt.setString(15, convenio.getTelefone2Convenio());
			pstmt.setString(16, convenio.getEmail1Convenio());
			pstmt.setString(17, convenio.getEmail2Convenio());
			pstmt.setString(18, convenio.isSolicitarSenhaConvenio() ? "S" : "N");
			
			if (pstmt.executeUpdate() != 1) {
				return false;
			}

			Conexao.stopConnection(connection);
				
			return true;

		} catch (SQLException e) {

			e.printStackTrace();
				
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
				
			return false;
		}
	}
	
	/**
	 * 
	 * @param convenio
	 * @return flag
	 * @throws IOException
	 */
	
	public boolean alteraConvenio(Convenio convenio) throws IOException {

		try {

			connection = Conexao.getConnection();

			StringBuffer sql = new StringBuffer();
			sql.append("update convenio set valor_consulta_convenio=?, nome_convenio=?, cep_convenio=?, logradouro_convenio=?, num_logradouro_convenio=?, ")
			   .append("complemento_convenio=?, bairro_convenio=?, cidade_convenio=?, uf_convenio=?, contato_1_convenio=?, contato_2_convenio=?, ")
			   .append("setor_contato_1_convenio=?, setor_contato_2_convenio=?, telefone_1_convenio=?, ")
			   .append("telefone_2_convenio=?, email_1_convenio=?, email_2_convenio=?, solitar_senha_convenio=? ")
			   .append("where id_convenio=?");

			PreparedStatement pstmt = connection.prepareStatement(sql.toString());

			pstmt.setDouble(1,  convenio.getValorConsultaConvenio());
			pstmt.setString(2,  convenio.getNomeConvenio());
			pstmt.setString(3,  convenio.getCepConvenio());
			pstmt.setString(4,  convenio.getLogradouroConvenio());
			pstmt.setString(5,  convenio.getNumLogradouroConvenio());
			pstmt.setString(6,  convenio.getComplementoConvenio());
			pstmt.setString(7,  convenio.getBairroConvenio());
			pstmt.setString(8,  convenio.getCidadeConvenio());
			pstmt.setString(9,  convenio.getUfConvenio());
			pstmt.setString(10, convenio.getContato1Convenio());
			pstmt.setString(11, convenio.getContato2Convenio());
			pstmt.setString(12, convenio.getSetorContato1Convenio());
			pstmt.setString(13, convenio.getSetorContato2Convenio());
			pstmt.setString(14, convenio.getTelefone1Convenio());
			pstmt.setString(15, convenio.getTelefone2Convenio());
			pstmt.setString(16, convenio.getEmail1Convenio());
			pstmt.setString(17, convenio.getEmail2Convenio());
			pstmt.setString(18, convenio.isSolicitarSenhaConvenio() ? "S" : "N");
			pstmt.setInt   (19, convenio.getIdConvenio());

			if (pstmt.executeUpdate() != 1) {
				return false;
			}

			Conexao.stopConnection(connection);
							
			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();

			return false;
			
		} catch (Exception e) {
			
			e.printStackTrace();
						
			return false;
		}
	}
	
	/**
	 * 
	 * @param idConvenio
	 * @return flag
	 * @throws IOException
	 */

	public boolean excluiConvenio(int idConvenio) throws IOException {
		
		try {
			
			connection = Conexao.getConnection();

			statement = connection.createStatement();

			String sql = "delete from convenio where id_convenio=" + idConvenio;
			
			System.out.println(sql);

			if (statement.executeUpdate(sql) != 1)
				return false;
			

			statement.close();
			Conexao.stopConnection(connection);

			return true;

		} catch (SQLException e) {

			e.printStackTrace();

			return false;
		}
	}
}