package br.ufpr.mityba.dao;

import java.io.IOException;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Vector;

import br.ufpr.mityba.model.DiarioAlimentacaoPaciente;
import br.ufpr.mityba.util.Conexao;
import br.ufpr.mityba.util.ControlePrincipal;

/**
 * @author Mityba
 * @since 02/12/2008
 * @version 1.0 02/12/2008
 */

public class DiarioAlimentacaoPacienteDAO {
 
	private Connection connection;
	private Statement statement;
	private ResultSet retorno;
	private ControlePrincipal controle;

	/**
	 * 
	 * @param controle
	 */

	public DiarioAlimentacaoPacienteDAO(ControlePrincipal controle) {
		this.controle 	= controle;
	}
	
	/**
	 * 
	 */

	public DiarioAlimentacaoPacienteDAO() {
	}
	
	/**
	 * 
	 * @param where
	 * @return flag
	 * @throws IOException
	 */

	public boolean carregaDiarioAlimentacao(String where) throws IOException {
		
		Vector<DiarioAlimentacaoPaciente> vector = new Vector<DiarioAlimentacaoPaciente>();

		try {

			connection = Conexao.getConnection();

			vector.removeAllElements();

			statement = connection.createStatement();

			String sql = "select * from diario_alimentacao_paciente " + where;

			retorno = statement.executeQuery(sql);

			while (retorno.next()) {

				vector.add(new DiarioAlimentacaoPaciente(
					retorno.getInt 		("id_diario_alimentacao_paciente"),
					retorno.getInt 		("id_paciente_diario_alimentacao_paciente"),
					retorno.getInt 		("id_alimento_diario_alimentacao_paciente"),
					retorno.getInt		("quantidade_porcoes_diario_alimentacao_paciente"),
					retorno.getInt		("refeicao_diario_alimentacao_paciente"),
					retorno.getString	("data_referencia_diario_alimentacao_paciente").trim()));
			}
			
			controle.setDiariosAlimentacao(vector);
			
			Conexao.stopConnection(connection);

			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();

			return false;

		} catch (Exception e) {
		
			e.printStackTrace();
			
			return false;
		}
	}
	
	/**
	 * 
	 * @param diario
	 * @return flag
	 * @throws IOException
	 */

	public boolean incluiDiarioAlimentacao(DiarioAlimentacaoPaciente diario) throws IOException{

		try {
			
			connection = Conexao.getConnection();

			StringBuffer sql = new StringBuffer();
			
			sql.append("insert into diario_alimentacao_paciente (id_alimento_diario_alimentacao_paciente, refeicao_diario_alimentacao_paciente, ")
				.append("quantidade_porcoes_diario_alimentacao_paciente, data_referencia_diario_alimentacao_paciente, id_paciente_diario_alimentacao_paciente) ")
				.append("values(?,?,?,?,?)");				

			PreparedStatement pstmt = connection.prepareStatement(sql.toString());

			pstmt.setInt	(1, diario.getIdAlimentoDiarioAlimentacaoPaciente());
			pstmt.setInt	(2, diario.getRefeicaoDiarioAlimentacaoPaciente());
			pstmt.setInt	(3, diario.getQuantidadePorcoesDiarioAlimentacaoPaciente());
			pstmt.setString	(4, diario.getDataDiarioAlimentacaoPaciente());
			pstmt.setInt	(5, diario.getIdPacienteDiarioAlimentacaoPaciente());

			if (pstmt.executeUpdate() != 1) {
				return false;
			}

			Conexao.stopConnection(connection);
			
			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();
				
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
				
			return false;
		}
	}

	/**
	 * 
	 * @param diario
	 * @return flag
	 * @throws IOException
	 */

	public boolean alteraDiarioAlimentacao(DiarioAlimentacaoPaciente diario) throws IOException {

		try {

			connection = Conexao.getConnection();

			StringBuffer sql = new StringBuffer();
			
			sql.append("update diario_alimentacao_paciente set id_alimento_diario_alimentacao_paciente=?, refeicao_diario_alimentacao_paciente=?, ")
				.append("quantidade_porcoes_diario_alimentacao_paciente=?, data_referencia_diario_alimentacao_paciente=?, id_paciente_diario_alimentacao_paciente=? ")
				.append("where id_diario_alimentacao_paciente=?");

			PreparedStatement pstmt = connection.prepareStatement(sql.toString());

			pstmt.setInt	(1, diario.getIdAlimentoDiarioAlimentacaoPaciente());
			pstmt.setInt	(2, diario.getRefeicaoDiarioAlimentacaoPaciente());
			pstmt.setInt	(3, diario.getQuantidadePorcoesDiarioAlimentacaoPaciente());
			pstmt.setString	(4, diario.getDataDiarioAlimentacaoPaciente());
			pstmt.setInt	(5, diario.getIdPacienteDiarioAlimentacaoPaciente());
			pstmt.setInt	(6, diario.getIdDiarioAlimentacaoPaciente());
	
			if (pstmt.executeUpdate() != 1) {
				return false;
			}
	
			Conexao.stopConnection(connection);
				
			return true;

		} catch (SQLException e) {

			e.printStackTrace();
			
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
			
			return false;
		}
	}
	
	/**
	 * 
	 * @param idDiarioAlimentacao
	 * @return flag
	 * @throws IOException
	 */

	public boolean excluiDiarioAlimentacao(int idDiarioAlimentacao) throws IOException {
		
		try {
			
			connection = Conexao.getConnection();

			statement = connection.createStatement();

			String sql = "delete from diario_alimentacao_paciente where id_diario_alimentacao_paciente=" + idDiarioAlimentacao;

			if (statement.executeUpdate(sql) != 1) {
				return false;
			}

			statement.close();
			Conexao.stopConnection(connection);

			return true;

		} catch (SQLException e) {

			e.printStackTrace();

			return false;
		
		} catch (Exception e) {
		
			e.printStackTrace();
		
			return false;
		}
	}
}