package br.ufpr.mityba.dao;

import java.io.IOException;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Vector;

import br.ufpr.mityba.model.DietaApoio;
import br.ufpr.mityba.util.Conexao;
import br.ufpr.mityba.util.ControlePrincipal;

/**
 * @author Mityba
 * @since 24/10/2008
 * @version 1.0 
 */

public class DietaApoioDAO {
 
	private Connection connection;
	private Statement statement;
	private ResultSet retorno;
	private ControlePrincipal controle;

	/**
	 * 
	 * @param controle
	 */

	public DietaApoioDAO(ControlePrincipal controle) {
		this.controle 	= controle;
	}
	
	/**
	 * 
	 */

	public DietaApoioDAO() {
	}
	
	/**
	 * 
	 * @param where
	 * @return flag
	 * @throws IOException
	 */

	public boolean carregaDietasApoio(String where) throws IOException {
		
		Vector<DietaApoio> vector = new Vector<DietaApoio>();

		try {

			connection = Conexao.getConnection();

			vector.removeAllElements();

			statement = connection.createStatement();

			String sql = "select * from dieta_apoio " + where;

			retorno = statement.executeQuery(sql);

			while (retorno.next()) {

				vector.add(new DietaApoio(
					retorno.getInt	 ("id_dieta_apoio"),
					retorno.getString("titulo_dieta_apoio").trim(),
					retorno.getString("descr_dieta_apoio").trim()));
			}
			
			controle.setDietasApoio(vector);
			
			Conexao.stopConnection(connection);

			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();

			return false;

		} catch (Exception e) {
		
			e.printStackTrace();
			
			return false;
		}
	}
	
	/**
	 * 
	 * @param dieta 
	 * @return flag
	 * @throws IOException
	 */

	public boolean incluiDietaApoio(DietaApoio dieta) throws IOException{

		try {
			
			connection = Conexao.getConnection();

			String sql = "insert into dieta_apoio (titulo_dieta_apoio, descr_dieta_apoio) values (?, ?)";

			PreparedStatement pstmt = connection.prepareStatement(sql);

			pstmt.setString(1, dieta.getTituloDietaApoio());
			pstmt.setString(2, dieta.getDescrApoio());

			if (pstmt.executeUpdate() != 1) {
				return false;
			}

			Conexao.stopConnection(connection);
			
			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();
				
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
				
			return false;
		}
	}

	/**
	 * 
	 * @param dieta
	 * @return flag
	 * @throws IOException
	 */

	public boolean alteraDietaApoio(DietaApoio dieta) throws IOException {

		try {

			connection = Conexao.getConnection();

			String sql = "update dieta_apoio set titulo_dieta_apoio=?, descr_dieta_apoio=? where id_dieta_apoio=?";
			
			PreparedStatement pstmt = connection.prepareStatement(sql);

			pstmt.setString	(1, dieta.getTituloDietaApoio());
			pstmt.setString	(2, dieta.getDescrApoio());
			pstmt.setInt	(3, dieta.getIdDietaApoio());

			if (pstmt.executeUpdate() != 1) {
				return false;
			}

			Conexao.stopConnection(connection);
				
			return true;

		} catch (SQLException e) {

			e.printStackTrace();
			
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
			
			return false;
		}
	}
	
	/**
	 * 
	 * @param idDietaApoio
	 * @return flag
	 * @throws IOException
	 */

	public boolean excluiDietaApoio(int idDietaApoio) throws IOException {
		
		try {
			
			connection = Conexao.getConnection();

			statement = connection.createStatement();

			String sql = "delete from dieta_apoio where id_dieta_apoio=" + idDietaApoio;

			if (statement.executeUpdate(sql) != 1) {
				return false;
			}

			statement.close();
			Conexao.stopConnection(connection);

			return true;

		} catch (SQLException e) {

			e.printStackTrace();

			return false;
		
		} catch (Exception e) {
		
			e.printStackTrace();

			return false;
		}
	}
}