package br.ufpr.mityba.dao;

import java.io.IOException;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Vector;

import br.ufpr.mityba.model.Endereco;
import br.ufpr.mityba.util.Conexao;
import br.ufpr.mityba.util.ControlePrincipal;

/**
 * @author Mityba
 * @since 20/10/2008
 * @version 1.0 20/10/2008
 * @version 2.0 03/11/2008
 */

public class EnderecoDAO {
 
	private Connection connection;
	private Statement statement;
	private ResultSet retorno;
	private ControlePrincipal controle;

	/**
	 * 
	 * @param controle
	 */

	public EnderecoDAO(ControlePrincipal controle) {
		this.controle 	= controle;
	}
	
	/**
	 * 
	 */

	public EnderecoDAO() {
	}
	
	/**
	 * 
	 * @param where
	 * @return flag
	 * @throws IOException
	 */

	public boolean carregaEnderecos(String where) throws IOException {
		
		Vector<Endereco> vector = new Vector<Endereco>();

		try {

			connection = Conexao.getConnection();

			vector.removeAllElements();

			statement = connection.createStatement();

			String sql = "select * from endereco " + where;

			retorno = statement.executeQuery(sql);

			while (retorno.next()) {
				
				vector.add(new Endereco(
					retorno.getInt		("id_endereco"),
					retorno.getString	("cep").trim(),	
					retorno.getString	("tp_logradouro").trim(),
					retorno.getString	("nome_logradouro").trim(),
					retorno.getString	("bairro").trim(),
					retorno.getString	("cidade").trim(),
					retorno.getString	("uf")));
			}

			statement.close();
			Conexao.stopConnection(connection);
									
			controle.setEnderecos(vector);
	
			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();

			return false;

		} catch (Exception e) {

			e.printStackTrace();
		
			return false;
		}
	}
	
	/**
	 * 
	 * @param endereco
	 * @return flag
	 * @throws IOException
	 */

	public boolean incluiEndereco(Endereco endereco) throws IOException{

		try {
			
			connection = Conexao.getConnection();
			
			StringBuffer sql = new StringBuffer();
			sql.append("insert into endereco (cep, tp_logradouro, nome_logradouro, bairro, cidade, uf) ")
			   .append("values (?,?,?,?,?,?)");

			PreparedStatement pstmt = connection.prepareStatement(sql.toString());

			pstmt.setString	(1, endereco.getCepEndereco());
			pstmt.setString	(2, endereco.getTipoLogradouro());
			pstmt.setString	(3, endereco.getNomeLogradouro());
			pstmt.setString	(4, endereco.getNomeBairro());
			pstmt.setString	(5, endereco.getNomeCidade());
			pstmt.setString	(6, endereco.getNomeUF());

			if (pstmt.executeUpdate() != 1) {
				return false;
			}
			
			Conexao.stopConnection(connection);
				
			return true;

		} catch (SQLException e) {

			e.printStackTrace();
				
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
				
			return false;
		}
	}
	
	/**
	 * 
	 * @param endereco
	 * @return flag
	 * @throws IOException
	 */
	
	public boolean alteraEndereco(Endereco endereco) throws IOException {

		try {

			connection = Conexao.getConnection();

			StringBuffer sql = new StringBuffer();
			sql.append("update endereco set cep=?, tp_logradouro=?, nome_logradouro=?, bairro=?, cidade=?, uf=?) ")
			   .append("where id_usuario=?");

			PreparedStatement pstmt = connection.prepareStatement(sql.toString());

			pstmt.setString	(1, endereco.getCepEndereco());
			pstmt.setString	(2, endereco.getTipoLogradouro());
			pstmt.setString	(3, endereco.getNomeLogradouro());
			pstmt.setString	(4, endereco.getNomeBairro());
			pstmt.setString	(5, endereco.getNomeCidade());
			pstmt.setString	(6, endereco.getNomeUF());
			pstmt.setInt	(7, endereco.getIdEndereco());

			if (pstmt.executeUpdate() != 1) {
				return false;
			}

			Conexao.stopConnection(connection);
							
			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();

			return false;
			
		} catch (Exception e) {
			
			e.printStackTrace();
						
			return false;
		}
	}
	
	/**
	 * 
	 * @param idEndereco
	 * @return flag
	 * @throws IOException
	 */

	public boolean excluiEndereco(int idEndereco) throws IOException {
		
		try {
			
			connection = Conexao.getConnection();

			statement = connection.createStatement();

			String sql = "delete from endereco where id_endereco=" + idEndereco;

			if (statement.executeUpdate(sql) != 1) {

				return false;
			}

			statement.close();
			Conexao.stopConnection(connection);

			return true;

		} catch (SQLException e) {

			e.printStackTrace();

			return false;
		}
	}
}