package br.ufpr.mityba.dao;

import java.io.IOException;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Vector;

import br.ufpr.mityba.model.GrupoAlimenticio;
import br.ufpr.mityba.util.Conexao;
import br.ufpr.mityba.util.ControlePrincipal;

/**
 * @author Mityba
 * @since 11/11/2008
 * @version 1.0 
 */

public class GrupoAlimenticioDAO {
 
	private Connection connection;
	private Statement statement;
	private ResultSet retorno;
	private ControlePrincipal controle;

	/**
	 * 
	 * @param controle
	 */

	public GrupoAlimenticioDAO(ControlePrincipal controle) {
		this.controle 	= controle;
	}
	
	/**
	 * 
	 */

	public GrupoAlimenticioDAO() {
	}
	
	/**
	 * 
	 * @param where
	 * @return flag
	 * @throws IOException
	 */

	public boolean carregaGrupoAlimenticio(String where) throws IOException {
		
		Vector<GrupoAlimenticio> vector = new Vector<GrupoAlimenticio>();

		try {

			connection = Conexao.getConnection();

			vector.removeAllElements();

			statement = connection.createStatement();

			String sql = "select * from grupo_alimenticio " + where;

			retorno = statement.executeQuery(sql);

			while (retorno.next()) {

				vector.add(new GrupoAlimenticio(
					retorno.getInt 		("id_grupo_alimenticio"),
					retorno.getDouble	("valor_calorico_grupo_alimenticio"),
					retorno.getString	("descr_grupo_alimenticio").trim()));
			}
			
			controle.setGruposAlimenticios(vector);
			
			Conexao.stopConnection(connection);

			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();

			return false;

		} catch (Exception e) {
		
			e.printStackTrace();
			
			return false;
		}
	}
	
	/**
	 * 
	 * @param grupoAlimenticio
	 * @return flag
	 * @throws IOException
	 */

	public boolean incluiGrupoAlimenticio(GrupoAlimenticio grupoAlimenticio) throws IOException{

		try {
			
			connection = Conexao.getConnection();

			StringBuffer sql = new StringBuffer();
			
			sql.append("insert into grupo_alimenticio (valor_calorico_grupo_alimenticio, descr_grupo_alimenticio) ")
				.append("values(?,?)");				

			PreparedStatement pstmt = connection.prepareStatement(sql.toString());
			
			pstmt.setDouble	(1, grupoAlimenticio.getValorCaloricoGrupoAlimenticio());
			pstmt.setString	(2, grupoAlimenticio.getNomeGrupoAlimenticio());

			if (pstmt.executeUpdate() != 1) {
				return false;
			}

			Conexao.stopConnection(connection);
			
			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();
				
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
				
			return false;
		}
	}

	/**
	 * 
	 * @param grupoAlimenticio
	 * @return flag
	 * @throws IOException
	 */

	public boolean alteraGrupoAlimenticio(GrupoAlimenticio grupoAlimenticio) throws IOException {

		try {

			connection = Conexao.getConnection();

			StringBuffer sql = new StringBuffer();
			
			sql.append("update grupo_alimenticio set valor_calorico_grupo_alimenticio=?, descr_grupo_alimenticio=? ")
				.append("where id_grupo_alimenticio=?");

			PreparedStatement pstmt = connection.prepareStatement(sql.toString());
			
			pstmt.setDouble(1, grupoAlimenticio.getValorCaloricoGrupoAlimenticio());
			pstmt.setString(2, grupoAlimenticio.getNomeGrupoAlimenticio());
			pstmt.setInt   (3, grupoAlimenticio.getIdGrupoAlimenticio());
	
			if (pstmt.executeUpdate() != 1) {
				return false;
			}
	
			Conexao.stopConnection(connection);
				
			return true;

		} catch (SQLException e) {

			e.printStackTrace();
			
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
			
			return false;
		}
	}
	
	/**
	 * 
	 * @param idGrupoAlimenticio
	 * @return flag
	 * @throws IOException
	 */

	public boolean excluiGrupoAlimenticio(int idGrupoAlimenticio) throws IOException {
		
		try {
			
			connection = Conexao.getConnection();

			statement = connection.createStatement();

			String sql = "delete from grupo_alimenticio where id_grupo_alimenticio=" + idGrupoAlimenticio;

			if (statement.executeUpdate(sql) != 1) {
				return false;
			}

			statement.close();
			Conexao.stopConnection(connection);

			return true;

		} catch (SQLException e) {

			e.printStackTrace();

			return false;
		
		} catch (Exception e) {
		
			e.printStackTrace();
		
			return false;
		}
	}
}