package br.ufpr.mityba.dao;

import java.io.IOException;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Vector;

import br.ufpr.mityba.model.HistoricoPaciente;
import br.ufpr.mityba.util.Conexao;
import br.ufpr.mityba.util.ControlePrincipal;

/**
 * @author Mityba
 * @since 11/11/2008
 * @version 1.0 
 */

public class HistoricoPacienteDAO {
 
	private Connection connection;
	private Statement statement;
	private ResultSet retorno;
	private ControlePrincipal controle;

	/**
	 * 
	 * @param controle
	 */

	public HistoricoPacienteDAO(ControlePrincipal controle) {
		this.controle 	= controle;
	}
	
	/**
	 * 
	 */

	public HistoricoPacienteDAO() {
	}
	
	/**
	 * 
	 * @param where
	 * @return flag
	 * @throws IOException
	 */

	public boolean carregaHistoricoPaciente(String where) throws IOException {
		
		Vector<HistoricoPaciente> vector = new Vector<HistoricoPaciente>();

		try {

			connection = Conexao.getConnection();

			vector.removeAllElements();

			statement = connection.createStatement();

			String sql = "select * from historico_paciente " + where + " order by id_historico_paciente desc";

			retorno = statement.executeQuery(sql);

			while (retorno.next()) {

				vector.add(new HistoricoPaciente(
					retorno.getInt 		("id_historico_paciente"),
					retorno.getInt 		("id_consulta_historico_paciente"),
					retorno.getInt 		("id_paciente_historico_paciente"),
					retorno.getInt 		("id_motivacao_historico_paciente"),
					retorno.getInt 		("id_atividade_fisica_historico_paciente"),
					retorno.getDouble	("peso_historico_paciente"),
					retorno.getDouble	("peso_meta_historico_paciente"),
					retorno.getDouble	("altura_historico_paciente"),
					retorno.getDouble	("percentual_gordura_historico_paciente"),
					retorno.getDouble	("valor_energetico_total_historico_paciente"),
					retorno.getDouble	("valor_energetico_dieta_historico_paciente"),
					retorno.getString	("pressao_arterial_historico_paciente").trim(),
					retorno.getString	("anamnese_hist_historico_paciente").trim(),
					retorno.getString	("anamnese_atual_historico_paciente").trim(),
					retorno.getString	("exames_hist_historico_paciente").trim(),
					retorno.getString	("exames_atual_historico_paciente").trim(),
					retorno.getString	("prescricao_hist_historico_paciente").trim(),
					retorno.getString	("prescricao_atual_historico_paciente").trim()));
			}
			
			controle.setHistoricoPacientes(vector);
			
			Conexao.stopConnection(connection);

			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();

			return false;

		} catch (Exception e) {
		
			e.printStackTrace();
			
			return false;
		}
	}
	
	/**
	 * 
	 * @param historico
	 * @return flag
	 * @throws IOException
	 */

	public boolean incluiHistoricoPaciente(HistoricoPaciente historico) throws IOException{

		try {
			
			connection = Conexao.getConnection();

			StringBuffer sql = new StringBuffer();
			
			sql.append("insert into historico_paciente (id_consulta_historico_paciente, id_paciente_historico_paciente, id_motivacao_historico_paciente, ")
				.append("id_atividade_fisica_historico_paciente, peso_historico_paciente, peso_meta_historico_paciente, altura_historico_paciente, ")
				.append("percentual_gordura_historico_paciente, valor_energetico_total_historico_paciente, valor_energetico_dieta_historico_paciente, ")
				.append("pressao_arterial_historico_paciente, anamnese_hist_historico_paciente, anamnese_atual_historico_paciente, exames_hist_historico_paciente, ")
				.append("exames_atual_historico_paciente, prescricao_hist_historico_paciente, prescricao_atual_historico_paciente) ")
				.append("values(?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)");

			PreparedStatement pstmt = connection.prepareStatement(sql.toString());

			pstmt.setInt	(1, historico.getIdConsultaHistoricoPaciente());
			pstmt.setInt	(2, historico.getIdPacienteHistoricoPaciente());
			pstmt.setInt	(3, historico.getIdMotivoHistoricoPaciente());
			pstmt.setInt	(4, historico.getIdAtividadeFisicaHistoricoPaciente());
			pstmt.setDouble	(5, historico.getPesoHistoricoPaciente());
			pstmt.setDouble	(6, historico.getPesoMetaHistoricoPaciente());
			pstmt.setDouble	(7, historico.getAlturaHistoricoPaciente());
			pstmt.setDouble	(8, historico.getPercentualGorduraHistoricoPaciente());
			pstmt.setDouble	(9, historico.getValorEnergeticoTotalHistoricoPaciente());
			pstmt.setDouble	(10, historico.getValorEnergeticoDietaHistoricoPaciente());
			pstmt.setString	(11, historico.getPressaoArterialHistoricoPaciente());
			pstmt.setString	(12, historico.getAnamneseHistoricoHistoricoPaciente());
			pstmt.setString	(13, historico.getAnamneseAtualHistoricoPaciente());
			pstmt.setString	(14, historico.getExamesHistoricoHistoricoPaciente());
			pstmt.setString	(15, historico.getExamesAtualHistoricoPaciente());
			pstmt.setString	(16, historico.getPrescricaoHistoricoHistoricoPaciente());
			pstmt.setString	(17, historico.getPrescricaoAtualHistoricoPaciente());

			if (pstmt.executeUpdate() != 1) {
				return false;
			}

			Conexao.stopConnection(connection);
			
			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();
				
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
				
			return false;
		}
	}

	/**
	 * 
	 * @param historico
	 * @return flag
	 * @throws IOException
	 */

	public boolean alteraHistoricoPaciente(HistoricoPaciente historico) throws IOException {

		try {

			connection = Conexao.getConnection();

			StringBuffer sql = new StringBuffer();
			
			sql.append("update historico_paciente set id_consulta_historico_paciente=?, id_paciente_historico_paciente=?, id_motivacao_historico_paciente=?, ")
				.append("id_atividade_fisica_historico_paciente=?, peso_historico_paciente=?, peso_meta_historico_paciente=?, altura_historico_paciente=?, ")
				.append("percentual_gordura_historico_paciente=?, valor_energetico_total_historico_paciente=?, valor_energetico_dieta_historico_paciente=?, ")
				.append("pressao_arterial_historico_paciente=?, anamnese_hist_historico_paciente=?, anamnese_atual_historico_paciente=?, exames_hist_historico_paciente=?, ")
				.append("exames_atual_historico_paciente=?, prescricao_hist_historico_paciente=?, prescricao_atual_historico_paciente=? ")
				.append("where id_historico_paciente=?");

			PreparedStatement pstmt = connection.prepareStatement(sql.toString());
	
			pstmt.setInt	(1, historico.getIdConsultaHistoricoPaciente());
			pstmt.setInt	(2, historico.getIdPacienteHistoricoPaciente());
			pstmt.setInt	(3, historico.getIdMotivoHistoricoPaciente());
			pstmt.setInt	(4, historico.getIdAtividadeFisicaHistoricoPaciente());
			pstmt.setDouble	(5, historico.getPesoHistoricoPaciente());
			pstmt.setDouble	(6, historico.getPesoMetaHistoricoPaciente());
			pstmt.setDouble	(7, historico.getAlturaHistoricoPaciente());
			pstmt.setDouble	(8, historico.getPercentualGorduraHistoricoPaciente());
			pstmt.setDouble	(9, historico.getValorEnergeticoTotalHistoricoPaciente());
			pstmt.setDouble	(10, historico.getValorEnergeticoDietaHistoricoPaciente());
			pstmt.setString	(11, historico.getPressaoArterialHistoricoPaciente());
			pstmt.setString	(12, historico.getAnamneseHistoricoHistoricoPaciente());
			pstmt.setString	(13, historico.getAnamneseAtualHistoricoPaciente());
			pstmt.setString	(14, historico.getExamesHistoricoHistoricoPaciente());
			pstmt.setString	(15, historico.getExamesAtualHistoricoPaciente());
			pstmt.setString	(16, historico.getPrescricaoHistoricoHistoricoPaciente());
			pstmt.setString	(17, historico.getPrescricaoAtualHistoricoPaciente());
			pstmt.setInt	(18, historico.getIdHistoricoPaciente());
	
			if (pstmt.executeUpdate() != 1) {
				return false;
			}
	
			Conexao.stopConnection(connection);
				
			return true;

		} catch (SQLException e) {

			e.printStackTrace();
			
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
			
			return false;
		}
	}
	
	/**
	 * 
	 * @param idHistoricoPaciente
	 * @return flag
	 * @throws IOException
	 */

	public boolean excluiHistoricoPaciente(int idHistoricoPaciente) throws IOException {
		
		try {
			
			connection = Conexao.getConnection();

			statement = connection.createStatement();

			String sql = "delete from historico_paciente where id_historico_paciente=" + idHistoricoPaciente;

			if (statement.executeUpdate(sql) != 1) {
				return false;
			}

			statement.close();
			Conexao.stopConnection(connection);

			return true;

		} catch (SQLException e) {

			e.printStackTrace();

			return false;
		
		} catch (Exception e) {
		
			e.printStackTrace();
		
			return false;
		}
	}
}