package br.ufpr.mityba.dao;

import java.io.IOException;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Vector;

import br.ufpr.mityba.model.HorarioConsulta;
import br.ufpr.mityba.util.Conexao;
import br.ufpr.mityba.util.ControlePrincipal;



/**
 * @author Mityba
 * @since 14/11/2008
 * @version 1.0 14/11/2008
 * @version 2.0 24/11/2008
 */

public class HorarioConsultaDAO {
 
	private Connection connection;
	private Statement statement;
	private ResultSet retorno;
	private ControlePrincipal controle;

	/**
	 * 
	 * @param controle
	 */

	public HorarioConsultaDAO(ControlePrincipal controle) {
		this.controle 	= controle;
	}
	
	/**
	 * 
	 */

	public HorarioConsultaDAO() {
	}
	
	/**
	 * 
	 * @param where
	 * @return flag
	 * @throws IOException
	 */

	public boolean carregaHorarios(String where) throws IOException {
		
		Vector<HorarioConsulta> vector = new Vector<HorarioConsulta>();

		try {

			connection = Conexao.getConnection();

			vector.removeAllElements();

			statement = connection.createStatement();

			String sql = "select * from horario_consulta where status_horario_consulta <> 'I' " + where + " order by horario_ini_horario_consulta";
			
			retorno = statement.executeQuery(sql);

			while (retorno.next()) {

				vector.add(new HorarioConsulta(
					retorno.getInt		("id_horario_consulta"),
					retorno.getInt		("id_intervalo_horario_consulta"),
					retorno.getInt		("id_usuario_horario_consulta"),
					retorno.getInt		("dia_semana_horario_consulta"),
					retorno.getInt		("tempo_intervalo_horario_consulta"),
					retorno.getString	("horario_ini_horario_consulta").trim()));
			}
			
			controle.setHorariosConsulta(vector);

			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();

			return false;

		} catch (Exception e) {
		
			e.printStackTrace();
			
			return false;
		}
	}
	
	/**
	 * 
	 * @param horario
	 * @return flag
	 * @throws IOException
	 */

	public boolean incluiHorarioConsulta(HorarioConsulta horario) throws IOException{

		try {
			
			connection = Conexao.getConnection();
			
			StringBuffer sql = new StringBuffer();
			sql.append("insert into horario_consulta (dia_semana_horario_consulta, tempo_intervalo_horario_consulta, ")
			   	.append("horario_ini_horario_consulta, id_intervalo_horario_consulta, id_usuario_horario_consulta, status_horario_consulta ) ")
			   	.append("values (?,?,?,?,?,?)");
			
			PreparedStatement pstmt = connection.prepareStatement(sql.toString());
			
			pstmt.setInt	(1, horario.getDiaSemanaHorarioConsulta());
			pstmt.setInt	(2, horario.getTempoIntervaloHorarioConsulta());
			pstmt.setString	(3, horario.getHorarioHorarioConsulta());
			pstmt.setInt	(4, horario.getIdIntervaloHorarioConsulta());
			pstmt.setInt	(5, horario.getIdUsuarioHorarioConsulta());
			pstmt.setString	(6, "A");

			if (pstmt.executeUpdate() != 1) {
				return false;
			}

			Conexao.stopConnection(connection);
			
			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();
				
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
				
			return false;
		}
	}

	/**
	 * 
	 * @param horario
	 * @return flag
	 * @throws IOException
	 */

	public boolean alteraHorarioConsulta(HorarioConsulta horario) throws IOException {

		try {

			connection = Conexao.getConnection();

			StringBuffer sql = new StringBuffer();
			sql.append("update horario_consulta set dia_semana_horario_consulta=?, tempo_intervalo_horario_consulta=?, ")
			   .append("horario_ini_horario_consulta=?, id_intervalo_horario_consulta=?, id_usuario_horario_consulta=? ")   
			   .append("where id_horario_consulta=?");
		
			PreparedStatement pstmt = connection.prepareStatement(sql.toString());
			
			pstmt.setInt	(1, horario.getDiaSemanaHorarioConsulta());
			pstmt.setInt	(2, horario.getTempoIntervaloHorarioConsulta());
			pstmt.setString	(3, horario.getHorarioHorarioConsulta());
			pstmt.setInt	(5, horario.getIdIntervaloHorarioConsulta());
			pstmt.setInt	(6, horario.getIdUsuarioHorarioConsulta());
			pstmt.setInt	(7, horario.getIdHorarioConsulta());

			if (pstmt.executeUpdate() != 1) {
				return false;
			}
			
			Conexao.stopConnection(connection);
				
			return true;

		} catch (SQLException e) {

			e.printStackTrace();
			
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
			
			return false;
		}
	}
	
	/**
	 * 
	 * @param idHorarioConsulta
	 * @return flag
	 * @throws IOException
	 */

	public boolean excluiHorarioConsulta(int idHorarioConsulta) throws IOException {
		
		try {
			
			connection = Conexao.getConnection();

			statement = connection.createStatement();

			String sql = "update horario_consulta set status_horario_consulta='I' where id_horario_consulta=" + idHorarioConsulta;

			if (statement.executeUpdate(sql) != 1) {
				return false;
			}

			statement.close();
			Conexao.stopConnection(connection);

			return true;

		} catch (SQLException e) {

			e.printStackTrace();

			return false;
		
		} catch (Exception e) {
		
			e.printStackTrace();
		
			return false;
		}
	}
	
	/**
	 * 
	 * @param idIntervaloHorarioConsulta
	 * @return flag
	 * @throws IOException
	 */

	public boolean excluiHorarioConsultaPorIntervalo(int idIntervaloHorarioConsulta) throws IOException {
		
		try {
			
			connection = Conexao.getConnection();

			statement = connection.createStatement();

			String sql = "update horario_consulta set status_horario_consulta='I', id_intervalo_horario_consulta=0, dia_semana_horario_consulta=-1 where id_intervalo_horario_consulta=" + idIntervaloHorarioConsulta;

			if (statement.executeUpdate(sql) != 1) {
				return false;
			}

			statement.close();
			Conexao.stopConnection(connection);

			return true;

		} catch (SQLException e) {

			e.printStackTrace();

			return false;
		
		} catch (Exception e) {
		
			e.printStackTrace();
		
			return false;
		}
	}
}