package br.ufpr.mityba.dao;

import java.io.IOException;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Vector;

import br.ufpr.mityba.model.IntervaloHorarioConsulta;
import br.ufpr.mityba.util.Conexao;
import br.ufpr.mityba.util.ControlePrincipal;



/**
 * @author Mityba
 * @since 24/11/2008
 * @version 1.0 24/11/2008
 */

public class IntervaloHorarioConsultaDAO {
 
	private Connection connection;
	private Statement statement;
	private ResultSet retorno;
	private ControlePrincipal controle;

	/**
	 * 
	 * @param controle
	 */

	public IntervaloHorarioConsultaDAO(ControlePrincipal controle) {
		this.controle 	= controle;
	}
	
	/**
	 * 
	 */

	public IntervaloHorarioConsultaDAO() {
	}
	
	/**
	 * 
	 * @param where
	 * @return flag
	 * @throws IOException
	 */

	public boolean carregaIntervalosHorarioConsulta(String where) throws IOException {
		
		Vector<IntervaloHorarioConsulta> vector = new Vector<IntervaloHorarioConsulta>();

		try {

			connection = Conexao.getConnection();

			vector.removeAllElements();

			statement = connection.createStatement();

			String sql = "select * from intervalo_horario_consulta " + where + " order by horario_ini_intervalo_horario_consulta";

			retorno = statement.executeQuery(sql);

			while (retorno.next()) {

				vector.add(new IntervaloHorarioConsulta(
					retorno.getInt		("id_intervalo_horario_consulta"),
					retorno.getInt		("id_usuario_intervalo_horario_consulta"),
					retorno.getInt		("dia_semana_intervalo_horario_consulta"),
					retorno.getInt		("tempo_intervalo_horario_consulta"),
					retorno.getString	("horario_ini_intervalo_horario_consulta").trim(),
					retorno.getString	("horario_fim_intervalo_horario_consulta").trim()));
			}
			
			controle.setIntervalosConsulta(vector);

			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();

			return false;

		} catch (Exception e) {
		
			e.printStackTrace();
			
			return false;
		}
	}
	
	/**
	 * 
	 * @return max
	 * @throws IOException
	 */

	public int maxIntervalosHorarioConsulta() throws IOException {

		try {

			connection = Conexao.getConnection();

			statement = connection.createStatement();

			String sql = "select max(id_intervalo_horario_consulta) from intervalo_horario_consulta";

			retorno = statement.executeQuery(sql);

			while (retorno.next()) {

				return retorno.getInt(1);
			}

			return 0;

		} catch (SQLException e) {
			
			e.printStackTrace();

			return -1;

		} catch (Exception e) {
		
			e.printStackTrace();
			
			return -1;
		}
	}
	
	/**
	 * 
	 * @param hora
	 * @param idUsuario
	 * @param diaSemana
	 * @return flag
	 * @throws IOException
	 */

	public boolean existeIntervalosHoraHorarioConsulta(int hora, int idUsuario, int diaSemana) throws IOException {

		try {

			connection = Conexao.getConnection();

			statement = connection.createStatement();

			StringBuffer sql = new StringBuffer();
			sql.append("select id_intervalo_horario_consulta from intervalo_horario_consulta ")
				.append("where horario_ini_intervalo_horario_consulta like '" + hora + ":%' ")
				.append("and dia_semana_intervalo_horario_consulta=" + diaSemana)
				.append("and id_usuario_intervalo_horario_consulta=" + idUsuario);

			retorno = statement.executeQuery(sql.toString());

			while (retorno.next()) {
				return true;
			}

			return false;

		} catch (SQLException e) {
			
			e.printStackTrace();

			return false;

		} catch (Exception e) {
		
			e.printStackTrace();
			
			return false;
		}
	}
	
	/**
	 * 
	 * @param intervalo
	 * @return flag
	 * @throws IOException
	 */

	public boolean incluiIntervaloHorarioConsulta(IntervaloHorarioConsulta intervalo) throws IOException{

		try {
			
			connection = Conexao.getConnection();
			
			StringBuffer sql = new StringBuffer();
			sql.append("insert into intervalo_horario_consulta (dia_semana_intervalo_horario_consulta, tempo_intervalo_horario_consulta, ")
			   	.append("horario_ini_intervalo_horario_consulta, horario_fim_intervalo_horario_consulta, id_usuario_intervalo_horario_consulta) ")
			   	.append("values (?,?,?,?,?)");
			
			PreparedStatement pstmt = connection.prepareStatement(sql.toString());

			pstmt.setInt	(1, intervalo.getDiaSemanaIntervaloHorarioConsulta());
			pstmt.setInt	(2, intervalo.getTempoIntervaloHorarioConsulta());
			pstmt.setString	(3, intervalo.getHorarioInicialIntervaloHorarioConsulta());
			pstmt.setString	(4, intervalo.getHorarioFinalIntervaloHorarioConsulta());
			pstmt.setInt	(5, intervalo.getIdUsuarioHorarioConsulta());

			if (pstmt.executeUpdate() != 1) {
				return false;
			}

			Conexao.stopConnection(connection);
			
			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();
				
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
				
			return false;
		}
	}

	/**
	 * 
	 * @param intervalo
	 * @return flag
	 * @throws IOException
	 */

	public boolean alteraIntervaloHorarioConsulta(IntervaloHorarioConsulta intervalo) throws IOException {

		try {

			connection = Conexao.getConnection();

			StringBuffer sql = new StringBuffer();
			sql.append("update intervalo_horario_consulta set dia_semana_intervalo_horario_consulta=?, tempo_intervalo_horario_consulta=?, ")
			   .append("horario_ini_intervalo_horario_consulta=?, horario_fim_intervalo_horario_consulta=?, id_usuario_intervalo_horario_consulta=? ")   
			   .append("where id_intervalo_horario_consulta=?");
		
			PreparedStatement pstmt = connection.prepareStatement(sql.toString());
			
			pstmt.setInt	(1, intervalo.getDiaSemanaIntervaloHorarioConsulta());
			pstmt.setInt	(2, intervalo.getTempoIntervaloHorarioConsulta());
			pstmt.setString	(3, intervalo.getHorarioInicialIntervaloHorarioConsulta());
			pstmt.setString	(4, intervalo.getHorarioFinalIntervaloHorarioConsulta());
			pstmt.setInt	(5, intervalo.getIdUsuarioHorarioConsulta());
			pstmt.setInt	(6, intervalo.getIdIntervaloHorarioConsulta());

			if (pstmt.executeUpdate() != 1) {
				return false;
			}
			
			Conexao.stopConnection(connection);
				
			return true;

		} catch (SQLException e) {

			e.printStackTrace();
			
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
			
			return false;
		}
	}
	
	/**
	 * 
	 * @param idHorarioConsulta
	 * @return flag
	 * @throws IOException
	 */

	public boolean excluiHorarioConsulta(int idHorarioConsulta) throws IOException {
		
		try {
			
			connection = Conexao.getConnection();

			statement = connection.createStatement();

			String sql = "delete from intervalo_horario_consulta where id_intervalo_horario_consulta=" + idHorarioConsulta;

			if (statement.executeUpdate(sql) != 1) {
				return false;
			}

			statement.close();
			Conexao.stopConnection(connection);

			return true;

		} catch (SQLException e) {

			e.printStackTrace();

			return false;
		
		} catch (Exception e) {
		
			e.printStackTrace();
		
			return false;
		}
	}
}