package br.ufpr.mityba.dao;

import java.io.IOException;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Vector;

import br.ufpr.mityba.model.Lancamento;
import br.ufpr.mityba.util.Conexao;
import br.ufpr.mityba.util.ControlePrincipal;



/**
 * @author Mityba
 * @since 17/11/2008
 * @version 1.0 17/11/2008
 */

public class LancamentoDAO {
 
	private Connection connection;
	private Statement statement;
	private ResultSet retorno;
	private ControlePrincipal controle;

	/**
	 * 
	 * @param controle
	 */

	public LancamentoDAO(ControlePrincipal controle) {
		this.controle 	= controle;
	}
	
	/**
	 * 
	 */

	public LancamentoDAO() {
	}
	
	/**
	 * 
	 * @param where
	 * @return flag
	 * @throws IOException
	 */

	public boolean carregaFinanceiro(String where) throws IOException {
		
		Vector<Lancamento> vector = new Vector<Lancamento>();

		try {

			connection = Conexao.getConnection();

			vector.removeAllElements();

			statement = connection.createStatement();

			String sql = "select * from lancamento " + where;

			retorno = statement.executeQuery(sql);

			while (retorno.next()) {

				vector.add(new Lancamento(
					retorno.getInt		("id_lancamento"),
					retorno.getInt		("id_convenio_lancamento"),
					retorno.getInt		("id_status_consulta_lancamento"),
					retorno.getDouble	("valor_lancamento"),
					retorno.getString	("data_lancamento")));
			}
			
			controle.setFinanceiros(vector);

			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();

			return false;

		} catch (Exception e) {
		
			e.printStackTrace();
			
			return false;
		}
	}

	/**
	 * 
	 * @param idConvenio
	 * @param idStatusConsulta
	 * @param mes
	 * @return count
	 * @throws IOException
	 */

	public int countConvenioLancamento(int idConvenio, int idStatusConsulta, String mes) throws IOException {

		try {

			connection = Conexao.getConnection();

			statement = connection.createStatement();

			StringBuffer sql = new StringBuffer();
			sql.append("select count(*) from lancamento ")
				.append("where id_convenio_lancamento=")
				.append(idConvenio)
				.append(" and id_status_consulta_lancamento=")
				.append(idStatusConsulta)
				.append(" and data_lancamento like '%/")
				.append(mes)
				.append("/%'");

			retorno = statement.executeQuery(sql.toString());

			while (retorno.next()) {
				return retorno.getInt(1);
			}

			return 0;

		} catch (SQLException e) {
			
			e.printStackTrace();

			return -1;

		} catch (Exception e) {
		
			e.printStackTrace();
			
			return -1;
		}
	}

	/**
	 * 
	 * @param idConvenio
	 * @param idStatusConsulta
	 * @param mes
	 * @return count
	 * @throws IOException
	 */

	public double sumConvenioLancamento(int idConvenio, int idStatusConsulta, String mes) throws IOException {

		try {

			connection = Conexao.getConnection();

			statement = connection.createStatement();

			StringBuffer sql = new StringBuffer();
			sql.append("select sum(valor_lancamento) from lancamento ")
				.append("where id_convenio_lancamento=")
				.append(idConvenio)
				.append(" and id_status_consulta_lancamento=")
				.append(idStatusConsulta)
				.append(" and data_lancamento like '%/")
				.append(mes)
				.append("/%'");

			retorno = statement.executeQuery(sql.toString());

			while (retorno.next()) {
				return retorno.getDouble(1);
			}

			return 0;

		} catch (SQLException e) {

			e.printStackTrace();

			return -1;

		} catch (Exception e) {

			e.printStackTrace();

			return -1;
		}
	}

	/**
	 * 
	 * @param idStatusConsulta
	 * @param mes
	 * @return count
	 * @throws IOException
	 */

	public int countLancamento(int idStatusConsulta, String mes) throws IOException {

		try {

			connection = Conexao.getConnection();

			statement = connection.createStatement();

			StringBuffer sql = new StringBuffer();
			sql.append("select count(*) from lancamento ")
				.append("where id_status_consulta_lancamento=")
				.append(idStatusConsulta)
				.append(" and data_lancamento like '%/")
				.append(mes)
				.append("/%'");

			retorno = statement.executeQuery(sql.toString());

			while (retorno.next()) {
				return retorno.getInt(1);
			}

			return 0;

		} catch (SQLException e) {

			e.printStackTrace();

			return -1;

		} catch (Exception e) {
		
			e.printStackTrace();
			
			return -1;
		}
	}
	
	/**
	 * 
	 * @param idStatusConsulta
	 * @param mes
	 * @return count
	 * @throws IOException
	 */

	public double sumLancamento(int idStatusConsulta, String mes) throws IOException {

		try {

			connection = Conexao.getConnection();

			statement = connection.createStatement();

			StringBuffer sql = new StringBuffer();
			sql.append("select sum(valor_lancamento) from lancamento ")
				.append("where id_status_consulta_lancamento=")
				.append(idStatusConsulta)
				.append(" and data_lancamento like '%/")
				.append(mes)
				.append("/%'");

			retorno = statement.executeQuery(sql.toString());

			while (retorno.next()) {
				return retorno.getDouble(1);
			}

			return 0;

		} catch (SQLException e) {
			
			e.printStackTrace();

			return -1;

		} catch (Exception e) {
		
			e.printStackTrace();
			
			return -1;
		}
	}
	
	/**
	 * 
	 * @param lancamento
	 * @return flag
	 * @throws IOException
	 */

	public boolean incluiLancamento(Lancamento lancamento) throws IOException{

		try {
			
			connection = Conexao.getConnection();
			
			StringBuffer sql = new StringBuffer();
			sql.append("insert into lancamento (id_convenio_lancamento, id_status_consulta_lancamento, valor_lancamento, data_lancamento) ")
			   	.append("values (?,?,?,?)");
			
			PreparedStatement pstmt = connection.prepareStatement(sql.toString());

			pstmt.setInt	(1, lancamento.getIdConvenioFinanceiro());
			pstmt.setInt	(2, lancamento.getIdStatusConsultaFinanceiro());
			pstmt.setDouble	(3, lancamento.getValorLancamentoFinanceiro());
			pstmt.setString	(4, lancamento.getDataLancamento());

			if (pstmt.executeUpdate() != 1) {
				return false;
			}

			Conexao.stopConnection(connection);
			
			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();
				
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
				
			return false;
		}
	}

	/**
	 * 
	 * @param lancamento
	 * @return flag
	 * @throws IOException
	 */

	public boolean alteraLancamento(Lancamento lancamento) throws IOException {

		try {

			connection = Conexao.getConnection();

			StringBuffer sql = new StringBuffer();
			sql.append("update lancamento set id_convenio_lancamento=?, id_status_consulta_lancamento=?, valor_lancamento=?, data_lancamento=? ")
			   	.append("where id_lancamento=?");
			
			PreparedStatement pstmt = connection.prepareStatement(sql.toString());
	
			pstmt.setInt	(1, lancamento.getIdConvenioFinanceiro());
			pstmt.setInt	(2, lancamento.getIdStatusConsultaFinanceiro());
			pstmt.setInt	(3, lancamento.getIdStatusConsultaFinanceiro());
			pstmt.setString	(4, lancamento.getDataLancamento());
			pstmt.setInt	(5, lancamento.getIdFinanceiro());

			if (pstmt.executeUpdate() != 1) {
				return false;
			}
			
			Conexao.stopConnection(connection);
				
			return true;

		} catch (SQLException e) {

			e.printStackTrace();
			
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
			
			return false;
		}
	}
	
	/**
	 * 
	 * @param idLancamento
	 * @return flag
	 * @throws IOException
	 */

	public boolean excluiLancamento(int idLancamento) throws IOException {
		
		try {
			
			connection = Conexao.getConnection();

			statement = connection.createStatement();

			String sql = "delete from lancamento where id_lancamento=" + idLancamento;

			if (statement.executeUpdate(sql) != 1) {
				return false;
			}

			statement.close();
			Conexao.stopConnection(connection);

			return true;

		} catch (SQLException e) {

			e.printStackTrace();

			return false;
		
		} catch (Exception e) {
		
			e.printStackTrace();
		
			return false;
		}
	}
}