
package br.ufpr.mityba.dao;

import java.io.IOException;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Vector;

import br.ufpr.mityba.model.Medicamento;
import br.ufpr.mityba.util.Conexao;
import br.ufpr.mityba.util.ControlePrincipal;

/**
 * @author Mityba
 * @since 10/11/2008
 * @version 1.0 
 */

public class MedicamentoDAO {
 
	private Connection connection;
	private Statement statement;
	private ResultSet retorno;
	private ControlePrincipal controle;

	/**
	 * 
	 * @param controle
	 */

	public MedicamentoDAO(ControlePrincipal controle) {
		this.controle 	= controle;
	}
	
	/**
	 * 
	 */

	public MedicamentoDAO() {
	}
	
	/**
	 * 
	 * @param where
	 * @return flag
	 * @throws IOException
	 */

	public boolean carregaMedicamentos(String where) throws IOException {
		
		Vector<Medicamento> vector = new Vector<Medicamento>();

		try {

			connection = Conexao.getConnection();

			vector.removeAllElements();

			statement = connection.createStatement();

			String sql = "select * from medicamento where id_medicamento <> 0 " + where;

			retorno = statement.executeQuery(sql);

			while (retorno.next()) {

				vector.add(new Medicamento(
					retorno.getInt	 ("id_medicamento"),
					retorno.getString("nome_comercial_medicamento").trim(),
					retorno.getString("principio_ativo_medicamento"),//.trim(),
					retorno.getString("indicacao_medicamento").trim(),
					retorno.getString("contra_indicacao_medicamento").trim(),
					retorno.getString("instrucoes_ingestao_medicamento").trim(),
					retorno.getString("efeitos_colaterais_medicamento").trim(),
					retorno.getString("alteracoes_sanguineas_medicamento").trim(),
					retorno.getString("cuidados_gestacao_medicamento").trim(),
					retorno.getString("interacao_dieta_medicamento").trim(),
					retorno.getString("precaucoes_medicamento").trim(),
					retorno.getString("alteracos_diversas_medicamento").trim(),
					retorno.getString("outras_orientacoes_medicamento").trim()));
			}
			
			controle.setMedicamentos(vector);
			
			Conexao.stopConnection(connection);

			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();

			return false;

		} catch (Exception e) {
		
			e.printStackTrace();
			
			return false;
		}
	}
	
	/**
	 * 
	 * @param where
	 * @return flag
	 * @throws IOException
	 */

	public int maxIdMedicamento() throws IOException {

		try {
			
			int maxId = 0;

			connection = Conexao.getConnection();

			statement = connection.createStatement();

			String sql = "select max(id_medicamento) from medicamento";

			retorno = statement.executeQuery(sql);

			while (retorno.next()) {
				maxId = retorno.getInt(1);
			}
			
			Conexao.stopConnection(connection);
			
			return maxId;

		} catch (SQLException e) {
			
			e.printStackTrace();

			return -1;

		} catch (Exception e) {
		
			e.printStackTrace();
			
			return -1;
		}
	}
	
	/**
	 * 
	 * @param medicamento
	 * @return flag
	 * @throws IOException
	 */

	public boolean incluiMedicamento(Medicamento medicamento) throws IOException{

		try {
			
			connection = Conexao.getConnection();

			StringBuffer sql = new StringBuffer();
			
			sql.append("insert into medicamento (nome_comercial_medicamento, principio_ativo_medicamento, indicacao_medicamento, ")
				.append("contra_indicacao_medicamento, instrucoes_ingestao_medicamento, efeitos_colaterais_medicamento, ")
				.append("alteracoes_sanguineas_medicamento, cuidados_gestacao_medicamento, interacao_dieta_medicamento, ")
				.append("precaucoes_medicamento, alteracos_diversas_medicamento, outras_orientacoes_medicamento) ")
				.append("values(?,?,?,?,?,?,?,?,?,?,?,?)");				

			PreparedStatement pstmt = connection.prepareStatement(sql.toString());
			
			pstmt.setString(1,  medicamento.getNomeComercialMedicamento());
			pstmt.setString(2,  medicamento.getPrincipioAtivoMedicamento());
			pstmt.setString(3,  medicamento.getIndicacaoMedicamento());
			pstmt.setString(4,  medicamento.getContraIndicacaoMedicamento());
			pstmt.setString(5,  medicamento.getInstrucoesIngestaoMedicamento());
			pstmt.setString(6,  medicamento.getEfeitosColateraisMedicamento());
			pstmt.setString(7,  medicamento.getAlteracoesSanguineasMedicamento());
			pstmt.setString(8,  medicamento.getCuidadosGestacaoMedicamento());
			pstmt.setString(9,  medicamento.getInteracaoDietaMedicamento());
			pstmt.setString(10, medicamento.getPrecaucoesMedicamento());
			pstmt.setString(11, medicamento.getAlteracoesDiversasMedicamento());
			pstmt.setString(12, medicamento.getOutrasOrientacoesMedicamento());

			if (pstmt.executeUpdate() != 1) {
				return false;
			}

			Conexao.stopConnection(connection);
			
			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();
				
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
				
			return false;
		}
	}

	/**
	 * 
	 * @param medicamento
	 * @return flag
	 * @throws IOException
	 */

	public boolean alteraMedicamento(Medicamento medicamento) throws IOException {

		try {

			connection = Conexao.getConnection();

			StringBuffer sql = new StringBuffer();
			
			sql.append("update medicamento set nome_comercial_medicamento=?, principio_ativo_medicamento=?, indicacao_medicamento=?, ")
				.append("contra_indicacao_medicamento=?, instrucoes_ingestao_medicamento=?, efeitos_colaterais_medicamento=?, ")
				.append("alteracoes_sanguineas_medicamento=?, cuidados_gestacao_medicamento=?, interacao_dieta_medicamento=?, ")
				.append("precaucoes_medicamento=?, alteracos_diversas_medicamento=?, outras_orientacoes_medicamento=? ")
				.append("where id_medicamento=?");				

			PreparedStatement pstmt = connection.prepareStatement(sql.toString());
			
			pstmt.setString(1,  medicamento.getNomeComercialMedicamento());
			pstmt.setString(2,  medicamento.getPrincipioAtivoMedicamento());
			pstmt.setString(3,  medicamento.getIndicacaoMedicamento());
			pstmt.setString(4,  medicamento.getContraIndicacaoMedicamento());
			pstmt.setString(5,  medicamento.getInstrucoesIngestaoMedicamento());
			pstmt.setString(6,  medicamento.getEfeitosColateraisMedicamento());
			pstmt.setString(7,  medicamento.getAlteracoesSanguineasMedicamento());
			pstmt.setString(8,  medicamento.getCuidadosGestacaoMedicamento());
			pstmt.setString(9,  medicamento.getInteracaoDietaMedicamento());
			pstmt.setString(10, medicamento.getPrecaucoesMedicamento());
			pstmt.setString(11, medicamento.getAlteracoesDiversasMedicamento());
			pstmt.setString(12, medicamento.getOutrasOrientacoesMedicamento());
			pstmt.setInt   (13, medicamento.getIdMedicamento());
	
			if (pstmt.executeUpdate() != 1) {
				return false;
			}
	
			Conexao.stopConnection(connection);
				
			return true;

		} catch (SQLException e) {

			e.printStackTrace();
			
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
			
			return false;
		}
	}
	
	/**
	 * 
	 * @param idMedicamento
	 * @return flag
	 * @throws IOException
	 */

	public boolean excluiMedicamento(int idMedicamento) throws IOException {
		
		try {
			
			connection = Conexao.getConnection();

			statement = connection.createStatement();

			String sql = "delete from medicamento where id_medicamento=" + idMedicamento;

			if (statement.executeUpdate(sql) != 1) {
				return false;
			}

			statement.close();
			Conexao.stopConnection(connection);

			return true;

		} catch (SQLException e) {

			e.printStackTrace();

			return false;
		
		} catch (Exception e) {
		
			e.printStackTrace();
		
			return false;
		}
	}
}