package br.ufpr.mityba.dao;

import java.io.IOException;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Vector;

import br.ufpr.mityba.model.Mensagem;
import br.ufpr.mityba.util.Conexao;
import br.ufpr.mityba.util.ControlePrincipal;



/**
 * @author Mityba
 * @since 24/10/2008
 * @version 1.0 24/10/2008
 * @version 2.0 03/11/2008
 */

public class MensagemDAO {
 
	private Connection connection;
	private Statement statement;
	private ResultSet retorno;
	private ControlePrincipal controle;

	/**
	 * 
	 * @param controle
	 */

	public MensagemDAO(ControlePrincipal controle) {
		this.controle 	= controle;
	}
	
	/**
	 * 
	 */

	public MensagemDAO() {
	}
	
	/**
	 * 
	 * @param where
	 * @return flag
	 * @throws IOException
	 */

	public boolean carregaMensagens(String where) throws IOException {
		
		Vector<Mensagem> vector = new Vector<Mensagem>();

		try {

			connection = Conexao.getConnection();

			vector.removeAllElements();

			statement = connection.createStatement();

			String sql = "select * from mensagem " + where + " order by id_mensagem";

			retorno = statement.executeQuery(sql);

			while (retorno.next()) {

				vector.add(new Mensagem(
					retorno.getInt		("id_mensagem"),
					retorno.getInt		("id_profissao_mensagem"),
					retorno.getInt		("id_tp_mensagem"),
					retorno.getInt		("qde_dias_antes_mensagem"),
					retorno.getString	("data_envio_mensagem").trim(),
					retorno.getString	("titulo_mensagem").trim(),
					retorno.getString	("descricao_mensagem").trim()));
			}
			
			controle.setMensagens(vector);

			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();

			return false;

		} catch (Exception e) {
		
			e.printStackTrace();
			
			return false;
		}
	}
	
	/**
	 * 
	 * @param mensagem
	 * @return flag
	 * @throws IOException
	 */

	public boolean incluiMensagem(Mensagem mensagem) throws IOException{

		try {
			
			connection = Conexao.getConnection();
			
			StringBuffer sql = new StringBuffer();
			sql.append("insert into mensagem (id_profissao_mensagem, id_tp_mensagem, titulo_mensagem, descricao_mensagem, ")
			   	.append("data_envio_mensagem, qde_dias_antes_mensagem) ")
			   	.append("values (?,?,?,?,?,?)");
			
			PreparedStatement pstmt = connection.prepareStatement(sql.toString());
			
			pstmt.setInt	(1, mensagem.getIdProfissaoMensagem());
			pstmt.setInt	(2, mensagem.getIdTipoMensagem());
			pstmt.setString	(3, mensagem.getTituloMensagem());
			pstmt.setString	(4, mensagem.getDescricaoMensagem());
			pstmt.setString	(5, mensagem.getDataEnvioMensagem());
			pstmt.setInt	(6, mensagem.getQdeDiasAntesMensagem());

			if (pstmt.executeUpdate() != 1) {
				return false;
			}

			Conexao.stopConnection(connection);
			
			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();
				
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
				
			return false;
		}
	}

	/**
	 * 
	 * @param mensagem
	 * @return flag
	 * @throws IOException
	 */

	public boolean alteraMensagem(Mensagem mensagem) throws IOException {

		try {

			connection = Conexao.getConnection();

			StringBuffer sql = new StringBuffer();
			sql.append("update mensagem id_profissao_mensagem=?, id_tp_mensagem=?, titulo_mensagem=?, descricao_mensagem=?, ")
			   .append("data_envio_mensagem=?, qde_dias_antes_mensagem=? ")   
			   .append("where id_mensagem=?");

			PreparedStatement pstmt = connection.prepareStatement(sql.toString());

			pstmt.setInt	(1, mensagem.getIdProfissaoMensagem());
			pstmt.setInt	(2, mensagem.getIdTipoMensagem());
			pstmt.setString	(3, mensagem.getTituloMensagem());
			pstmt.setString	(4, mensagem.getDescricaoMensagem());
			pstmt.setString	(5, mensagem.getDataEnvioMensagem());
			pstmt.setInt	(6, mensagem.getQdeDiasAntesMensagem());
			pstmt.setInt	(7, mensagem.getIdMensagem());

			if (pstmt.executeUpdate() != 1) {
				return false;
			}
			
			Conexao.stopConnection(connection);
				
			return true;

		} catch (SQLException e) {

			e.printStackTrace();
			
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
			
			return false;
		}
	}
	
	/**
	 * 
	 * @param idMensagem
	 * @return flag
	 * @throws IOException
	 */

	public boolean excluiMensagem(int idMensagem) throws IOException {
		
		try {
			
			connection = Conexao.getConnection();

			statement = connection.createStatement();

			String sql = "delete from mensagem where id_mensagem=" + idMensagem;

			if (statement.executeUpdate(sql) != 1) {
				return false;
			}

			statement.close();
			Conexao.stopConnection(connection);

			return true;

		} catch (SQLException e) {

			e.printStackTrace();

			return false;
		
		} catch (Exception e) {
		
			e.printStackTrace();
		
			return false;
		}
	}
}
