package br.ufpr.mityba.dao;

import java.io.IOException;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Vector;

import br.ufpr.mityba.model.NomeGenerico;
import br.ufpr.mityba.util.Conexao;
import br.ufpr.mityba.util.ControlePrincipal;

/**
 * @author Mityba
 * @since 10/11/2008
 * @version 1.0 
 */

public class NomeGenericoDAO {
 
	private Connection connection;
	private Statement statement;
	private ResultSet retorno;
	private ControlePrincipal controle;

	/**
	 * 
	 * @param controle
	 */

	public NomeGenericoDAO(ControlePrincipal controle) {
		this.controle 	= controle;
	}
	
	/**
	 * 
	 */

	public NomeGenericoDAO() {
	}
	
	/**
	 * 
	 * @param where
	 * @return flag
	 * @throws IOException
	 */

	public boolean carregaNomesGenericos(String where) throws IOException {
		
		Vector<NomeGenerico> vector = new Vector<NomeGenerico>();

		try {

			connection = Conexao.getConnection();

			vector.removeAllElements();

			statement = connection.createStatement();

			String sql = "select * from nome_generico " + where;

			retorno = statement.executeQuery(sql);

			while (retorno.next()) {

				vector.add(new NomeGenerico(
					retorno.getInt	 ("id_nome_generico"),
					retorno.getInt	 ("id_medicamento_nome_generico"),
					retorno.getString("descr_nome_generico").trim()));
			}
			
			controle.setNomesGenericos(vector);
			
			Conexao.stopConnection(connection);

			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();

			return false;

		} catch (Exception e) {
		
			e.printStackTrace();
			
			return false;
		}
	}
	
	/**
	 * 
	 * @param nomeGenerico
	 * @return flag
	 * @throws IOException
	 */

	public boolean incluiNomeGenerico(NomeGenerico nomeGenerico) throws IOException{

		try {
			
			connection = Conexao.getConnection();

			StringBuffer sql = new StringBuffer();
			
			sql.append("insert into nome_generico (id_medicamento_nome_generico, descr_nome_generico) ")
				.append("values(?,?)");				

			PreparedStatement pstmt = connection.prepareStatement(sql.toString());
			
			pstmt.setInt   (1,  nomeGenerico.getIdMedicamento());
			pstmt.setString(2,  nomeGenerico.getDescrGenerico());

			if (pstmt.executeUpdate() != 1) {
				return false;
			}

			Conexao.stopConnection(connection);
			
			return true;

		} catch (SQLException e) {
			
			e.printStackTrace();
				
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
				
			return false;
		}
	}

	/**
	 * 
	 * @param nomeGenerico
	 * @return flag
	 * @throws IOException
	 */

	public boolean alteraNomeGenerico(NomeGenerico nomeGenerico) throws IOException {

		try {

			connection = Conexao.getConnection();

			StringBuffer sql = new StringBuffer();
			
			sql.append("update nome_generico set id_medicamento_nome_generico=?, descr_nome_generico=? ")
				.append("where id_nome_generico=?");				

			PreparedStatement pstmt = connection.prepareStatement(sql.toString());

			pstmt.setInt   (1, nomeGenerico.getIdMedicamento());
			pstmt.setString(2, nomeGenerico.getDescrGenerico());
			pstmt.setInt   (3, nomeGenerico.getIdNomeGenerico());
	
			if (pstmt.executeUpdate() != 1) {
				return false;
			}
	
			Conexao.stopConnection(connection);
				
			return true;

		} catch (SQLException e) {

			e.printStackTrace();
			
			return false;
			
		} catch (Exception e) {

			e.printStackTrace();
			
			return false;
		}
	}
	
	/**
	 * 
	 * @param idNomeGenerico
	 * @return flag
	 * @throws IOException
	 */

	public boolean excluiNomeGenerico(int idNomeGenerico) throws IOException {
		
		try {
			
			connection = Conexao.getConnection();

			statement = connection.createStatement();

			String sql = "delete from nome_generico where id_nome_generico=" + idNomeGenerico;

			if (statement.executeUpdate(sql) != 1) {
				return false;
			}

			statement.close();
			Conexao.stopConnection(connection);

			return true;

		} catch (SQLException e) {

			e.printStackTrace();

			return false;
		
		} catch (Exception e) {
		
			e.printStackTrace();
		
			return false;
		}
	}
	
	/**
	 * 
	 * @param idMedicamento
	 * @return flag
	 * @throws IOException
	 */

	public boolean excluiNomeGenericoPorMedicamento(int idMedicamento) throws IOException {
		
		try {
			
			connection = Conexao.getConnection();

			statement = connection.createStatement();

			String sql = "delete from nome_generico where id_medicamento_nome_generico=" + idMedicamento;
			
			if (statement.executeUpdate(sql) != 1) {
				return false;
			}

			statement.close();
			Conexao.stopConnection(connection);

			return true;

		} catch (SQLException e) {

			e.printStackTrace();

			return false;
		
		} catch (Exception e) {
		
			e.printStackTrace();
		
			return false;
		}
	}
}