package br.ufpr.mityba.servlets;

import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.Vector;

import javax.servlet.RequestDispatcher;
import javax.servlet.Servlet;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import br.ufpr.mityba.controller.GerenteConsultaHorarioConsulta;
import br.ufpr.mityba.controller.GerenteConsultaPaciente;
import br.ufpr.mityba.controller.GerenteConsultaUsuario;
import br.ufpr.mityba.dao.ConsultaDAO;
import br.ufpr.mityba.model.Consulta;
import br.ufpr.mityba.model.HorarioConsulta;
import br.ufpr.mityba.model.ViewPacienteConsulta;
import br.ufpr.mityba.util.Constantes;
import br.ufpr.mityba.util.ControlePrincipal;
import br.ufpr.mityba.util.Utilitarios;

/**
 * Servlet implementation class for Servlet: ServletAgendaSite
 * 
 * @author Mityba
 * @since 09/12/2008
 * @version 1.0 09/12/2008
 */
 public class ServletAgendaSite extends HttpServlet implements Servlet {
	 
   static final long serialVersionUID = 13243842L;
   
   /**
	 * @param pReq 
	 * @param pResp 
	 * @throws ServletException 
	 * @throws IOException 
	 * 
	 */
   public void service(HttpServletRequest pReq, HttpServletResponse pResp)	throws ServletException, IOException {
	   
		Vector<String> tErro = new Vector<String>();

		HttpSession session = pReq.getSession(false);

		String service = pReq.getParameter("service");

		if (session == null) {

			tErro.add("Voc deve efetuar o login antes de acessar essa funcionalidade!");

		} else {
		
			if (service == null || service.equals("")) {
	
				tErro.add("Informar a ao a ser executada\n");
	
			} else if (service.equals("agenda")) {
				
				acaoAgenda(pReq, pResp, session);
	
			} else if (service.equals("agendarConsulta")) {
				
				acaoAgendarConsulta(pReq, pResp, session);
				
			} else if (service.equals("mudaMedico")) {
				
				acaoMudaMedico(pReq, pResp, session);
				
			} else if (service.equals("exibirDia")) {
				
				acaoExibirDia(pReq, pResp, session);
			}
		}
		
		if (tErro.size() > 0){			
			mostrarErro(pReq, pResp, tErro, "/user_home.jsp");
		}
   }

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param pErro
	 * @param pPag
	 * @throws ServletException
	 * @throws IOException
	 */

   private void mostrarErro(HttpServletRequest pReq, HttpServletResponse pResp, Vector<String> pErro, String pPag) throws ServletException, IOException {

		pReq.setAttribute("Erros", pErro);

		ativarPagina(pReq, pResp, pPag);
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param pPagina
	 * @throws ServletException
	 * @throws IOException
	 */

	private void ativarPagina(HttpServletRequest pReq, HttpServletResponse pResp, String pPagina) throws ServletException, IOException {

		ServletContext tContexto 		= getServletContext();
		RequestDispatcher tDespachante 	= tContexto.getRequestDispatcher(pPagina);
		tDespachante.forward(pReq, pResp);
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */

	private void acaoAgenda(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {

		ControlePrincipal controle 	= new ControlePrincipal();
		
		Date date 					= new Date();
		
		Calendar calendar			= new GregorianCalendar(); 
		calendar.setTimeInMillis(date.getTime());
		
		int diaSemana 				= Utilitarios.getDiaSemana(calendar.get(Calendar.DAY_OF_WEEK));
		
		int idMedico				= 0;
		
		ConsultaDAO consultaDAO		= new ConsultaDAO(controle);
		
		ViewPacienteConsulta view	= null;
		
		Vector<HorarioConsulta> horarios;
		Vector<ViewPacienteConsulta> views = new Vector<ViewPacienteConsulta>();
		
		GerenteConsultaHorarioConsulta.horariosPorDiaSemana(controle, diaSemana, idMedico);
		
		if(GerenteConsultaHorarioConsulta.horariosPorDiaSemana(controle, diaSemana, idMedico)){
			
			horarios = controle.getHorariosConsulta();
			
			for(int i = 0; i < horarios.size(); i++){
				
				view = consultaDAO.carregaViewPacienteConsulta(
					new SimpleDateFormat("dd/MM/yyyy").format(date.getTime()),
					idMedico, 
					horarios.get(i).getIdHorarioConsulta(), 
					1
				);
				
				if(view != null) 
					views.add(view);
			}
			
			pReq.setAttribute("PacientesConsulta", views);
			
		} else {
			
			pReq.setAttribute("Msg"	, "Problemas ao carregar as consultas");
		}

		GerenteConsultaUsuario.usuarioMedico(controle);
		
		pReq.setAttribute("Medicos"		, controle.getUsuarios());
		pReq.setAttribute("Data"		, String.valueOf(date.getTime()));
		pReq.setAttribute("DiaSemana"	, String.valueOf(diaSemana));
		
		ativarPagina(pReq, pResp, "/user_agenda.jsp");
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */

	private void acaoMudaMedico(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {

		ControlePrincipal controle 	= new ControlePrincipal();
		
		Date date 					= new Date(Long.parseLong(pReq.getParameter("data")));
		
		int idMedico				= Integer.parseInt(pReq.getParameter("medico"));
		int diaSemana 				= Integer.parseInt(pReq.getParameter("diaSemana"));
		
		ConsultaDAO consultaDAO		= new ConsultaDAO(controle);
		
		ViewPacienteConsulta view	= null;
		
		Vector<HorarioConsulta> horarios;
		Vector<ViewPacienteConsulta> views = new Vector<ViewPacienteConsulta>();
		
		GerenteConsultaHorarioConsulta.horariosPorDiaSemana(controle, diaSemana, idMedico);
		
		if(GerenteConsultaHorarioConsulta.horariosPorDiaSemana(controle, diaSemana, idMedico)){
			
			horarios = controle.getHorariosConsulta();
			
			for(int i = 0; i < horarios.size(); i++){
				
				view = consultaDAO.carregaViewPacienteConsulta(
					new SimpleDateFormat("dd/MM/yyyy").format(date.getTime()),
					idMedico, 
					horarios.get(i).getIdHorarioConsulta(), 
					1
				);
				
				if(view != null) 
					views.add(view);
			}
			
			pReq.setAttribute("PacientesConsulta", views);
			
		} else {
			
			pReq.setAttribute("Msg"	, "Problemas ao carregar as consultas");
		}

		GerenteConsultaUsuario.usuarioMedico(controle);
		
		pReq.setAttribute("Medicos"		, controle.getUsuarios());
		pReq.setAttribute("Data"		, date.getTime());
		pReq.setAttribute("DiaSemana"	, String.valueOf(diaSemana));
		pReq.setAttribute("Medico"		, String.valueOf(idMedico));
		
		ativarPagina(pReq, pResp, "/user_agenda.jsp");
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */

	private void acaoExibirDia(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {

		ControlePrincipal controle 	= new ControlePrincipal();
		
		Date date 					= new Date();
		
		Calendar calendar			= new GregorianCalendar(); 
		calendar.setTimeInMillis(date.getTime());
		
		int diaSemanaAtual			= Utilitarios.getDiaSemana(calendar.get(Calendar.DAY_OF_WEEK));
		
		int idMedico				= Integer.parseInt(pReq.getParameter("medico"));
		int diaSemana 				= Integer.parseInt(pReq.getParameter("diaSemana"));
		
		int diferenca				= diaSemana - diaSemanaAtual;
		
		long miliData				= System.currentTimeMillis() + (diferenca * Constantes.MILISEGUNDOS_DIA);
		
		date 						= new Date(miliData);
		
		ConsultaDAO consultaDAO		= new ConsultaDAO(controle);
		
		ViewPacienteConsulta view	= null;
		
		Vector<HorarioConsulta> horarios;
		Vector<ViewPacienteConsulta> views = new Vector<ViewPacienteConsulta>();
		
		GerenteConsultaHorarioConsulta.horariosPorDiaSemana(controle, diaSemana, idMedico);
		
		if(GerenteConsultaHorarioConsulta.horariosPorDiaSemana(controle, diaSemana, idMedico)){
			
			horarios = controle.getHorariosConsulta();
			
			for(int i = 0; i < horarios.size(); i++){
				
				view = consultaDAO.carregaViewPacienteConsulta(
					new SimpleDateFormat("dd/MM/yyyy").format(date.getTime()),
					idMedico,
					horarios.get(i).getIdHorarioConsulta(), 
					1
				);
				
				if(view != null) 
					views.add(view);
			}
			
			pReq.setAttribute("PacientesConsulta", views);
			
		} else {
			
			pReq.setAttribute("Msg"	, "Problemas ao carregar as consultas");
		}
		
		GerenteConsultaUsuario.usuarioMedico(controle);
		
		pReq.setAttribute("Medicos"		, controle.getUsuarios());
		pReq.setAttribute("Data"		, date.getTime());
		pReq.setAttribute("DiaSemana"	, String.valueOf(diaSemana));
		pReq.setAttribute("Medico"		, String.valueOf(idMedico));
		
		ativarPagina(pReq, pResp, "/user_agenda.jsp");
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */

	private void acaoAgendarConsulta(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {

		ControlePrincipal controle 	= new ControlePrincipal();
		
		Date date 					= new Date(Long.parseLong(pReq.getParameter("data")));
		
		ConsultaDAO consultaDAO		= new ConsultaDAO(controle);
		
		int idPaciente				= (Integer) session.getAttribute(Constantes.ATRIB_ID_USUARIO_LOGADO);
		int idMedico				= Integer.parseInt(pReq.getParameter("medico"));
		int diaSemana 				= Integer.parseInt(pReq.getParameter("diaSemana"));
		
		GerenteConsultaPaciente.pacientePorCodigo(controle, idPaciente);
		
		int idConvenio				= controle.getPacientes().get(0).getIdConvenio();
		
		String idsConsulta			= pReq.getParameter("idsConsulta");
		
		Consulta consulta = new Consulta(
			0,
			Integer.parseInt(idsConsulta.substring((idsConsulta.indexOf(".")) + 1)), //idHorarioConsulta
			idConvenio,
			idPaciente,
			idMedico,
			Constantes.COD_CONSULTA_PENDENTE,
			false,
			"Agendado via site",
			new SimpleDateFormat("dd/MM/yyyy").format(date.getTime())
		);
		
		consultaDAO.incluiConsulta(consulta);
		
		ViewPacienteConsulta view	= null;
		
		Vector<HorarioConsulta> horarios;
		Vector<ViewPacienteConsulta> views = new Vector<ViewPacienteConsulta>();
		
		GerenteConsultaHorarioConsulta.horariosPorDiaSemana(controle, diaSemana, idMedico);
		
		if(GerenteConsultaHorarioConsulta.horariosPorDiaSemana(controle, diaSemana, idMedico)){
			
			horarios = controle.getHorariosConsulta();
			
			for(int i = 0; i < horarios.size(); i++){
				
				view = consultaDAO.carregaViewPacienteConsulta(
					new SimpleDateFormat("dd/MM/yyyy").format(date.getTime()),
					idMedico, 
					horarios.get(i).getIdHorarioConsulta(), 
					1
				);
				
				if(view != null) 
					views.add(view);
			}
			
			pReq.setAttribute("PacientesConsulta", views);
			
		} else {
			
			pReq.setAttribute("Msg"	, "Problemas ao carregar as consultas");
		}
		
		GerenteConsultaUsuario.usuarioMedico(controle);
		
		pReq.setAttribute("Medicos"		, controle.getUsuarios());
		pReq.setAttribute("Data"		, date.getTime());
		pReq.setAttribute("DiaSemana"	, String.valueOf(diaSemana));
		pReq.setAttribute("Medico"		, String.valueOf(idMedico));
		
		ativarPagina(pReq, pResp, "/user_agenda.jsp");
	}
}