package br.ufpr.mityba.servlets;

import java.io.IOException;
import java.util.Vector;

import javax.servlet.RequestDispatcher;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import br.ufpr.mityba.controller.GerenteConsultaConvenio;
import br.ufpr.mityba.controller.GerenteConsultaEndereco;
import br.ufpr.mityba.dao.AuditLogDAO;
import br.ufpr.mityba.dao.ConvenioDAO;
import br.ufpr.mityba.model.AuditLog;
import br.ufpr.mityba.model.Convenio;
import br.ufpr.mityba.model.Endereco;
import br.ufpr.mityba.util.Constantes;
import br.ufpr.mityba.util.ControlePrincipal;

/**
 * Servlet implementation class ServletConvenio
 * 
 * @author Mityba
 * @since 03/11/2008
 * @version 1.0 03/11/2008
 * @version 1.1 06/11/2008
 */

public class ServletConvenio extends HttpServlet {

	static final long serialVersionUID = 1324122132L;

	/**
	 * @param pReq 
	 * @param pResp 
	 * @throws ServletException 
	 * @throws IOException 
	 * 
	 */
	public void service(final HttpServletRequest pReq, final HttpServletResponse pResp) throws ServletException, IOException {

		Vector<String> tErro = new Vector<String>();

		HttpSession session = pReq.getSession(false);

		String service = pReq.getParameter("service");

		if (session == null) {

			tErro.add("Voc deve efetuar o login antes de acessar essa funcionalidade!");

		} else {

			if (service == null || service.equals("")) {

				tErro.add("Informar a ao a ser executada\n");

			} else if (service.equals("cadastroConvenios")) {
				
				if((Integer) session.getAttribute(Constantes.ATRIB_ACESSO_CADASTRO) == 3){

					session.setAttribute(Constantes.ATRIB_DT_INI_CAD_CONVENIO, Constantes.HORA_ATUAL());
	
					ativarPagina(pReq, pResp, "/cadastroConvenio.jsp");	
				
				} else {
					
					tErro.add("Voc no tem o nvel de privilgio necessrio para acessar essa funcionalidade");
				}
				
			} else if (service.equals("pesquisarConvenios")) {
				
				if((Integer) session.getAttribute(Constantes.ATRIB_ACESSO_CADASTRO) >= 2){
				
					ativarPagina(pReq, pResp, "/consultaConvenio.jsp");
				
				} else {
					
					tErro.add("Voc no tem o nvel de privilgio necessrio para acessar essa funcionalidade");
				}
				
			} else if (service.equals("pesquisaPorNome")) {
				
				acaoPesquisarConvenio(pReq, pResp);
				
			} else if (service.equals("salvarCadastro")) {
				
				acaoSalvarCadastro(pReq, pResp, session);
				
			} else if (service.equals("salvarAlteracao")) {
				
				acaoSalvarAlteracao(pReq, pResp, session);
				
			} else if (service.equals("exibirConvenio")) {
				
				if((Integer) session.getAttribute(Constantes.ATRIB_ACESSO_CADASTRO) == 3){

					session.setAttribute(Constantes.ATRIB_DT_INI_ALT_CONVENIO, Constantes.HORA_ATUAL());
					session.setAttribute(Constantes.ATRIB_DT_INI_EXC_CONVENIO, Constantes.HORA_ATUAL());
					
					acaoExibirConvenio(pReq, pResp);
				
				} else {
					
					tErro.add("Voc no tem o nvel de privilgio necessrio para acessar essa funcionalidade");
				}
				
			} else if (service.equals("excluir")) {
				
				acaoExclusaoConfirmada(pReq, pResp, session);
				
			} else if (service.equals("procurarEndereco")) {
				
				acaoProcurarEndereco(pReq, pResp);
	
			} else if (service.equals("voltarConsultaConvenio")) {
				
				ativarPagina(pReq, pResp, "/consultaConvenio.jsp");

			} else if (service.equals("voltaTela")) {

				ativarPagina(pReq, pResp, "/PaginaInicial.jsp");
			}
		}

		if (tErro.size() > 0) {
			mostrarErro(pReq, pResp, tErro, "/cadastroConvenio.jsp");
		}
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param pErro
	 * @param pPag
	 * @throws ServletException
	 * @throws IOException
	 */

	private void mostrarErro(HttpServletRequest pReq, HttpServletResponse pResp, Vector<String> pErro, String pPag) throws ServletException, IOException {
		pReq.setAttribute("Erros", pErro);
		ativarPagina(pReq, pResp, pPag);
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param pPagina
	 * @throws ServletException
	 * @throws IOException
	 */

	private void ativarPagina(HttpServletRequest pReq, HttpServletResponse pResp, String pPagina) throws ServletException, IOException {
		ServletContext tContexto 		= getServletContext();
		RequestDispatcher tDespachante 	= tContexto.getRequestDispatcher(pPagina);
		tDespachante.forward(pReq, pResp);
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoSalvarCadastro(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {
		
		Vector<String> tErro		= new Vector<String>();
		
		String nomeDigitado 		= pReq.getParameter("nome");
		String cepDigitado			= pReq.getParameter("cep");
		String enderecoDigitado		= pReq.getParameter("rua");
		String numEnderecoDigitado	= pReq.getParameter("numEndereco");
		String bairroDigitado		= pReq.getParameter("bairro");
		String cidadeDigitado		= pReq.getParameter("cidade");
		String ufDigitado			= pReq.getParameter("uf");
		String complementoDigitado	= pReq.getParameter("complemento");
		String contato1Digitado 	= pReq.getParameter("contato1");
		String contato2Digitado 	= pReq.getParameter("contato2");
		String setor1Digitado 		= pReq.getParameter("setor1");
		String setor2Digitado	 	= pReq.getParameter("setor2");
		String fone1Digitado		= pReq.getParameter("fone1");
		String fone2Digitado		= pReq.getParameter("fone2");
		String email1Digitado 		= pReq.getParameter("email1");
		String email2Digitado	 	= pReq.getParameter("email2");
		String valorConsultaDigitado= pReq.getParameter("valorConsulta").replace(',', '.').replace("R$ ", "");
		String solicitarDigitado	= pReq.getParameter("solicitarSenha");
		
		double valorConsultaNum		= 0.0;
		
		if(nomeDigitado == null || nomeDigitado.equals(""))
			tErro.add("O campo nome deve ser preenchido!");
		
		if(valorConsultaDigitado == null || valorConsultaDigitado.equals(""))
			tErro.add("O campo valor da consulta deve ser preenchido!");
		
		try{
			valorConsultaNum = Double.parseDouble(valorConsultaDigitado);
		} catch (NumberFormatException e) {
			tErro.add("O campo valor da consulta em formato incorreto!");
		}
		
		if(solicitarDigitado == null || solicitarDigitado.equals("")){
			solicitarDigitado = "n";
		}
		
		if(tErro.size() > 0){
			mostrarErro(pReq, pResp, tErro, "/cadastroConvenio.jsp");
			
		} else {
			
			Convenio convenio = new Convenio(
				0,
				valorConsultaNum,
				nomeDigitado,
				cepDigitado,
				enderecoDigitado,
				numEnderecoDigitado,
				complementoDigitado,
				bairroDigitado,
				cidadeDigitado,
				ufDigitado,
				contato1Digitado,
				contato2Digitado,
				setor1Digitado,
				setor2Digitado,
				fone1Digitado,
				fone2Digitado,
				email1Digitado,
				email2Digitado,
				solicitarDigitado.equals("s")
			);
			
			if(new ConvenioDAO().incluiConvenio(convenio)){
				
				String loginUsuario = (String) session.getAttribute(Constantes.ATRIB_USUARIO_LOGADO);
				String ipUsuario 	= (String) session.getAttribute(Constantes.ATRIB_IP_LOGADO);
				String dtIni 		= (String) session.getAttribute(Constantes.ATRIB_DT_INI_CAD_CONVENIO);
				
				AuditLog audit 		= new AuditLog(0, loginUsuario, ipUsuario, dtIni, Constantes.HORA_ATUAL(), Constantes.COD_CADASTRO_CONVENIO);
				
				new AuditLogDAO().incluiRegistro(audit);
				
				pReq.setAttribute("Msg", "Convnio cadastrado com sucesso");
				
				session.setAttribute(Constantes.ATRIB_DT_INI_CAD_CONVENIO, Constantes.HORA_ATUAL());
				
			} else {
				
				pReq.setAttribute("Msg", "Problemas ao cadastrar o convnio");
			}
			
			ativarPagina(pReq, pResp, "/cadastroConvenio.jsp");
		}
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoSalvarAlteracao(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {
		
		Vector<String> tErro		= new Vector<String>();

		String codDigitado 			= pReq.getParameter("codigo");
		String nomeDigitado 		= pReq.getParameter("nome");
		String cepDigitado			= pReq.getParameter("cep");
		String enderecoDigitado		= pReq.getParameter("rua");
		String numEnderecoDigitado	= pReq.getParameter("numEndereco");
		String bairroDigitado		= pReq.getParameter("bairro");
		String cidadeDigitado		= pReq.getParameter("cidade");
		String ufDigitado			= pReq.getParameter("uf");
		String complementoDigitado	= pReq.getParameter("complemento");
		String contato1Digitado 	= pReq.getParameter("contato1");
		String contato2Digitado 	= pReq.getParameter("contato2");
		String setor1Digitado 		= pReq.getParameter("setor1");
		String setor2Digitado	 	= pReq.getParameter("setor2");
		String fone1Digitado		= pReq.getParameter("fone1");
		String fone2Digitado		= pReq.getParameter("fone2");
		String email1Digitado 		= pReq.getParameter("email1");
		String email2Digitado	 	= pReq.getParameter("email2");
		String valorConsultaDigitado= pReq.getParameter("valorConsulta").replace(',', '.').replace("R$ ", "");
		String solicitarDigitado	= pReq.getParameter("solicitarSenha");
		
		double valorConsultaNum		= 0.0;
		
		int codigo					= 0;
		
		if(nomeDigitado == null || nomeDigitado.equals(""))
			tErro.add("O campo nome deve ser preenchido!");
		
		if(valorConsultaDigitado == null || valorConsultaDigitado.equals(""))
			tErro.add("O campo valor da consulta deve ser preenchido!");
		
		try{
			valorConsultaNum = Double.parseDouble(valorConsultaDigitado);
		} catch (NumberFormatException e) {
			tErro.add("O campo valor da consulta est com formato incorreto!");
		}
		
		if(solicitarDigitado == null || solicitarDigitado.equals("")){
			solicitarDigitado = "n";
		}
		
		try{			
			codigo = Integer.parseInt(codDigitado);
		}catch (NumberFormatException e) {
			codigo = 0;
		}
		
		if(tErro.size() > 0){
			mostrarErro(pReq, pResp, tErro, "/visualizacaoConvenio.jsp");
			
		} else {
			
			Convenio convenio = new Convenio(
				codigo,
				valorConsultaNum,
				nomeDigitado,
				cepDigitado,
				enderecoDigitado,
				numEnderecoDigitado,
				complementoDigitado,
				bairroDigitado,
				cidadeDigitado,
				ufDigitado,
				contato1Digitado,
				contato2Digitado,
				setor1Digitado,
				setor2Digitado,
				fone1Digitado,
				fone2Digitado,
				email1Digitado,
				email2Digitado,
				solicitarDigitado.equals("s")
			);
			
			if(new ConvenioDAO().alteraConvenio(convenio)){
				
				String loginUsuario = (String) session.getAttribute(Constantes.ATRIB_USUARIO_LOGADO);
				String ipUsuario 	= (String) session.getAttribute(Constantes.ATRIB_IP_LOGADO);
				String dtIni 		= (String) session.getAttribute(Constantes.ATRIB_DT_INI_ALT_CONVENIO);
				
				AuditLog audit 		= new AuditLog(0, loginUsuario, ipUsuario, dtIni, Constantes.HORA_ATUAL(), Constantes.COD_ALTERACAO_CONVENIO);
				
				new AuditLogDAO().incluiRegistro(audit);
				
				pReq.setAttribute("Msg", "Convnio alterado com sucesso");
				
			} else {
				
				pReq.setAttribute("Msg", "Problemas ao alterar o convnio");
			}
			
			ativarPagina(pReq, pResp, "/consultaConvenio.jsp");
		}
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoExclusaoConfirmada(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {
		
		String codDigitado 	= pReq.getParameter("codConvenio");
			
		int codigo			= 0;
		
		try{			
			codigo = Integer.parseInt(codDigitado);
		}catch (NumberFormatException e) {
			codigo = 0;
		}
			
		if(new ConvenioDAO().excluiConvenio(codigo)){
			
			String loginUsuario = (String) session.getAttribute(Constantes.ATRIB_USUARIO_LOGADO);
			String ipUsuario 	= (String) session.getAttribute(Constantes.ATRIB_IP_LOGADO);
			String dtIni 		= (String) session.getAttribute(Constantes.ATRIB_DT_INI_EXC_CONVENIO);
			
			AuditLog audit 		= new AuditLog(0, loginUsuario, ipUsuario, dtIni, Constantes.HORA_ATUAL(), Constantes.COD_EXCLUSAO_CONVENIO);
			
			new AuditLogDAO().incluiRegistro(audit);
			
			pReq.setAttribute("Msg", "Convnio excludo com sucesso");
			
		} else {
			
			pReq.setAttribute("Msg", "Problemas ao excluir o convnio");
		}
		
		ativarPagina(pReq, pResp, "/consultaConvenio.jsp");
		
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoProcurarEndereco(HttpServletRequest pReq, HttpServletResponse pResp) throws ServletException, IOException {
		
		Vector<String> tErro = new Vector<String>();

		String nomeDigitado 		= pReq.getParameter("nome");
		String cepDigitado 			= pReq.getParameter("cep");
		String numEnderecoDigitado	= pReq.getParameter("numEndereco");
		String complementoDigitado	= pReq.getParameter("complemento");
		String contato1Digitado 	= pReq.getParameter("contato1");
		String contato2Digitado 	= pReq.getParameter("contato2");
		String setor1Digitado		= pReq.getParameter("setor1");
		String setor2Digitado		= pReq.getParameter("setor2");
		String ddd1Digitado 		= pReq.getParameter("ddd1");
		String ddd2Digitado 		= pReq.getParameter("ddd2");
		String fone1Digitado 		= pReq.getParameter("fone1");
		String fone2Digitado 		= pReq.getParameter("fone2");
		String email1Digitado 		= pReq.getParameter("email1");
		String email2Digitado 		= pReq.getParameter("email2");
		String valorDigitado	 	= pReq.getParameter("valorConsulta");
		String solicitSenhaDigitado = pReq.getParameter("solicitarSenha");
		
		boolean eCadastro			= pReq.getParameter("eCadastro").equals("sim");
		
		Endereco endereco;
		
		if(cepDigitado == null || cepDigitado.equals("")){
			
			tErro.add("Digite o nmero do CEP!");
		
		} else {
			
			ControlePrincipal controle 	= new ControlePrincipal();
			
			GerenteConsultaEndereco.enderecoPorCep(controle, cepDigitado.replace("-", ""));
			
			try{
			
				endereco = controle.getEnderecos().get(0);
				
				pReq.setAttribute("Logradouro"	, endereco.getTipoLogradouro().trim() + " " + endereco.getNomeLogradouro().trim());
				pReq.setAttribute("Bairro"		, endereco.getNomeBairro().trim());
				pReq.setAttribute("Cidade"		, endereco.getNomeCidade().trim());
				pReq.setAttribute("UF"			, endereco.getNomeUF());
				
				
			}catch (ArrayIndexOutOfBoundsException e) {
				
				pReq.setAttribute("Msg", "<font color='red'>No existe nenhum endereo para o CEP informado</font>");
			}
			
			//-------------------------------- Dados j digitados ----------------------------//
			
			pReq.setAttribute("Nome"			, nomeDigitado);
			pReq.setAttribute("CEP"				, cepDigitado);
			pReq.setAttribute("NumEndereco"		, numEnderecoDigitado);
			pReq.setAttribute("Complemento"		, complementoDigitado);
			pReq.setAttribute("Contato1"		, contato1Digitado);
			pReq.setAttribute("Contato2"		, contato2Digitado);
			pReq.setAttribute("Setor1"			, setor1Digitado);
			pReq.setAttribute("Setor2"			, setor2Digitado);
			pReq.setAttribute("DDD1"			, ddd1Digitado);
			pReq.setAttribute("DDD2"			, ddd2Digitado);
			pReq.setAttribute("Fone1"			, fone1Digitado);
			pReq.setAttribute("Fone2"			, fone2Digitado);
			pReq.setAttribute("Email1"			, email1Digitado);
			pReq.setAttribute("Email2"			, email2Digitado);
			pReq.setAttribute("ValorConsulta"	, valorDigitado);
			pReq.setAttribute("SolicitarSenha"	, solicitSenhaDigitado);

			//--------------------------------------------------------------------------------//
		}
		
		if(tErro.size() > 0){
			
			if(eCadastro)
				mostrarErro(pReq, pResp, tErro, "/cadastroConvenio.jsp");
			else
				mostrarErro(pReq, pResp, tErro, "/visualizacaoConvenio.jsp");
			
		} else {

			if(eCadastro)
				ativarPagina(pReq, pResp, "/cadastroConvenio.jsp");
			else
				ativarPagina(pReq, pResp, "/visualizacaoConvenio.jsp");
		}
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoPesquisarConvenio(HttpServletRequest pReq, HttpServletResponse pResp) throws ServletException, IOException {
		
		ControlePrincipal controle = new ControlePrincipal();
		
		Vector<Convenio> convenios;
		
		String nome = pReq.getParameter("nome");
		pReq.setAttribute("Nome", nome);

		if(GerenteConsultaConvenio.convenioPorNome(controle, nome)){
			
			convenios = controle.getConvenios();
			
			pReq.setAttribute("Convenios", convenios);
		
		} else {
			
			pReq.setAttribute("Msg", "Problemas ao realizar consulta de convnios");
		}


		ativarPagina(pReq, pResp, "/consultaConvenio.jsp");
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoExibirConvenio(HttpServletRequest pReq, HttpServletResponse pResp) throws ServletException, IOException {

		ControlePrincipal controle	= new ControlePrincipal();

		Convenio convenio			= null;

		int codConvenio				= 0;

		try{
			codConvenio				= Integer.parseInt(pReq.getParameter("codConvenio"));
		}catch (NumberFormatException e) {
			codConvenio				= 0;
		}

		if(GerenteConsultaConvenio.convenioPorCodigo(controle, codConvenio)){

			convenio = controle.getConvenios().get(0);

			pReq.setAttribute("CodConvenio"		, String.valueOf(convenio.getIdConvenio()));
			pReq.setAttribute("Nome"			, convenio.getNomeConvenio());
			pReq.setAttribute("CEP"				, convenio.getCepConvenio());
			pReq.setAttribute("Logradouro"		, convenio.getLogradouroConvenio());
			pReq.setAttribute("NumEndereco"		, convenio.getNumLogradouroConvenio());
			pReq.setAttribute("Complemento"		, convenio.getComplementoConvenio());
			pReq.setAttribute("Bairro"			, convenio.getBairroConvenio());
			pReq.setAttribute("Cidade"			, convenio.getCidadeConvenio());
			pReq.setAttribute("UF"				, convenio.getUfConvenio());
			pReq.setAttribute("Contato1"		, convenio.getContato1Convenio());
			pReq.setAttribute("Contato2"		, convenio.getContato2Convenio());
			pReq.setAttribute("Setor1"			, convenio.getSetorContato1Convenio());
			pReq.setAttribute("Setor2"			, convenio.getSetorContato2Convenio());
			pReq.setAttribute("Fone1"			, convenio.getTelefone1Convenio());
			pReq.setAttribute("Fone2"			, convenio.getTelefone2Convenio());
			pReq.setAttribute("Email1"			, convenio.getEmail1Convenio());
			pReq.setAttribute("Email2"			, convenio.getEmail2Convenio());
			pReq.setAttribute("ValorConsulta"	, String.valueOf(convenio.getValorConsultaConvenio()));
			pReq.setAttribute("SolicitarSenha"	, convenio.isSolicitarSenhaConvenio() ? "S" : "N");
		
		} else {
			
			pReq.setAttribute("Msg"				, "Problemas ao carregar os dados do convnio");
		}
			
		ativarPagina(pReq, pResp, "/visualizacaoConvenio.jsp");
	}
	
}