package br.ufpr.mityba.servlets;

import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Vector;

import javax.servlet.RequestDispatcher;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import br.ufpr.mityba.controller.GerenteConsultaAlimento;
import br.ufpr.mityba.controller.GerenteConsultaDiarioAlimentacao;
import br.ufpr.mityba.controller.GerenteConsultaGrupoAlimenticio;
import br.ufpr.mityba.dao.DiarioAlimentacaoPacienteDAO;
import br.ufpr.mityba.model.DiarioAlimentacaoPaciente;
import br.ufpr.mityba.util.Constantes;
import br.ufpr.mityba.util.ControlePrincipal;

/**
 * Servlet implementation class ServletDiarioAlimentacao
 * 
 * @author Mityba
 * @since 08/12/2008
 * @version 1.0 08/12/2008
 */
public class ServletDiarioAlimentacao extends HttpServlet {

	static final long serialVersionUID = 1322132L;

	/**
	 * @param pReq 
	 * @param pResp 
	 * @throws ServletException 
	 * @throws IOException 
	 * 
	 */
	public void service(final HttpServletRequest pReq, final HttpServletResponse pResp) throws ServletException, IOException {

		Vector<String> tErro = new Vector<String>();

		HttpSession session = pReq.getSession(false);

		String service = pReq.getParameter("service");

		if (session == null) {

			tErro.add("Voc deve efetuar o login antes de acessar essa funcionalidade!");

		} else {

			if (service == null || service.equals("")) {

				tErro.add("Informar a ao a ser executada\n");

			} else if (service.equals("diario")) {
				
				acaoDiarioAlimentacao(pReq, pResp, session);

			} else if (service.equals("mudaGrupo")) {
				
				acaoMudaGrupo(pReq, pResp, session);

			} else if (service.equals("adicionarAlimento")) {
				
				acaoAdicionarAlimento(pReq, pResp, session);

			} else if (service.equals("removerAlimento")) {
				
				acaoRemoverAlimento(pReq, pResp, session);
			}
		}

		if (tErro.size() > 0) {
			mostrarErro(pReq, pResp, tErro, "/user_home.jsp");
		}
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param pErro
	 * @param pPag
	 * @throws ServletException
	 * @throws IOException
	 */

	private void mostrarErro(HttpServletRequest pReq, HttpServletResponse pResp, Vector<String> pErro, String pPag) throws ServletException, IOException {
		pReq.setAttribute("Erros", pErro);
		ativarPagina(pReq, pResp, pPag);
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param pPagina
	 * @throws ServletException
	 * @throws IOException
	 */

	private void ativarPagina(HttpServletRequest pReq, HttpServletResponse pResp, String pPagina) throws ServletException, IOException {
		ServletContext tContexto 		= getServletContext();
		RequestDispatcher tDespachante 	= tContexto.getRequestDispatcher(pPagina);
		tDespachante.forward(pReq, pResp);
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */

	private void acaoDiarioAlimentacao(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {
		
		ControlePrincipal controle = new ControlePrincipal();
		
		int idUsuario 	= (Integer) session.getAttribute(Constantes.ATRIB_ID_USUARIO_LOGADO);
		
		String data		= new SimpleDateFormat("dd/MM/yyyy").format(new Date());
		String refeicao	= "";
		
		GerenteConsultaGrupoAlimenticio.todosGrupos(controle);
		GerenteConsultaDiarioAlimentacao.diarioPorPacienteEData(controle, idUsuario, data);
		
		Vector<DiarioAlimentacaoPaciente> diario 	= controle.getDiariosAlimentacao();
		Vector<String> descricaoDiario				= new Vector<String>();
		Vector<Integer> idsDiario					= new Vector<Integer>();
		
		for(int i = 0; i < diario.size(); i++){
			
			idsDiario.add(diario.get(i).getIdDiarioAlimentacaoPaciente());
			
			GerenteConsultaAlimento.alimentoPorCodigo(controle, diario.get(i).getIdAlimentoDiarioAlimentacaoPaciente());
			
			if(diario.get(i).getRefeicaoDiarioAlimentacaoPaciente() == Constantes.REFEICAO_ALMOCO){
				refeicao = "Almoo - ";
			} else if(diario.get(i).getRefeicaoDiarioAlimentacaoPaciente() == Constantes.REFEICAO_DESJEJUM){
				refeicao = "Desjejum - ";
			} else if(diario.get(i).getRefeicaoDiarioAlimentacaoPaciente() == Constantes.REFEICAO_JANTAR){
				refeicao = "Jantar - ";
			} else if(diario.get(i).getRefeicaoDiarioAlimentacaoPaciente() == Constantes.REFEICAO_LANCHE){
				refeicao = "Lanche - ";
			}
			
			descricaoDiario.add(refeicao + controle.getAlimentos().get(0).getNomeAlimento());
		}

		pReq.setAttribute("Data"			, data);
		pReq.setAttribute("IdsDiarios"		, idsDiario);
		pReq.setAttribute("DescricaoDiarios", descricaoDiario);
		pReq.setAttribute("Grupos"			, controle.getGruposAlimenticios());
		
		ativarPagina(pReq, pResp, "/user_diario.jsp");
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */

	private void acaoMudaGrupo(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {
		
		ControlePrincipal controle = new ControlePrincipal();
		
		int idUsuario 	= (Integer) session.getAttribute(Constantes.ATRIB_ID_USUARIO_LOGADO);
		int grupo		= Integer.parseInt(pReq.getParameter("grupo"));
		
		String data		= pReq.getParameter("data");
		String refeicao	= "";
		
		GerenteConsultaGrupoAlimenticio.todosGrupos				(controle);
		GerenteConsultaAlimento.alimentoPorGrupo				(controle, grupo);
		GerenteConsultaDiarioAlimentacao.diarioPorPacienteEData	(controle, idUsuario, data);
		
		Vector<DiarioAlimentacaoPaciente> diario 	= controle.getDiariosAlimentacao();
		Vector<String> descricaoDiario				= new Vector<String>();
		Vector<Integer> idsDiario					= new Vector<Integer>();
		
		for(int i = 0; i < diario.size(); i++){
			
			idsDiario.add(diario.get(i).getIdDiarioAlimentacaoPaciente());
			
			GerenteConsultaAlimento.alimentoPorCodigo(controle, diario.get(i).getIdAlimentoDiarioAlimentacaoPaciente());

			if(diario.get(i).getRefeicaoDiarioAlimentacaoPaciente() == Constantes.REFEICAO_ALMOCO){
				refeicao = "Almoo - ";
			} else if(diario.get(i).getRefeicaoDiarioAlimentacaoPaciente() == Constantes.REFEICAO_DESJEJUM){
				refeicao = "Desjejum - ";
			} else if(diario.get(i).getRefeicaoDiarioAlimentacaoPaciente() == Constantes.REFEICAO_JANTAR){
				refeicao = "Jantar - ";
			} else if(diario.get(i).getRefeicaoDiarioAlimentacaoPaciente() == Constantes.REFEICAO_LANCHE){
				refeicao = "Lanche - ";
			}

			descricaoDiario.add(refeicao + controle.getAlimentos().get(0).getNomeAlimento());
		}
		
		pReq.setAttribute("Data"			, data);		
		pReq.setAttribute("IdsDiarios"		, idsDiario);
		pReq.setAttribute("DescricaoDiarios", descricaoDiario);
		pReq.setAttribute("Grupos"			, controle.getGruposAlimenticios());
		pReq.setAttribute("Grupo"			, String.valueOf(grupo));
		pReq.setAttribute("Alimentos"		, controle.getAlimentos());
		
		ativarPagina(pReq, pResp, "/user_diario.jsp");
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */

	private void acaoAdicionarAlimento(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {
		
		ControlePrincipal controle = new ControlePrincipal();
		
		int idUsuario 	= (Integer) session.getAttribute(Constantes.ATRIB_ID_USUARIO_LOGADO);
		int grupo		= Integer.parseInt(pReq.getParameter("grupo"));
		int alimento	= Integer.parseInt(pReq.getParameter("alimento"));
		int refeicao	= Integer.parseInt(pReq.getParameter("refeicao"));
		
		String data		= pReq.getParameter("data");
		String descrRef	= "";
		
		DiarioAlimentacaoPaciente diarioAlimentacao = new DiarioAlimentacaoPaciente(
			0,
			idUsuario,
			alimento,
			0,
			refeicao,
			data
		);
		
		new DiarioAlimentacaoPacienteDAO().incluiDiarioAlimentacao(diarioAlimentacao);
		
		GerenteConsultaGrupoAlimenticio.todosGrupos				(controle);
		GerenteConsultaAlimento.alimentoPorGrupo				(controle, grupo);
		GerenteConsultaDiarioAlimentacao.diarioPorPacienteEData	(controle, idUsuario, data);
		
		Vector<DiarioAlimentacaoPaciente> diario 	= controle.getDiariosAlimentacao();
		Vector<String> descricaoDiario				= new Vector<String>();
		Vector<Integer> idsDiario					= new Vector<Integer>();
		
		for(int i = 0; i < diario.size(); i++){
			
			idsDiario.add(diario.get(i).getIdDiarioAlimentacaoPaciente());
			
			GerenteConsultaAlimento.alimentoPorCodigo(controle, diario.get(i).getIdAlimentoDiarioAlimentacaoPaciente());
			
			if(diario.get(i).getRefeicaoDiarioAlimentacaoPaciente() == Constantes.REFEICAO_ALMOCO){
				descrRef = "Almoo - ";
			} else if(diario.get(i).getRefeicaoDiarioAlimentacaoPaciente() == Constantes.REFEICAO_DESJEJUM){
				descrRef = "Desjejum - ";
			} else if(diario.get(i).getRefeicaoDiarioAlimentacaoPaciente() == Constantes.REFEICAO_JANTAR){
				descrRef = "Jantar - ";
			} else if(diario.get(i).getRefeicaoDiarioAlimentacaoPaciente() == Constantes.REFEICAO_LANCHE){
				descrRef = "Lanche - ";
			}
			
			descricaoDiario.add(descrRef + controle.getAlimentos().get(0).getNomeAlimento());
		}

		pReq.setAttribute("Data"			, data);
		pReq.setAttribute("IdsDiarios"		, idsDiario);
		pReq.setAttribute("DescricaoDiarios", descricaoDiario);
		pReq.setAttribute("Grupos"			, controle.getGruposAlimenticios());
		pReq.setAttribute("Grupo"			, String.valueOf(grupo));
		pReq.setAttribute("Alimentos"		, controle.getAlimentos());
		
		ativarPagina(pReq, pResp, "/user_diario.jsp");
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */

	private void acaoRemoverAlimento(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {
		
		ControlePrincipal controle = new ControlePrincipal();
		
		int idUsuario 	= (Integer) session.getAttribute(Constantes.ATRIB_ID_USUARIO_LOGADO);
		int grupo		= Integer.parseInt(pReq.getParameter("grupo"));
		int idDiario	= Integer.parseInt(pReq.getParameter("diario"));
		
		String data		= pReq.getParameter("data");
		String refeicao	= "";
		
		new DiarioAlimentacaoPacienteDAO().excluiDiarioAlimentacao(idDiario);
		
		GerenteConsultaGrupoAlimenticio.todosGrupos				(controle);
		GerenteConsultaAlimento.alimentoPorGrupo				(controle, grupo);
		GerenteConsultaDiarioAlimentacao.diarioPorPacienteEData	(controle, idUsuario, data);
		
		Vector<DiarioAlimentacaoPaciente> diario 	= controle.getDiariosAlimentacao();
		Vector<String> descricaoDiario				= new Vector<String>();
		Vector<Integer> idsDiario					= new Vector<Integer>();
		
		for(int i = 0; i < diario.size(); i++){
			
			idsDiario.add(diario.get(i).getIdDiarioAlimentacaoPaciente());
			
			GerenteConsultaAlimento.alimentoPorCodigo(controle, diario.get(i).getIdAlimentoDiarioAlimentacaoPaciente());
			
			if(diario.get(i).getRefeicaoDiarioAlimentacaoPaciente() == Constantes.REFEICAO_ALMOCO){
				refeicao = "Almoo - ";
			} else if(diario.get(i).getRefeicaoDiarioAlimentacaoPaciente() == Constantes.REFEICAO_DESJEJUM){
				refeicao = "Desjejum - ";
			} else if(diario.get(i).getRefeicaoDiarioAlimentacaoPaciente() == Constantes.REFEICAO_JANTAR){
				refeicao = "Jantar - ";
			} else if(diario.get(i).getRefeicaoDiarioAlimentacaoPaciente() == Constantes.REFEICAO_LANCHE){
				refeicao = "Lanche - ";
			}
			
			descricaoDiario.add(refeicao + controle.getAlimentos().get(0).getNomeAlimento());
		}
		
		pReq.setAttribute("Data"			, data);
		pReq.setAttribute("IdsDiarios"		, idsDiario);
		pReq.setAttribute("DescricaoDiarios", descricaoDiario);
		pReq.setAttribute("Grupos"			, controle.getGruposAlimenticios());
		pReq.setAttribute("Grupo"			, String.valueOf(grupo));
		pReq.setAttribute("Alimentos"		, controle.getAlimentos());
		
		ativarPagina(pReq, pResp, "/user_diario.jsp");
	}
}