package br.ufpr.mityba.servlets;

import java.io.IOException;
import java.util.Vector;

import javax.servlet.RequestDispatcher;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import br.ufpr.mityba.controller.GerenteConsultaDietaApoio;
import br.ufpr.mityba.dao.AuditLogDAO;
import br.ufpr.mityba.dao.DietaApoioDAO;
import br.ufpr.mityba.model.AuditLog;
import br.ufpr.mityba.model.DietaApoio;
import br.ufpr.mityba.util.Constantes;
import br.ufpr.mityba.util.ControlePrincipal;

/**
 * Servlet implementation class ServletDietaApoio
 * 
 * @author Mityba
 * @since 23/11/2008
 * @version 1.0 23/11/2008
 */
public class ServletDietaApoio extends HttpServlet {

	static final long serialVersionUID = 1322132L;

	/**
	 * @param pReq 
	 * @param pResp 
	 * @throws ServletException 
	 * @throws IOException 
	 * 
	 */
	public void service(final HttpServletRequest pReq, final HttpServletResponse pResp) throws ServletException, IOException {

		Vector<String> tErro = new Vector<String>();

		HttpSession session = pReq.getSession(false);

		String service = pReq.getParameter("service");

		if (session == null) {

			tErro.add("Voc deve efetuar o login antes de acessar essa funcionalidade!");

		} else {

			if (service == null || service.equals("")) {

				tErro.add("Informar a ao a ser executada\n");

			} else if (service.equals("cadastroDietasApoio")) {
				
				if((Integer) session.getAttribute(Constantes.ATRIB_ACESSO_CADASTRO) == 3){

					session.setAttribute(Constantes.ATRIB_DT_INI_CAD_DIETA_APOIO, Constantes.HORA_ATUAL());
	
					ativarPagina(pReq, pResp, "/cadastroDietaApoio.jsp");

				} else {
					
					tErro.add("Voc no tem o nvel de privilgio necessrio para acessar essa funcionalidade");
				}
				
			} else if (service.equals("pesquisarDietasApoio")) {
				
				if((Integer) session.getAttribute(Constantes.ATRIB_ACESSO_CADASTRO) >= 2){
				
					ativarPagina(pReq, pResp, "/consultaDietaApoio.jsp");
				
				} else {
					
					tErro.add("Voc no tem o nvel de privilgio necessrio para acessar essa funcionalidade");
				}
				
			} else if (service.equals("pesquisaPorTitulo")) {
				
				acaoPesquisarDietaApoio(pReq, pResp);
				
			} else if (service.equals("salvarCadastro")) {
				
				acaoSalvarCadastro(pReq, pResp, session);
				
			} else if (service.equals("salvarAlteracao")) {
				
				acaoSalvarAlteracao(pReq, pResp, session);
				
			} else if (service.equals("excluir")) {
				
				acaoExclusaoConfirmada(pReq, pResp, session);
				
			} else if (service.equals("exibirDietaApoio")) {
				
				if((Integer) session.getAttribute(Constantes.ATRIB_ACESSO_CADASTRO) == 3){
				
					acaoExibirDietaApoio(pReq, pResp, session);
				
				} else {
					
					tErro.add("Voc no tem o nvel de privilgio necessrio para acessar essa funcionalidade");
				}
				
			} else if (service.equals("excluir")) {
				
				acaoExclusaoConfirmada(pReq, pResp, session);
				
			} else if (service.equals("imprimirDieta")) {
				
				acaoImprimirDietas(pReq, pResp, session);
	
			} else if (service.equals("voltarTelaConsulta")) {
				
				ativarPagina(pReq, pResp, "/consultaDietaApoio.jsp");

			} else if (service.equals("voltaTela")) {

				ativarPagina(pReq, pResp, "/PaginaInicial.jsp");
			}
		}

		if (tErro.size() > 0) {
			mostrarErro(pReq, pResp, tErro, "/PaginaInicial.jsp");
		}
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param pErro
	 * @param pPag
	 * @throws ServletException
	 * @throws IOException
	 */

	private void mostrarErro(HttpServletRequest pReq, HttpServletResponse pResp, Vector<String> pErro, String pPag) throws ServletException, IOException {
		pReq.setAttribute("Erros", pErro);
		ativarPagina(pReq, pResp, pPag);
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param pPagina
	 * @throws ServletException
	 * @throws IOException
	 */

	private void ativarPagina(HttpServletRequest pReq, HttpServletResponse pResp, String pPagina) throws ServletException, IOException {
		ServletContext tContexto 		= getServletContext();
		RequestDispatcher tDespachante 	= tContexto.getRequestDispatcher(pPagina);
		tDespachante.forward(pReq, pResp);
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoSalvarCadastro(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {
		
		Vector<String> tErro				= new Vector<String>();
		
		String tituloDigitado 				= pReq.getParameter("titulo");
		String descricaoDigitado			= pReq.getParameter("descricao");

		if(tituloDigitado == null || tituloDigitado.equals(""))
			tErro.add("O campo ttulo deve ser preenchido!");
		
		if(descricaoDigitado == null || descricaoDigitado.equals(""))
			tErro.add("O campo descrio deve ser preenchido!");
		
		if(tErro.size() > 0){
			mostrarErro(pReq, pResp, tErro, "/cadastroDietaApoio.jsp");
			
		} else {
			
			DietaApoio dieta = new DietaApoio(
					0,
					tituloDigitado,
					descricaoDigitado
			);
			
			if(new DietaApoioDAO().incluiDietaApoio(dieta)){

				String loginUsuario = (String) session.getAttribute(Constantes.ATRIB_USUARIO_LOGADO);
				String ipUsuario 	= (String) session.getAttribute(Constantes.ATRIB_IP_LOGADO);
				String dtIni 		= (String) session.getAttribute(Constantes.ATRIB_DT_INI_CAD_DIETA_APOIO);
				
				AuditLog audit 		= new AuditLog(0, loginUsuario, ipUsuario, dtIni, Constantes.HORA_ATUAL(), Constantes.COD_CADASTRO_DIETA_APOIO);
				
				new AuditLogDAO().incluiRegistro(audit);
				
				pReq.setAttribute("Msg", "Dieta de apoio cadastrada com sucesso");
				
				session.setAttribute(Constantes.COD_CADASTRO_DIETA_APOIO, Constantes.HORA_ATUAL());
				
			} else {
				
				pReq.setAttribute("Msg", "Problemas ao cadastrar a dieta de apoio");
			}
			
			ativarPagina(pReq, pResp, "/cadastroDietaApoio.jsp");
		}
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoSalvarAlteracao(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {
		
		Vector<String> tErro				= new Vector<String>();

		int codigoDigitado					= 0;
		String tituloDigitado 				= pReq.getParameter("titulo");
		String descricaoDigitado			= pReq.getParameter("descricao");

		try{
			codigoDigitado = Integer.parseInt(pReq.getParameter("codDietaApoio"));
		}catch (NumberFormatException e) {
			codigoDigitado = 0;
		}
		
		if(tituloDigitado == null || tituloDigitado.equals(""))
			tErro.add("O campo ttulo deve ser preenchido!");
		
		if(descricaoDigitado == null || descricaoDigitado.equals(""))
			tErro.add("O campo descrio deve ser preenchido!");
		
		if(tErro.size() > 0){
			mostrarErro(pReq, pResp, tErro, "/visualizacaoDietaApoio.jsp");
			
		} else {
			
			DietaApoio dieta = new DietaApoio(
					codigoDigitado,
					tituloDigitado,
					descricaoDigitado
			);
			
			if(new DietaApoioDAO().alteraDietaApoio(dieta)){
											
				String loginUsuario = (String) session.getAttribute(Constantes.ATRIB_USUARIO_LOGADO);
				String ipUsuario 	= (String) session.getAttribute(Constantes.ATRIB_IP_LOGADO);
				String dtIni 		= (String) session.getAttribute(Constantes.ATRIB_DT_INI_ALT_DIETA_APOIO);
				
				AuditLog audit 		= new AuditLog(0, loginUsuario, ipUsuario, dtIni, Constantes.HORA_ATUAL(), Constantes.COD_ALTERACAO_DIETA_APOIO);
				
				new AuditLogDAO().incluiRegistro(audit);
				
				pReq.setAttribute("Msg", "Dieta de apoio alterada com sucesso");				
				
			} else {
				
				pReq.setAttribute("Msg", "Problemas ao alterar a dieta de apoio");
			}
			
			ativarPagina(pReq, pResp, "/consultaDietaApoio.jsp");
		}
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoPesquisarDietaApoio(HttpServletRequest pReq, HttpServletResponse pResp) throws ServletException, IOException {
		
		ControlePrincipal controle = new ControlePrincipal();
		
		String titulo = pReq.getParameter("titulo");
		
		if(GerenteConsultaDietaApoio.dietasApoioPorTitulo(controle, titulo)){
			pReq.setAttribute("DietasApoio", controle.getDietasApoio());
		} else {
			pReq.setAttribute("Msg", "Problemas na consulta de dietas");
		}

		ativarPagina(pReq, pResp, "/consultaDietaApoio.jsp");
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoExibirDietaApoio(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {

		session.setAttribute(Constantes.ATRIB_DT_INI_ALT_DIETA_APOIO, Constantes.HORA_ATUAL());
		session.setAttribute(Constantes.ATRIB_DT_INI_EXC_DIETA_APOIO, Constantes.HORA_ATUAL());
		
		ControlePrincipal controle	= new ControlePrincipal();

		DietaApoio dieta			= null;

		int codDietaApoio			= 0;

		try{
			codDietaApoio			= Integer.parseInt(pReq.getParameter("codDietaApoio"));
		}catch (NumberFormatException e) {
			codDietaApoio			= 0;
		}

		if(GerenteConsultaDietaApoio.dietasApoioPorCodigo(controle, codDietaApoio)){

			dieta = controle.getDietasApoio().get(0);

			pReq.setAttribute("CodDietaApoio"	, String.valueOf(dieta.getIdDietaApoio()));
			pReq.setAttribute("Titulo"			, dieta.getTituloDietaApoio());
			pReq.setAttribute("Descricao"		, dieta.getDescrApoio());

		} else {
			
			pReq.setAttribute("Msg", "Problemas ao carregar os dados da dieta de apoio");
		}
			
		ativarPagina(pReq, pResp, "/visualizacaoDietaApoio.jsp");
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoExclusaoConfirmada(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {
		
		int codDietaApoio = Integer.parseInt(pReq.getParameter("codDietaApoio"));
		
		if(new DietaApoioDAO().excluiDietaApoio(codDietaApoio)){
			
			String loginUsuario = (String) session.getAttribute(Constantes.ATRIB_USUARIO_LOGADO);
			String ipUsuario 	= (String) session.getAttribute(Constantes.ATRIB_IP_LOGADO);
			String dtIni 		= (String) session.getAttribute(Constantes.ATRIB_DT_INI_EXC_DIETA_APOIO);
			
			AuditLog audit 		= new AuditLog(0, loginUsuario, ipUsuario, dtIni, Constantes.HORA_ATUAL(), Constantes.COD_EXCLUSAO_DIETA_APOIO);
			
			new AuditLogDAO().incluiRegistro(audit);
			
			pReq.setAttribute("Msg", "Dieta de apoio excluda com sucesso");		
			
		} else {
			
			pReq.setAttribute("Msg", "Problemas ao remover dieta de apoio");
		}
		
		ativarPagina(pReq, pResp, "/consultaDietaApoio.jsp");
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoImprimirDietas(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {
		
		ControlePrincipal controle = new ControlePrincipal();
		
		DietaApoio dieta = null;
		
		String[] dietas = pReq.getParameterValues("dieta");
		
		StringBuffer conteudo = new StringBuffer();
		
		for(int i = 0; i < dietas.length; i++){
			
			GerenteConsultaDietaApoio.dietasApoioPorCodigo(controle, Integer.parseInt(dietas[i]));
			dieta = controle.getDietasApoio().get(0);
			
			conteudo.append("Dieta de apoio: ")
				.append(dieta.getTituloDietaApoio())
				.append("<br><br>")
				.append(dieta.getDescrApoio())
				.append("<br><br><br><br>");
		}
		
		pReq.setAttribute("Conteudo", conteudo.toString());
		
		ativarPagina(pReq, pResp, "/impressaoDietas.jsp");
	}
}