package br.ufpr.mityba.servlets;

import java.io.IOException;
import java.util.Vector;

import javax.servlet.RequestDispatcher;
import javax.servlet.Servlet;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import br.ufpr.mityba.controller.GerenteConsultaExameCadastrado;
import br.ufpr.mityba.controller.GerenteConsultaUnidadeExame;
import br.ufpr.mityba.dao.AuditLogDAO;
import br.ufpr.mityba.dao.ExameCadastradoDAO;
import br.ufpr.mityba.dao.UnidadeExameDAO;
import br.ufpr.mityba.model.AuditLog;
import br.ufpr.mityba.model.ExameCadastrado;
import br.ufpr.mityba.model.UnidadeExame;
import br.ufpr.mityba.util.Constantes;
import br.ufpr.mityba.util.ControlePrincipal;


/**
 * Servlet implementation class for Servlet: ServletExame
 * 
 * @author Mityba
 * @since 16/10/2008
 * @version 1.0 16/10/2008
 * @version 1.1 28/11/2008
 */
public class ServletExame extends HttpServlet implements Servlet {

	static final long serialVersionUID = 484181L;


	/**
	 * @param pReq 
	 * @param pResp 
	 * @throws ServletException 
	 * @throws IOException 
	 * 
	 */
	public void service(HttpServletRequest pReq, HttpServletResponse pResp)	throws ServletException, IOException {

		Vector<String> tErro = new Vector<String>();
		
		HttpSession session = pReq.getSession(false);

		String service 		= pReq.getParameter("service");
		
		if (session == null){
			
			tErro.add("Voc deve efetuar o login antes de acessar essa funcionalidade!");
			
			mostrarErro(pReq, pResp, tErro, "/PaginaInicial.jsp");
			
		} else {

			if (service == null || service.equals("")) {
	
				tErro.add("Informar a ao a ser executada\n");
	
			} else if (service.equals("cadastroExames")) {
				
				if((Integer) session.getAttribute(Constantes.ATRIB_ACESSO_CADASTRO) == 3){
				
					acaoAtivarTelaCadastro(pReq, pResp, session);
				
				} else {
					
					tErro.add("Voc no tem o nvel de privilgio necessrio para acessar essa funcionalidade");
				}
				
			} else if (service.equals("pesquisarExames")) {
				
				if((Integer) session.getAttribute(Constantes.ATRIB_ACESSO_CADASTRO) >= 2){
				
					acaoAtivarTelaConsulta(pReq, pResp);
				
				} else {
					
					tErro.add("Voc no tem o nvel de privilgio necessrio para acessar essa funcionalidade");
				}
	
			} else if (service.equals("pesquisaPorNome")) {
				
				acaoPesquisarExame(pReq, pResp, true);
	
			} else if (service.equals("pesquisaPorUnidade")) {
				
				acaoPesquisarExame(pReq, pResp, false);
				
			} else if (service.equals("exibirExame")) {
				
				if((Integer) session.getAttribute(Constantes.ATRIB_ACESSO_CADASTRO) == 3){
				
					acaoExibirExame(pReq, pResp, session);
				
				} else {
					
					tErro.add("Voc no tem o nvel de privilgio necessrio para acessar essa funcionalidade");
				}
				
			} else if (service.equals("salvarCadastro")) {

				acaoCadastrarExame(pReq, pResp, session);
				
			} else if (service.equals("salvarAlteracao")) {

				acaoAlterarExame(pReq, pResp, session);
				
			} else if (service.equals("excluir")) {

				acaoExcluirExame(pReq, pResp, session);
				
			} else if (service.equals("salvarNovaUnidade")) {
				
				acaoNovaUnidade(pReq, pResp);
	
			} else if (service.equals("voltarConsultaExame")) {
				
				ControlePrincipal controle	= new ControlePrincipal();

				if(GerenteConsultaUnidadeExame.todasUnidadesExame(controle)){
					pReq.setAttribute("Unidades", controle.getUnidadesExame());
				}
				
				ativarPagina(pReq, pResp, "/consultaExame.jsp");
	
			} else if (service.equals("voltaTela")) {
				
				ativarPagina(pReq, pResp, "/PaginaInicial.jsp");
			
			} else {
				tErro.add("Ao inexistente para a pgina atual, favor verificar sintaxe!");
				mostrarErro(pReq, pResp, tErro, "/PaginaInicial.jsp");
			}
		}
		
		if (tErro.size() > 0){
			mostrarErro(pReq, pResp, tErro, "/PaginaInicial.jsp");			
		}
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param pErro
	 * @param pPag
	 * @throws ServletException
	 * @throws IOException
	 */

	private void mostrarErro(HttpServletRequest pReq, HttpServletResponse pResp, Vector<String> pErro, String pPag) throws ServletException, IOException {

		pReq.setAttribute("Erros", pErro);

		ativarPagina(pReq, pResp, pPag);
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param pPagina
	 * @throws ServletException
	 * @throws IOException
	 */

	private void ativarPagina(HttpServletRequest pReq, HttpServletResponse pResp, String pPagina) throws ServletException, IOException {

		ServletContext tContexto 		= getServletContext();
		RequestDispatcher tDespachante 	= tContexto.getRequestDispatcher(pPagina);
		tDespachante.forward(pReq, pResp);
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoAtivarTelaCadastro(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException{

		session.setAttribute(Constantes.ATRIB_DT_INI_CAD_EXAME, Constantes.HORA_ATUAL());
		
		ControlePrincipal controle	= new ControlePrincipal();

		if(GerenteConsultaUnidadeExame.todasUnidadesExame(controle)){
			pReq.setAttribute("Unidades", controle.getUnidadesExame());
		}
		
		ativarPagina(pReq, pResp, "/cadastroExame.jsp");
		
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoAtivarTelaConsulta(HttpServletRequest pReq, HttpServletResponse pResp) throws ServletException, IOException{
		
		ControlePrincipal controle	= new ControlePrincipal();

		if(GerenteConsultaUnidadeExame.todasUnidadesExame(controle)){
			pReq.setAttribute("Unidades", controle.getUnidadesExame());
		}
		
		ativarPagina(pReq, pResp, "/consultaExame.jsp");
		
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoCadastrarExame(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException{
				
		Vector<String> tErro= new Vector<String>();
		
		String nome			= pReq.getParameter("nome");
		String unidade		= pReq.getParameter("unidade");
		String minimo06		= pReq.getParameter("minimo0-6");
		String maximo06		= pReq.getParameter("maximo0-6");
		String minimo712	= pReq.getParameter("minimo7-12");
		String maximo712	= pReq.getParameter("maximo7-12");
		String minimo65		= pReq.getParameter("minimo65");
		String maximo65		= pReq.getParameter("maximo65");
		String minimoFem	= pReq.getParameter("minimoFem");
		String maximoFem	= pReq.getParameter("maximoFem");
		String minimoMas	= pReq.getParameter("minimoMas");
		String maximoMas	= pReq.getParameter("maximoMas");
		String minimoBaixo	= pReq.getParameter("minimoBaixo");
		String maximoBaixo	= pReq.getParameter("maximoBaixo");
		String minimoDesej	= pReq.getParameter("minimoDesejavel");
		String maximoDesej	= pReq.getParameter("maximoDesejavel");
		String minimoLimite	= pReq.getParameter("minimoLimite");
		String maximoLimite	= pReq.getParameter("maximoLimite");
		String minimoAlto	= pReq.getParameter("minimoAlto");
		String maximoAlto	= pReq.getParameter("maximoAlto");
		String minimoMtAlto	= pReq.getParameter("minimoMuitoAlto");
		String maximoMtAlto	= pReq.getParameter("maximoMuitoAlto");
		String obsAbaixo	= pReq.getParameter("abaixo");
		String obsAcima		= pReq.getParameter("acima");
		
		String[] opcoes		= pReq.getParameterValues("opcao");
		
		int numUnidade		= 0;
		
		//------------------------------------------- Validaes ------------------------------------------//

		if(nome == null || nome.equals(""))			
			tErro.add("O campo nome deve estar preenchido!");
		
		try{
			numUnidade = Integer.parseInt(unidade);
		}catch (NumberFormatException e) {
			numUnidade = 0;
		}
		
		if(opcoes == null || opcoes.length == 0){
			tErro.add("Nenhuma opo foi selecionada!");
			
		} else {
			
			for (int i = 0; i < opcoes.length; i++){
				
				if(opcoes[i].equals("06")){
					
					if(minimo06 == null || minimo06.equals("") || maximo06 == null || maximo06.equals(""))
						tErro.add("Os campos de mnimo e mximo de 0 a 6 anos devem estar preenchidos!");
									
				} else if(opcoes[i].equals("712")){
					
					if(minimo712 == null || minimo712.equals("") || maximo712 == null || maximo712.equals(""))
						tErro.add("Os campos de mnimo e mximo de 7 a 12 anos devem estar preenchidos!");
									
				} else if(opcoes[i].equals("65")){
					
					if(minimo65 == null || minimo65.equals("") || maximo65 == null || maximo65.equals(""))
						tErro.add("Os campos de mnimo e mximo de maiores de 65 anos devem estar preenchidos!");
									
				} else if(opcoes[i].equals("fem")){
					
					if(minimoFem == null || minimoFem.equals("") || maximoFem == null || maximoFem.equals(""))
						tErro.add("Os campos de mnimo e mximo da opo Feminino devem estar preenchidos!");
									
				} else if(opcoes[i].equals("mas")){
					
					if(minimoMas == null || minimoMas.equals("") || maximoMas == null || maximoMas.equals(""))
						tErro.add("Os campos de mnimo e mximo da opo Masculino devem estar preenchidos!");
									
				} else if(opcoes[i].equals("baixo")){
					
					if(minimoBaixo == null || minimoBaixo.equals("") || maximoBaixo == null || maximoBaixo.equals(""))
						tErro.add("Os campos de mnimo e mximo da opo Baixo devem estar preenchidos!");
	
				} else if(opcoes[i].equals("desejavel")){
					
					if(minimoDesej == null || minimoDesej.equals("") || maximoDesej == null || maximoDesej.equals(""))
						tErro.add("Os campos de mnimo e mximo da opo Desejvel devem estar preenchidos!");
									
				} else if(opcoes[i].equals("limite")){
					
					if(minimoLimite == null || minimoLimite.equals("") || maximoLimite == null || maximoLimite.equals(""))
						tErro.add("Os campos de mnimo e mximo da opo Limite devem estar preenchidos!");
									
				} else if(opcoes[i].equals("alto")){
					
					if(minimoAlto == null || minimoAlto.equals("") || maximoAlto == null || maximoAlto.equals(""))
						tErro.add("Os campos de mnimo e mximo da opo Alto devem estar preenchidos!");
									
				} else if(opcoes[i].equals("muitoAlto")){
					
					if(minimoMtAlto == null || minimoMtAlto.equals("") || maximoMtAlto == null || maximoMtAlto.equals(""))
						tErro.add("Os campos de mnimo e mximo da opo Muito Alto devem estar preenchidos!");
					
				}
			}
		}
		
		//------------------------------------------------------------------------------------------------//
		
		if(tErro.size() > 0)			
			mostrarErro(pReq, pResp, tErro, "/cadastroExame.jsp");
		
		else {
			
			ExameCadastrado exame = new ExameCadastrado(
				0, numUnidade, nome, minimo06, maximo06, minimo712, maximo712, minimo65, maximo65, minimoFem, maximoFem, minimoMas, maximoMas, 
				minimoBaixo, maximoBaixo, minimoDesej, maximoDesej, minimoLimite, maximoLimite, minimoAlto, maximoAlto, minimoMtAlto, 
				maximoMtAlto, obsAbaixo, obsAcima
			);
			
			if(new ExameCadastradoDAO().incluiExameCadastrado(exame)) {
				
				String loginUsuario = (String) session.getAttribute(Constantes.ATRIB_USUARIO_LOGADO);
				String ipUsuario 	= (String) session.getAttribute(Constantes.ATRIB_IP_LOGADO);
				String dtIni 		= (String) session.getAttribute(Constantes.ATRIB_DT_INI_CAD_EXAME);
				
				AuditLog audit 		= new AuditLog(0, loginUsuario, ipUsuario, dtIni, Constantes.HORA_ATUAL(), Constantes.COD_CADASTRO_EXAME);
				
				new AuditLogDAO().incluiRegistro(audit);
				
				pReq.setAttribute("Msg", "Exame cadastrado com sucesso!");
				
				session.setAttribute(Constantes.ATRIB_DT_INI_CAD_EXAME, Constantes.HORA_ATUAL());
			
			} else {
				
				pReq.setAttribute("Msg", "Problemas ao cadastrar o exame!");
			}
			
			ControlePrincipal controle	= new ControlePrincipal();

			if(GerenteConsultaUnidadeExame.todasUnidadesExame(controle)){
				pReq.setAttribute("Unidades", controle.getUnidadesExame());
			}

			ativarPagina(pReq, pResp, "/cadastroExame.jsp");
			
		}
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoAlterarExame(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException{
				
		Vector<String> tErro= new Vector<String>();

		int codigo			= Integer.parseInt(pReq.getParameter("codExame"));
		String nome			= pReq.getParameter("nome");
		String unidade		= pReq.getParameter("unidade");
		String minimo06		= pReq.getParameter("minimo0-6");
		String maximo06		= pReq.getParameter("maximo0-6");
		String minimo712	= pReq.getParameter("minimo7-12");
		String maximo712	= pReq.getParameter("maximo7-12");
		String minimo65		= pReq.getParameter("minimo65");
		String maximo65		= pReq.getParameter("maximo65");
		String minimoFem	= pReq.getParameter("minimoFem");
		String maximoFem	= pReq.getParameter("maximoFem");
		String minimoMas	= pReq.getParameter("minimoMas");
		String maximoMas	= pReq.getParameter("maximoMas");
		String minimoBaixo	= pReq.getParameter("minimoBaixo");
		String maximoBaixo	= pReq.getParameter("maximoBaixo");
		String minimoDesej	= pReq.getParameter("minimoDesejavel");
		String maximoDesej	= pReq.getParameter("maximoDesejavel");
		String minimoLimite	= pReq.getParameter("minimoLimite");
		String maximoLimite	= pReq.getParameter("maximoLimite");
		String minimoAlto	= pReq.getParameter("minimoAlto");
		String maximoAlto	= pReq.getParameter("maximoAlto");
		String minimoMtAlto	= pReq.getParameter("minimoMuitoAlto");
		String maximoMtAlto	= pReq.getParameter("maximoMuitoAlto");
		String obsAbaixo	= pReq.getParameter("abaixo");
		String obsAcima		= pReq.getParameter("acima");
		
		String[] opcoes		= pReq.getParameterValues("opcao");
		
		int numUnidade		= 0;
		
		//------------------------------------------- Validaes ------------------------------------------//

		if(nome == null || nome.equals(""))			
			tErro.add("O campo nome deve estar preenchido!");
		
		try{
			numUnidade = Integer.parseInt(unidade);
		}catch (NumberFormatException e) {
			numUnidade = 0;
		}
		
		if(opcoes == null || opcoes.length == 0){
			tErro.add("Nenhuma opo foi selecionada!");
			
		} else {
			
			for (int i = 0; i < opcoes.length; i++){
				
				if(opcoes[i].equals("06")){
					
					if(minimo06 == null || minimo06.equals("") || maximo06 == null || maximo06.equals(""))
						tErro.add("Os campos de mnimo e mximo de 0 a 6 anos devem estar preenchidos!");
									
				} else if(opcoes[i].equals("712")){
					
					if(minimo712 == null || minimo712.equals("") || maximo712 == null || maximo712.equals(""))
						tErro.add("Os campos de mnimo e mximo de 7 a 12 anos devem estar preenchidos!");
									
				} else if(opcoes[i].equals("65")){
					
					if(minimo65 == null || minimo65.equals("") || maximo65 == null || maximo65.equals(""))
						tErro.add("Os campos de mnimo e mximo de maiores de 65 anos devem estar preenchidos!");
									
				} else if(opcoes[i].equals("fem")){
					
					if(minimoFem == null || minimoFem.equals("") || maximoFem == null || maximoFem.equals(""))
						tErro.add("Os campos de mnimo e mximo da opo Feminino devem estar preenchidos!");
									
				} else if(opcoes[i].equals("mas")){
					
					if(minimoMas == null || minimoMas.equals("") || maximoMas == null || maximoMas.equals(""))
						tErro.add("Os campos de mnimo e mximo da opo Masculino devem estar preenchidos!");
									
				} else if(opcoes[i].equals("baixo")){
					
					if(minimoBaixo == null || minimoBaixo.equals("") || maximoBaixo == null || maximoBaixo.equals(""))
						tErro.add("Os campos de mnimo e mximo da opo Baixo devem estar preenchidos!");
	
				} else if(opcoes[i].equals("desejavel")){
					
					if(minimoDesej == null || minimoDesej.equals("") || maximoDesej == null || maximoDesej.equals(""))
						tErro.add("Os campos de mnimo e mximo da opo Desejvel devem estar preenchidos!");
									
				} else if(opcoes[i].equals("limite")){
					
					if(minimoLimite == null || minimoLimite.equals("") || maximoLimite == null || maximoLimite.equals(""))
						tErro.add("Os campos de mnimo e mximo da opo Limite devem estar preenchidos!");
									
				} else if(opcoes[i].equals("alto")){
					
					if(minimoAlto == null || minimoAlto.equals("") || maximoAlto == null || maximoAlto.equals(""))
						tErro.add("Os campos de mnimo e mximo da opo Alto devem estar preenchidos!");
									
				} else if(opcoes[i].equals("muitoAlto")){
					
					if(minimoMtAlto == null || minimoMtAlto.equals("") || maximoMtAlto == null || maximoMtAlto.equals(""))
						tErro.add("Os campos de mnimo e mximo da opo Muito Alto devem estar preenchidos!");
					
				}
			}
		}
		
		//------------------------------------------------------------------------------------------------//
		
		if(tErro.size() > 0)			
			mostrarErro(pReq, pResp, tErro, "/visualizacaoExame.jsp");
		
		else {
			
			ExameCadastrado exame = new ExameCadastrado(
				codigo, numUnidade, nome, minimo06, maximo06, minimo712, maximo712, minimo65, maximo65, minimoFem, maximoFem, minimoMas, maximoMas, 
				minimoBaixo, maximoBaixo, minimoDesej, maximoDesej, minimoLimite, maximoLimite, minimoAlto, maximoAlto, minimoMtAlto, 
				maximoMtAlto, obsAbaixo, obsAcima
			);
			
			if(new ExameCadastradoDAO().alteraExameCadastrado(exame)) {
				
				String loginUsuario = (String) session.getAttribute(Constantes.ATRIB_USUARIO_LOGADO);
				String ipUsuario 	= (String) session.getAttribute(Constantes.ATRIB_IP_LOGADO);
				String dtIni 		= (String) session.getAttribute(Constantes.ATRIB_DT_INI_ALT_EXAME);
				
				AuditLog audit 		= new AuditLog(0, loginUsuario, ipUsuario, dtIni, Constantes.HORA_ATUAL(), Constantes.COD_ALTERACAO_EXAME);
				
				new AuditLogDAO().incluiRegistro(audit);
				
				pReq.setAttribute("Msg", "Exame alterado com sucesso!");
			
			} else {
				
				pReq.setAttribute("Msg", "Problemas ao alterar o exame!");
			}
			
			ControlePrincipal controle	= new ControlePrincipal();

			if(GerenteConsultaUnidadeExame.todasUnidadesExame(controle))
				pReq.setAttribute("Unidades", controle.getUnidadesExame());
			

			ativarPagina(pReq, pResp, "/consultaExame.jsp");
			
		}
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param eNome
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoPesquisarExame(HttpServletRequest pReq, HttpServletResponse pResp, boolean eNome) throws ServletException, IOException {
		
		ControlePrincipal controle = new ControlePrincipal();
		
		Vector<ExameCadastrado> exames;
		
		String campo = "";
		
		if(eNome){
			
			campo = pReq.getParameter("nome");
			pReq.setAttribute("Nome", campo);
			
			if(GerenteConsultaExameCadastrado.examePorNome(controle, campo)){
				
				exames = controle.getExamesCadastrados();
				
				pReq.setAttribute("Exames", exames);
			
			} else {
				
				pReq.setAttribute("Msg", "Problemas ao realizar consulta de exames");
			}
			
		}else{
			
			campo = pReq.getParameter("unidade");
			
			int numUnidade = 0;
			
			try{			
				numUnidade = Integer.parseInt(campo);				
			}catch (NumberFormatException e) {
				numUnidade = 0;
			}
			
			pReq.setAttribute("unidade", campo);
			
			if(GerenteConsultaExameCadastrado.examePorUnidade(controle, numUnidade)){
				
				exames = controle.getExamesCadastrados();
				
				pReq.setAttribute("Exames", exames);
			
			} else {
				
				pReq.setAttribute("Msg", "Problemas ao realizar consulta de exames");
			}
		}

		if(GerenteConsultaUnidadeExame.todasUnidadesExame(controle)){
			pReq.setAttribute("Unidades", controle.getUnidadesExame());
		}

		ativarPagina(pReq, pResp, "/consultaExame.jsp");
	}
	

	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */

	private void acaoExcluirExame(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {
		
		ControlePrincipal controle = new ControlePrincipal();
		
		int codExame = Integer.parseInt(pReq.getParameter("codExame"));
		
		if(new ExameCadastradoDAO().excluiExamesCadastrados(codExame)){
			
			String loginUsuario = (String) session.getAttribute(Constantes.ATRIB_USUARIO_LOGADO);
			String ipUsuario 	= (String) session.getAttribute(Constantes.ATRIB_IP_LOGADO);
			String dtIni 		= (String) session.getAttribute(Constantes.ATRIB_DT_INI_EXC_EXAME);
			
			AuditLog audit 		= new AuditLog(0, loginUsuario, ipUsuario, dtIni, Constantes.HORA_ATUAL(), Constantes.COD_EXCLUSAO_EXAME);
			
			new AuditLogDAO().incluiRegistro(audit);
			
			pReq.setAttribute("Msg", "Exame excludo com sucesso!");
		
		} else {
			
			pReq.setAttribute("Msg", "Problemas ao excluir o exame!");
		}
		
		if(GerenteConsultaUnidadeExame.todasUnidadesExame(controle)){
			pReq.setAttribute("Unidades", controle.getUnidadesExame());
		}
		
		ativarPagina(pReq, pResp, "/consultaExame.jsp");
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */

	private void acaoExibirExame(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {

		session.setAttribute(Constantes.ATRIB_DT_INI_ALT_EXAME, Constantes.HORA_ATUAL());
		session.setAttribute(Constantes.ATRIB_DT_INI_EXC_EXAME, Constantes.HORA_ATUAL());
		
		ControlePrincipal controle = new ControlePrincipal();
		
		ExameCadastrado exame;
		
		String codExame = pReq.getParameter("codExame");
		
		int numCod = 0;
		
		try{
			numCod = Integer.parseInt(codExame);
		}catch (NumberFormatException e) {
			numCod = 0;
		}
		
		if(GerenteConsultaExameCadastrado.examePorCodigo(controle, numCod)){
			
			Vector<String> opcoes = new Vector<String>();
			
			exame = controle.getExamesCadastrados().get(0);
			
			// Verificao de campos vazios no banco de dados

			if(!(exame.getMinimo06() == null || exame.getMaximo06() == null	|| exame.getMinimo06().equals("") || exame.getMaximo06().equals(""))){

				opcoes.add("06");
				
				pReq.setAttribute("Minimo06", exame.getMinimo06());
				pReq.setAttribute("Maximo06", exame.getMaximo06());
				
			}

			if(!(exame.getMinimo712() == null || exame.getMaximo712() == null || exame.getMinimo712().equals("") || exame.getMaximo712().equals(""))){

				opcoes.add("712");
				
				pReq.setAttribute("Minimo712", exame.getMinimo712());
				pReq.setAttribute("Maximo712", exame.getMaximo712());
			}

			if(!(exame.getMinimo65() == null || exame.getMaximo65() == null || exame.getMinimo65().equals("") || exame.getMaximo65().equals(""))){

				opcoes.add("65");
				
				pReq.setAttribute("Minimo65", exame.getMinimo65());
				pReq.setAttribute("Maximo65", exame.getMaximo65());
			}

			if(!(exame.getMinimoFem() == null || exame.getMaximoFem() == null || exame.getMinimoFem().equals("") || exame.getMaximoFem().equals(""))){

				opcoes.add("fem");
				
				pReq.setAttribute("MinimoFem", exame.getMinimoFem());
				pReq.setAttribute("MaximoFem", exame.getMaximoFem());
			}

			if (!(exame.getMinimoMas() == null || exame.getMaximoMas() == null || exame.getMinimoMas().equals("") || exame.getMaximoMas().equals(""))){

				opcoes.add("mas");
				
				pReq.setAttribute("MinimoMas", exame.getMinimoMas());
				pReq.setAttribute("MaximoMas", exame.getMaximoMas());
			}

			if(!(exame.getMinimoBaixo() == null || exame.getMaximoBaixo() == null || exame.getMinimoBaixo().equals("") || exame.getMaximoBaixo().equals(""))){

				opcoes.add("baixo");
				
				pReq.setAttribute("MinimoBaixo", exame.getMinimoBaixo());
				pReq.setAttribute("MaximoBaixo", exame.getMaximoBaixo());
			}

			if(!(exame.getMinimoDesej() == null || exame.getMaximoDesej() == null || exame.getMinimoDesej().equals("") || exame.getMaximoDesej().equals(""))){

				opcoes.add("desejavel");
				
				pReq.setAttribute("MinimoDesejavel", exame.getMinimoDesej());
				pReq.setAttribute("MaximoDesejavel", exame.getMaximoDesej());
			}

			if(!(exame.getMinimoLimite() == null || exame.getMaximoLimite() == null || exame.getMinimoLimite().equals("") || exame.getMaximoLimite().equals(""))){

				opcoes.add("limite");
				
				pReq.setAttribute("MinimoLimite", exame.getMinimoLimite());
				pReq.setAttribute("MaximoLimite", exame.getMaximoLimite());
			}

			if(!(exame.getMinimoAlto() == null || exame.getMaximoAlto() == null || exame.getMinimoAlto().equals("") || exame.getMaximoAlto().equals(""))){

				opcoes.add("alto");
				
				pReq.setAttribute("MinimoAlto", exame.getMinimoAlto());
				pReq.setAttribute("MaximoAlto", exame.getMaximoAlto());
			}

			if(!(exame.getMinimoMtAlto() == null || exame.getMaximoMtAlto() == null || exame.getMinimoMtAlto().equals("") || exame.getMaximoMtAlto().equals(""))){

				opcoes.add("muitoAlto");
				
				pReq.setAttribute("MinimoMuitoAlto", exame.getMinimoMtAlto());
				pReq.setAttribute("MaximoMuitoAlto", exame.getMaximoMtAlto());
			}

			pReq.setAttribute("CodExame", exame.getIdExame());
			pReq.setAttribute("Nome"	, exame.getNome());
			pReq.setAttribute("Unidade"	, String.valueOf(exame.getUnidade()));
			pReq.setAttribute("Abaixo"	, exame.getObsAbaixo());
			pReq.setAttribute("Acima"	, exame.getObsAcima());
			pReq.setAttribute("Opcoes"	, opcoes);
			
		} else {
			
			pReq.setAttribute("Msg", "Problemas ao exibir exame");
		}

		if(GerenteConsultaUnidadeExame.todasUnidadesExame(controle)){
			pReq.setAttribute("Unidades", controle.getUnidadesExame());
		}
		
		ativarPagina(pReq, pResp, "/visualizacaoExame.jsp");
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @throws ServletException
	 * @throws IOException
	 */
		
	private void acaoNovaUnidade(HttpServletRequest pReq, HttpServletResponse pResp) throws ServletException, IOException {
				
		ControlePrincipal controle = new ControlePrincipal();
		
		boolean eCadastro			= pReq.getParameter("eCadastro").equals("sim");
		
		String codExameDigitado 	= pReq.getParameter("codExame");
		String nomeDigitado			= pReq.getParameter("nome");
		String minimo06Digitado		= pReq.getParameter("minimo0-6");
		String maximo06Digitado		= pReq.getParameter("maximo0-6");
		String minimo712Digitado	= pReq.getParameter("minimo7-12");
		String maximo712Digitado	= pReq.getParameter("maximo7-12");
		String minimo65Digitado		= pReq.getParameter("minimo65");
		String maximo65Digitado		= pReq.getParameter("maximo65");
		String minimoFemDigitado	= pReq.getParameter("minimoFem");
		String maximoFemDigitado	= pReq.getParameter("maximoFem");
		String minimoMasDigitado	= pReq.getParameter("minimoMas");
		String maximoMasDigitado	= pReq.getParameter("maximoMas");
		String minimoBaixoDigitado	= pReq.getParameter("minimoBaixo");
		String maximoBaixoDigitado	= pReq.getParameter("maximoBaixo");
		String minimoDesejDigitado	= pReq.getParameter("minimoDesejavel");
		String maximoDesejDigitado	= pReq.getParameter("maximoDesejavel");
		String minimoLimiteDigitado	= pReq.getParameter("minimoLimite");
		String maximoLimiteDigitado	= pReq.getParameter("maximoLimite");
		String minimoAltoDigitado	= pReq.getParameter("minimoAlto");
		String maximoAltoDigitado	= pReq.getParameter("maximoAlto");
		String minimoMtAltoDigitado	= pReq.getParameter("minimoMuitoAlto");
		String maximoMtAltoDigitado	= pReq.getParameter("maximoMuitoAlto");
		String obsAbaixoDigitado	= pReq.getParameter("abaixo");
		String obsAcimaDigitado		= pReq.getParameter("acima");
		
		UnidadeExame unidade = new UnidadeExame(0, pReq.getParameter("novaUnidade"));
		
		if(new UnidadeExameDAO().incluiUnidadeExame(unidade)){
			
			Vector<String> opcoes = new Vector<String>();			

			if(!(minimo06Digitado == null || maximo06Digitado == null	|| minimo06Digitado.equals("") || maximo06Digitado.equals(""))){

				opcoes.add("06");
				
				pReq.setAttribute("Minimo06", minimo06Digitado);
				pReq.setAttribute("Maximo06", maximo06Digitado);				
			}

			if(!(minimo712Digitado == null || maximo712Digitado == null || minimo712Digitado.equals("") || maximo712Digitado.equals(""))){

				opcoes.add("712");
				
				pReq.setAttribute("Minimo712", minimo712Digitado);
				pReq.setAttribute("Maximo712", maximo712Digitado);
			}

			if(!(minimo65Digitado == null || maximo65Digitado == null || minimo65Digitado.equals("") || maximo65Digitado.equals(""))){

				opcoes.add("65");
				
				pReq.setAttribute("Minimo65", minimo65Digitado);
				pReq.setAttribute("Maximo65", maximo65Digitado);
			}

			if(!(minimoFemDigitado == null || maximoFemDigitado == null || minimoFemDigitado.equals("") || maximoFemDigitado.equals(""))){

				opcoes.add("fem");
				
				pReq.setAttribute("MinimoFem", minimoFemDigitado);
				pReq.setAttribute("MaximoFem", maximoFemDigitado);
			}

			if (!(minimoMasDigitado == null || maximoMasDigitado == null || minimoMasDigitado.equals("") || maximoMasDigitado.equals(""))){

				opcoes.add("mas");
				
				pReq.setAttribute("MinimoMas", minimoMasDigitado);
				pReq.setAttribute("MaximoMas", maximoMasDigitado);
			}

			if(!(minimoBaixoDigitado == null || maximoBaixoDigitado == null || minimoBaixoDigitado.equals("") || maximoBaixoDigitado.equals(""))){

				opcoes.add("baixo");
				
				pReq.setAttribute("MinimoBaixo", minimoBaixoDigitado);
				pReq.setAttribute("MaximoBaixo", maximoBaixoDigitado);
			}

			if(!(minimoDesejDigitado == null || maximoDesejDigitado == null || minimoDesejDigitado.equals("") || maximoDesejDigitado.equals(""))){

				opcoes.add("desejavel");
				
				pReq.setAttribute("MinimoDesejavel", minimoDesejDigitado);
				pReq.setAttribute("MaximoDesejavel", maximoDesejDigitado);
			}

			if(!(minimoLimiteDigitado == null || maximoLimiteDigitado == null || minimoLimiteDigitado.equals("") || maximoLimiteDigitado.equals(""))){

				opcoes.add("limite");
				
				pReq.setAttribute("MinimoLimite", minimoLimiteDigitado);
				pReq.setAttribute("MaximoLimite", maximoLimiteDigitado);
			}

			if(!(minimoAltoDigitado == null || maximoAltoDigitado == null || minimoAltoDigitado.equals("") || maximoAltoDigitado.equals(""))){

				opcoes.add("alto");
				
				pReq.setAttribute("MinimoAlto", minimoAltoDigitado);
				pReq.setAttribute("MaximoAlto", maximoAltoDigitado);
			}

			if(!(minimoMtAltoDigitado == null || maximoMtAltoDigitado == null || minimoMtAltoDigitado.equals("") || maximoMtAltoDigitado.equals(""))){

				opcoes.add("muitoAlto");
				
				pReq.setAttribute("MinimoMuitoAlto", minimoMtAltoDigitado);
				pReq.setAttribute("MaximoMuitoAlto", maximoMtAltoDigitado);
			}

			pReq.setAttribute("CodExame", codExameDigitado);
			pReq.setAttribute("Nome"	, nomeDigitado);
			pReq.setAttribute("Abaixo"	, obsAbaixoDigitado);
			pReq.setAttribute("Acima"	, obsAcimaDigitado);
			pReq.setAttribute("Opcoes"	, opcoes);

			if(GerenteConsultaUnidadeExame.todasUnidadesExame(controle))
				pReq.setAttribute("Unidades", controle.getUnidadesExame());
			
		} else {
			
			pReq.setAttribute("Msg", "Problemas ao cadastrar nova unidade");
		}
		
		ativarPagina(pReq, pResp, eCadastro ? "/cadastroExame.jsp" : "/visualizacaoExame.jsp");
	}
}