package br.ufpr.mityba.servlets;

import java.io.IOException;
import java.util.Vector;

import javax.servlet.RequestDispatcher;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import br.ufpr.mityba.controller.GerenteConsultaConvenio;
import br.ufpr.mityba.dao.LancamentoDAO;
import br.ufpr.mityba.model.Convenio;
import br.ufpr.mityba.util.Constantes;
import br.ufpr.mityba.util.ControlePrincipal;
import br.ufpr.mityba.util.Utilitarios;

/**
 * Servlet implementation class ServletFinanceiro
 * 
 * @author Mityba
 * @since 17/11/2008
 * @version 1.0 17/11/2008
 */
public class ServletFinanceiro extends HttpServlet {

	static final long serialVersionUID = 1324122132L;

	/**
	 * @param pReq 
	 * @param pResp 
	 * @throws ServletException 
	 * @throws IOException 
	 * 
	 */
	public void service(final HttpServletRequest pReq, final HttpServletResponse pResp) throws ServletException, IOException {

		Vector<String> tErro = new Vector<String>();

		HttpSession session = pReq.getSession(false);

		String service = pReq.getParameter("service");

		if (session == null) {

			tErro.add("Voc deve efetuar o login antes de acessar essa funcionalidade!");

		} else {

			if (service == null || service.equals("")) {

				tErro.add("Informar a ao a ser executada\n");
				
			} else if (service.equals("apresentaFinanceiro")) {
				
				if((Integer) session.getAttribute(Constantes.ATRIB_ACESSO_FINANCEIRO) == 3){
				
					ativarPagina(pReq, pResp, "/apresentaFinanceiro.jsp");
				
				} else {
					
					tErro.add("Voc no tem o nvel de privilgio necessrio para acessar essa funcionalidade");
				}
				
			} else if (service.equals("gerarGrafico")) {
				
				acaoGerarGrafico(pReq, pResp);
			
			} else if (service.equals("voltaTela")) {

				ativarPagina(pReq, pResp, "/PaginaInicial.jsp");
			}
		}

		if (tErro.size() > 0) {
			mostrarErro(pReq, pResp, tErro, "/apresentaFinanceiro.jsp");
		}
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param pErro
	 * @param pPag
	 * @throws ServletException
	 * @throws IOException
	 */

	private void mostrarErro(HttpServletRequest pReq, HttpServletResponse pResp, Vector<String> pErro, String pPag) throws ServletException, IOException {
		pReq.setAttribute("Erros", pErro);
		ativarPagina(pReq, pResp, pPag);
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param pPagina
	 * @throws ServletException
	 * @throws IOException
	 */

	private void ativarPagina(HttpServletRequest pReq, HttpServletResponse pResp, String pPagina) throws ServletException, IOException {
		ServletContext tContexto 		= getServletContext();
		RequestDispatcher tDespachante 	= tContexto.getRequestDispatcher(pPagina);
		tDespachante.forward(pReq, pResp);
	}	
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoGerarGrafico(HttpServletRequest pReq, HttpServletResponse pResp) throws ServletException, IOException {

		Vector<String> tErro		= new Vector<String>();
		
		ControlePrincipal controle	= new ControlePrincipal();
		
		LancamentoDAO lancamentoDAO	= new LancamentoDAO();
		
		StringBuffer xml			= new StringBuffer();

		//barras ou pizza
		String layoutGrafico		= pReq.getParameter("layoutGrafico");		
		pReq.setAttribute("LayoutGrafico", layoutGrafico);
		
		//quantidade ou $
		String tipoGrafico			= pReq.getParameter("tipoGrafico");		
		pReq.setAttribute("TipoGrafico", tipoGrafico);
		
		//convenios ou perdas
		String categoriaGrafico		= pReq.getParameter("categoriaGrafico");		
		pReq.setAttribute("CategoriaGrafico", categoriaGrafico);

		String tituloGrafico		= "";
		String prefixoGrafico		= "";

		String[] meses				= pReq.getParameterValues("meses");		
		String[] cores				= new String[]{"AFD8F8", "F6BD0F", "8BBA00"};
		
		int indiceCor				= 0;
		
		boolean todos				= pReq.getParameter("todos").equals("s");
		
		Vector<Convenio> convenios	= null;
		
		if((meses == null || meses.length == 0) && !todos){
			
			tErro.add("Selecione algum ms para gerar o relatrio!");
			
			mostrarErro(pReq, pResp, tErro, "/apresentaFinanceiro.jsp");
		
		} else {
			
			if(todos){
				
				meses = new String[]{"01", "02", "03", "04", "05", "06", "07", "08", "09", "10", "11", "12"};
				
				pReq.setAttribute("Todos", "s");
				
			} else {
				
				meses = Utilitarios.ordenaVetor(meses);
				
				pReq.setAttribute("Todos", "n");
			}
			
			if(categoriaGrafico.equals(Constantes.GRAFICO_CONVENIOS)){
			
				if(GerenteConsultaConvenio.todosConvenios(controle)){
					convenios = controle.getConvenios();
				}else{
					convenios = new Vector<Convenio>();
				}
				//--------------- Grfico de barras
				
				if(layoutGrafico.equals(Constantes.GRAFICO_BARRAS)){
					
					pReq.setAttribute("chart", "MSColumn3D");
					
				//--------------- Quantidade
					
					if(tipoGrafico.equals(Constantes.GRAFICO_POR_QUANTIDADE)){
						
						tituloGrafico 	= "Quantidade de consultas por convenio";
				
				//--------------- $
						
					} else {
						
						tituloGrafico 	= "Balano financeiro por convenio";
						prefixoGrafico	= Constantes.MOEDA;
					}
					
					if(convenios.size() > 0){
					
						xml.append("- <chart caption='" + tituloGrafico + "' shownames='1' showvalues='1' decimals='2' numberPrefix='" + prefixoGrafico + "' showBorder='1'>")
						   .append("- <categories>");
						
						for(int i = 0; i < convenios.size(); i++){
							xml.append("	<category label='" + convenios.get(i).getNomeConvenio() + "' />");
						}
						
						xml.append("</categories>");
						
						for(int i = 0; i < meses.length; i++){
							
							indiceCor = i;
							
							if(indiceCor >= cores.length)
								while(indiceCor >= cores.length)
									indiceCor -= cores.length;
	
							xml.append("- <dataset seriesName='" + Utilitarios.getMes(Integer.parseInt(meses[i])) + "' color='" + cores[indiceCor] + "' showValues='1'>");
							
							if(tipoGrafico.equals(Constantes.GRAFICO_POR_QUANTIDADE)){						
								for(int j = 0; j < convenios.size(); j++){
									xml.append("	 <set value='" + lancamentoDAO.countConvenioLancamento(convenios.get(j).getIdConvenio(), Constantes.COD_CONSULTA_ATENDIDA, meses[i]) + "' /> ");
								}
							} else if(tipoGrafico.equals(Constantes.GRAFICO_POR_$)) {
								for(int j = 0; j < convenios.size(); j++){								
									xml.append("	 <set value='" + lancamentoDAO.sumConvenioLancamento(convenios.get(j).getIdConvenio(), Constantes.COD_CONSULTA_ATENDIDA, meses[i]) + "' /> ");
								}
							}
							
							xml.append("</dataset>");
						}
						
						xml.append("</chart>");
					}
					
				//--------- Grfico de pizza
					
				} else if(layoutGrafico.equals(Constantes.GRAFICO_PIZZA)){
					
					pReq.setAttribute("chart", "Pie3D");
	
				//-------- Quantidade
					
					if(tipoGrafico.equals(Constantes.GRAFICO_POR_QUANTIDADE)){
						
						xml.append("- <chart palette='4' decimals='0' enableSmartLabels='1' enableRotation='0' bgColor='99CCFF,FFFFFF' bgAlpha='40,100' bgRatio='0,100' bgAngle='360' showBorder='1' startingAngle='70'>");
						
						for(int i = 0; i < convenios.size(); i++){
							
							int numeroConsultas = 0;
							
							for(int j = 0; j < meses.length; j++)
								numeroConsultas += lancamentoDAO.countConvenioLancamento(convenios.get(i).getIdConvenio(), Constantes.COD_CONSULTA_ATENDIDA, meses[j]);
													
							xml.append("	<set label='" + convenios.get(i).getNomeConvenio() + "' value='" + numeroConsultas + "' />");
						}
						
				//-------- $
						
					} else if(tipoGrafico.equals(Constantes.GRAFICO_POR_$)) {
						
						xml.append("- <chart palette='4' decimals='2' enableSmartLabels='1' enableRotation='0' bgColor='99CCFF,FFFFFF' bgAlpha='40,100' bgRatio='0,100' bgAngle='360' showBorder='1' startingAngle='70'>");
	
						for(int i = 0; i < convenios.size(); i++){
							
							double sumConsultas = 0;
							
							for(int j = 0; j < meses.length; j++)
								sumConsultas += lancamentoDAO.sumConvenioLancamento(convenios.get(i).getIdConvenio(), Constantes.COD_CONSULTA_ATENDIDA, meses[j]);
													
							xml.append("	<set label='" + convenios.get(i).getNomeConvenio() + "' value='" + sumConsultas + "' />");
						}					
					}				
					xml.append(" </chart>");
				}
				
			} else if(categoriaGrafico.equals(Constantes.GRAFICO_PERDAS)){
				
				//--------------- Grfico de barras
				
				if(layoutGrafico.equals(Constantes.GRAFICO_BARRAS)){
					
					pReq.setAttribute("chart", "MSColumn3D");
					
				//--------------- Quantidade
					
					if(tipoGrafico.equals("quantidade")){
						
						tituloGrafico 	= "Quantidade consultas perdidas";
				
				//--------------- $
						
					} else {
						
						tituloGrafico 	= "Balano financeiro de consultas perdidas";
						prefixoGrafico	= Constantes.MOEDA;
					}
					
					xml.append("- <chart caption='" + tituloGrafico + "' shownames='1' showvalues='1' decimals='2' numberPrefix='" + prefixoGrafico + "' showBorder='1'>")
					   .append("- <categories>")
					   .append("	<category label='" + Constantes.DESCR_CONSULTA_FALTA 	 + "' />")
					   .append("	<category label='" + Constantes.DESCR_CONSULTA_CANCELADA + "' />")
					   .append("	<category label='" + Constantes.DESCR_CONSULTA_REMARCADA + "' />")
					   .append("</categories>");
					
					for(int i = 0; i < meses.length; i++){
						
						indiceCor = i;
						
						if(indiceCor >= cores.length)
							while(indiceCor >= cores.length)
								indiceCor -= cores.length;

						xml.append("- <dataset seriesName='" + Utilitarios.getMes(Integer.parseInt(meses[i])) + "' color='" + cores[indiceCor] + "'>");
						
						if(tipoGrafico.equals(Constantes.GRAFICO_POR_QUANTIDADE)){						

							xml.append("	 <set value='" + lancamentoDAO.countLancamento(Constantes.COD_CONSULTA_FALTA	, meses[i]) + "' /> ")
							   .append("	 <set value='" + lancamentoDAO.countLancamento(Constantes.COD_CONSULTA_CANCELADA, meses[i]) + "' /> ")
							   .append("	 <set value='" + lancamentoDAO.countLancamento(Constantes.COD_CONSULTA_REMARCADA, meses[i]) + "' /> ");

						} else if(tipoGrafico.equals(Constantes.GRAFICO_POR_$)) {		

							xml.append("	 <set value='" + lancamentoDAO.sumLancamento(Constantes.COD_CONSULTA_FALTA		, meses[i]) + "' /> ")
							   .append("	 <set value='" + lancamentoDAO.sumLancamento(Constantes.COD_CONSULTA_CANCELADA	, meses[i]) + "' /> ")
							   .append("	 <set value='" + lancamentoDAO.sumLancamento(Constantes.COD_CONSULTA_REMARCADA	, meses[i]) + "' /> ");
						}

						xml.append("</dataset>");
					}

				//--------- Grfico de pizza

				} else if(layoutGrafico.equals(Constantes.GRAFICO_PIZZA)){

					pReq.setAttribute("chart", "Pie3D");

				//-------- Quantidade

					if(tipoGrafico.equals(Constantes.GRAFICO_POR_QUANTIDADE)){
						
						xml.append("- <chart palette='4' decimals='0' enableSmartLabels='1' enableRotation='0' bgColor='99CCFF,FFFFFF' bgAlpha='40,100' bgRatio='0,100' bgAngle='360' showBorder='1' startingAngle='70'>");
													
						int numeroConsultas = 0;

						for(int j = 0; j < meses.length; j++)
							numeroConsultas += lancamentoDAO.countLancamento(Constantes.COD_CONSULTA_FALTA, meses[j]);

						xml.append("	<set label='" + Constantes.DESCR_CONSULTA_FALTA + "' value='" + numeroConsultas + "' />");

						numeroConsultas = 0;

						for(int j = 0; j < meses.length; j++)
							numeroConsultas += lancamentoDAO.countLancamento(Constantes.COD_CONSULTA_CANCELADA, meses[j]);

						xml.append("	<set label='" + Constantes.DESCR_CONSULTA_CANCELADA + "' value='" + numeroConsultas + "' />");
						
						numeroConsultas = 0;

						for(int j = 0; j < meses.length; j++)
							numeroConsultas += lancamentoDAO.countLancamento(Constantes.COD_CONSULTA_REMARCADA, meses[j]);

						xml.append("	<set label='" + Constantes.DESCR_CONSULTA_REMARCADA + "' value='" + numeroConsultas + "' />");

				//-------- $

					} else if(tipoGrafico.equals(Constantes.GRAFICO_POR_$)) {

						xml.append("- <chart palette='4' decimals='2' enableSmartLabels='1' enableRotation='0' bgColor='99CCFF,FFFFFF' bgAlpha='40,100' bgRatio='0,100' bgAngle='360' showBorder='1' startingAngle='70'>");

						double sumConsultas = 0;

						for(int j = 0; j < meses.length; j++)
							sumConsultas += lancamentoDAO.sumLancamento(Constantes.COD_CONSULTA_FALTA, meses[j]);

						xml.append("	<set label='" + Constantes.DESCR_CONSULTA_FALTA + "' value='" + sumConsultas + "' />");

						sumConsultas = 0;

						for(int j = 0; j < meses.length; j++)
							sumConsultas += lancamentoDAO.sumLancamento(Constantes.COD_CONSULTA_CANCELADA, meses[j]);

						xml.append("	<set label='" + Constantes.DESCR_CONSULTA_CANCELADA + "' value='" + sumConsultas + "' />");

						sumConsultas = 0;

						for(int j = 0; j < meses.length; j++)
							sumConsultas += lancamentoDAO.sumLancamento(Constantes.COD_CONSULTA_REMARCADA, meses[j]);

						xml.append("	<set label='" + Constantes.DESCR_CONSULTA_REMARCADA + "' value='" + sumConsultas + "' />");											
					}
				}
				xml.append(" </chart>");
			}

			pReq.setAttribute("xml", xml.toString());

			pReq.setAttribute("Meses", meses);

			ativarPagina(pReq, pResp, "/apresentaFinanceiro.jsp");
		}
	}
}