package br.ufpr.mityba.servlets;

import java.io.IOException;
import java.util.Vector;

import javax.servlet.RequestDispatcher;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import br.ufpr.mityba.controller.GerenteConsultaIntervaloHorarioConsulta;
import br.ufpr.mityba.controller.GerenteConsultaUsuario;
import br.ufpr.mityba.dao.AuditLogDAO;
import br.ufpr.mityba.dao.HorarioConsultaDAO;
import br.ufpr.mityba.dao.IntervaloHorarioConsultaDAO;
import br.ufpr.mityba.model.AuditLog;
import br.ufpr.mityba.model.HorarioConsulta;
import br.ufpr.mityba.model.IntervaloHorarioConsulta;
import br.ufpr.mityba.util.Constantes;
import br.ufpr.mityba.util.ControlePrincipal;

/**
 * Servlet implementation class ServletHorarioConsulta
 * 
 * @author Mityba
 * @since 24/11/2008
 * @version 1.0 24/11/2008
 */
public class ServletHorarioConsulta extends HttpServlet {

	static final long serialVersionUID = 132232132L;

	/**
	 * @param pReq 
	 * @param pResp 
	 * @throws ServletException 
	 * @throws IOException 
	 * 
	 */
	public void service(final HttpServletRequest pReq, final HttpServletResponse pResp) throws ServletException, IOException {

		Vector<String> tErro = new Vector<String>();

		HttpSession session = pReq.getSession(false);

		String service = pReq.getParameter("service");

		if (session == null) {

			tErro.add("Voc deve efetuar o login antes de acessar essa funcionalidade!");

		} else {

			if (service == null || service.equals("")) {

				tErro.add("Informar a ao a ser executada\n");

			} else if (service.equals("cadastroHorarios")) {
				
				if((Integer) session.getAttribute(Constantes.ATRIB_ACESSO_CADASTRO) == 3){
				
					acaoCadastroHorarios(pReq, pResp, session);
				
				} else {
					
					tErro.add("Voc no tem o nvel de privilgio necessrio para acessar essa funcionalidade");
				}
				
			} else if (service.equals("salvarCadastro")) {				
				
				acaoSalvarCadastro(pReq, pResp, session);
				
			} else if (service.equals("excluir")) {
				
				acaoExclusaoConfirmada(pReq, pResp, session);
				
			} else if (service.equals("exibirDia")) {
				
				acaoExibirDia(pReq, pResp, session);
				
			} else if (service.equals("excluir")) {
				
				acaoExclusaoConfirmada(pReq, pResp, session);
				
			} else if (service.equals("mudaMedico")) {
				
				acaoMudaMedico(pReq, pResp, session);

			} else if (service.equals("voltaTela")) {

				ativarPagina(pReq, pResp, "/PaginaInicial.jsp");
			}
		}

		if (tErro.size() > 0) {
			mostrarErro(pReq, pResp, tErro, "/PaginaInicial.jsp");
		}
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param pErro
	 * @param pPag
	 * @throws ServletException
	 * @throws IOException
	 */

	private void mostrarErro(HttpServletRequest pReq, HttpServletResponse pResp, Vector<String> pErro, String pPag) throws ServletException, IOException {
		pReq.setAttribute("Erros", pErro);
		ativarPagina(pReq, pResp, pPag);
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param pPagina
	 * @throws ServletException
	 * @throws IOException
	 */

	private void ativarPagina(HttpServletRequest pReq, HttpServletResponse pResp, String pPagina) throws ServletException, IOException {
		ServletContext tContexto 		= getServletContext();
		RequestDispatcher tDespachante 	= tContexto.getRequestDispatcher(pPagina);
		tDespachante.forward(pReq, pResp);
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoCadastroHorarios(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {

		session.setAttribute(Constantes.ATRIB_DT_INI_CAD_INTERVALO, Constantes.HORA_ATUAL());
		
		ControlePrincipal controle = new ControlePrincipal();
		int idUsuario	= (Integer) session.getAttribute(Constantes.ATRIB_ID_USUARIO_LOGADO);		
		
		if(GerenteConsultaIntervaloHorarioConsulta.intervalosPorDiaSemana(controle, Constantes.COD_SEGUNDA_FEIRA, idUsuario)){
			pReq.setAttribute("Intervalos", controle.getIntervalosConsulta());
		} else {
			pReq.setAttribute("Msg", "Problemas ao carregar horrios");
		}
		
		pReq.setAttribute("DiaSemana", String.valueOf(Constantes.COD_SEGUNDA_FEIRA));
		
		if ((Integer) session.getAttribute(Constantes.ATRIB_TIPO_ACESSO) == Constantes.ACESSO_SECRETARIA){
			pReq.setAttribute("eSecretaria", "sim");
			
			GerenteConsultaUsuario.usuarioMedico(controle);
			pReq.setAttribute("Medicos", controle.getUsuarios());
		}

		ativarPagina(pReq, pResp, "/cadastroHorarioConsulta.jsp");
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoMudaMedico(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {

		session.setAttribute(Constantes.ATRIB_DT_INI_CAD_INTERVALO, Constantes.HORA_ATUAL());
		
		ControlePrincipal controle = new ControlePrincipal();
		int idUsuario	= Integer.parseInt(pReq.getParameter("medico"));		
		
		if(GerenteConsultaIntervaloHorarioConsulta.intervalosPorDiaSemana(controle, Constantes.COD_SEGUNDA_FEIRA, idUsuario)){
			pReq.setAttribute("Intervalos", controle.getIntervalosConsulta());
		} else {
			pReq.setAttribute("Msg", "Problemas ao carregar horrios");
		}
		
		GerenteConsultaUsuario.usuarioMedico(controle);
		
		pReq.setAttribute("Medicos", controle.getUsuarios());
		pReq.setAttribute("eSecretaria"	, "sim");
		pReq.setAttribute("DiaSemana"	, String.valueOf(Constantes.COD_SEGUNDA_FEIRA));
		pReq.setAttribute("Medico"		, String.valueOf(idUsuario));

		ativarPagina(pReq, pResp, "/cadastroHorarioConsulta.jsp");
	}
		
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */
		
	private void acaoSalvarCadastro(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {
		
		Vector<String> tErro	= new Vector<String>();
		
		ControlePrincipal controle = new ControlePrincipal();

		IntervaloHorarioConsultaDAO intervaloDAO 	= new IntervaloHorarioConsultaDAO();
		HorarioConsultaDAO horarioDAO 				= new HorarioConsultaDAO();
		
		int diaSemana			= Integer.parseInt(pReq.getParameter("diaSemana"));
		int intervaloDigitado 	= 0;
		int inicioDigitado		= 0;
		int fimDigitado			= 0;

		try{
			
			intervaloDigitado 	= Integer.parseInt(pReq.getParameter("intervalo"));
			
			if(intervaloDigitado != 10 && intervaloDigitado != 15 && intervaloDigitado != 30 && intervaloDigitado != 60){
				tErro.add("O campo intervalo deve ser com 10, 15, 30 ou 60");
			}
			
		}catch (NumberFormatException e) {
			tErro.add("O campo intervalo deve ser preenchido por caracteres numricos apenas");
		}
		
		try{
			inicioDigitado 	= Integer.parseInt(pReq.getParameter("inicio"));
		}catch (NumberFormatException e) {
			tErro.add("O campo incio deve ser preenchido por caracteres numricos apenas");
		}
		
		try{
			
			fimDigitado 	= Integer.parseInt(pReq.getParameter("fim"));
			
			if(inicioDigitado >= fimDigitado)
				tErro.add("O campo fim deve ser maior que o campo incio");
			
		}catch (NumberFormatException e) {
			tErro.add("O campo fim deve ser preenchido por caracteres numricos apenas");
		}

		if(tErro.size() > 0){
			mostrarErro(pReq, pResp, tErro, "/cadastroHorarioConsulta.jsp");
			
		} else {
			
			int codigoIntervalo		= 0;
			int horas 				= fimDigitado - inicioDigitado;
			int qtdeConsultasHora 	= 60 / intervaloDigitado;
			
			boolean eSecretaria		= pReq.getParameter("eSecretaria").equals("sim");
			
			int idUsuario 			= eSecretaria ? Integer.parseInt(pReq.getParameter("medico")) : (Integer) session.getAttribute(Constantes.ATRIB_ID_USUARIO_LOGADO);
			
			boolean existe 			= false;
			
			//--------- Procura horrios j cadastrados no intervalo que o usurio digitou
			
			for(int i = 0; i < horas; i++){
				if(GerenteConsultaIntervaloHorarioConsulta.existeIntervaloHoraDiaSemana((inicioDigitado + i), idUsuario, diaSemana)){
					existe = true;
					break;
				}
			}
			
			//---------
			
			if(!existe){
			
				IntervaloHorarioConsulta intervalo = new IntervaloHorarioConsulta(
					0,
					idUsuario,
					diaSemana,
					intervaloDigitado,
					inicioDigitado	+ ":00:00",
					fimDigitado		+ ":00:00"
				);
				
				if(intervaloDAO.incluiIntervaloHorarioConsulta(intervalo)){
					
					codigoIntervalo		= intervaloDAO.maxIntervalosHorarioConsulta();
					
					HorarioConsulta horario	= null;
					
					for(int i = 0; i < horas; i++){
						for(int j = 0; j < qtdeConsultasHora; j++){
							
							horario = new HorarioConsulta(
								0,
								codigoIntervalo,
								idUsuario,
								diaSemana,
								intervaloDigitado,
								(inicioDigitado + i) + ":" + (j == 0 ? "00" : (j * intervaloDigitado)) + ":00"
							);
							
							horarioDAO.incluiHorarioConsulta(horario);
						}
					}
	
					String loginUsuario = (String) session.getAttribute(Constantes.ATRIB_USUARIO_LOGADO);
					String ipUsuario 	= (String) session.getAttribute(Constantes.ATRIB_IP_LOGADO);
					String dtIni 		= (String) session.getAttribute(Constantes.ATRIB_DT_INI_CAD_INTERVALO);
					
					AuditLog audit 		= new AuditLog(0, loginUsuario, ipUsuario, dtIni, Constantes.HORA_ATUAL(), Constantes.COD_CADASTRO_INTERVALO);
					
					new AuditLogDAO().incluiRegistro(audit);
					
				} else {
					
					pReq.setAttribute("Msg", "Problemas ao cadastrar o intervalo");
				}
				
			} else {
				
				tErro.add("J existem horrios cadastrados nesse perodo");
			}
			
			if(eSecretaria)
				pReq.setAttribute("eSecretaria"	, "sim");
			
			GerenteConsultaUsuario.usuarioMedico(controle);
			pReq.setAttribute("Medicos"		, controle.getUsuarios());
			pReq.setAttribute("Medico"		, String.valueOf(idUsuario));

			if(tErro.size() > 0)
				mostrarErro(pReq, pResp, tErro, "/cadastroHorarioConsulta.jsp");
			else 			
				acaoCadastroHorarios(pReq, pResp, session);
		}
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoExibirDia(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {

		session.setAttribute(Constantes.ATRIB_DT_INI_CAD_INTERVALO, Constantes.HORA_ATUAL());
		
		ControlePrincipal controle 	= new ControlePrincipal();
		
		int diaSemana 				= Integer.parseInt(pReq.getParameter("diaSemana"));		
		
		boolean eSecretaria			= pReq.getParameter("eSecretaria").equals("sim");
		
		int idUsuario 				= eSecretaria ? Integer.parseInt(pReq.getParameter("medico")) : (Integer) session.getAttribute(Constantes.ATRIB_ID_USUARIO_LOGADO);
		
		if(GerenteConsultaIntervaloHorarioConsulta.intervalosPorDiaSemana(controle, diaSemana, idUsuario)){
			pReq.setAttribute("Intervalos", controle.getIntervalosConsulta());
		} else {
			pReq.setAttribute("Msg", "Problemas ao carregar horrios");
		}
		
		if(eSecretaria)
			pReq.setAttribute("eSecretaria"	, "sim");
		
		GerenteConsultaUsuario.usuarioMedico(controle);
		pReq.setAttribute("Medicos"		, controle.getUsuarios());
		pReq.setAttribute("DiaSemana"	, String.valueOf(diaSemana));
		pReq.setAttribute("Medico"		, String.valueOf(idUsuario));

		ativarPagina(pReq, pResp, "/cadastroHorarioConsulta.jsp");
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoExclusaoConfirmada(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {
		
		int codIntervalo = Integer.parseInt(pReq.getParameter("codIntervalo"));
		
		new HorarioConsultaDAO().excluiHorarioConsultaPorIntervalo(codIntervalo);
		
		if(new IntervaloHorarioConsultaDAO().excluiHorarioConsulta(codIntervalo)){			
			
			String loginUsuario = (String) session.getAttribute(Constantes.ATRIB_USUARIO_LOGADO);
			String ipUsuario 	= (String) session.getAttribute(Constantes.ATRIB_IP_LOGADO);
			String dtIni 		= (String) session.getAttribute(Constantes.ATRIB_DT_INI_EXC_INTERVALO);
			
			AuditLog audit 		= new AuditLog(0, loginUsuario, ipUsuario, dtIni, Constantes.HORA_ATUAL(), Constantes.COD_EXCLUSAO_INTERVALO);
			
			new AuditLogDAO().incluiRegistro(audit);
			
			pReq.setAttribute("Msg", "Intervalo excludo com sucesso");		
			
		} else {
			
			pReq.setAttribute("Msg", "Problemas ao remover o intervalo");
		}
		
		acaoExibirDia(pReq, pResp, session);
	}	
}