package br.ufpr.mityba.servlets;

import java.io.IOException;
import java.util.Vector;

import javax.servlet.RequestDispatcher;
import javax.servlet.Servlet;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import br.ufpr.mityba.controller.GerenteConsultaPaciente;
import br.ufpr.mityba.controller.GerenteConsultaUsuario;
import br.ufpr.mityba.dao.AuditLogDAO;
import br.ufpr.mityba.dao.PacienteDAO;
import br.ufpr.mityba.dao.UsuarioDAO;
import br.ufpr.mityba.model.AuditLog;
import br.ufpr.mityba.model.Paciente;
import br.ufpr.mityba.model.Usuario;
import br.ufpr.mityba.util.Constantes;
import br.ufpr.mityba.util.ControlePrincipal;

/**
 * Servlet implementation class for Servlet: ServletLogin
 * 
 * @author Mityba
 * @since 06/09/2008
 * @version 1.0.1 17/10/2008
 * @version 1.0.2 13/11/2008
 */

 public class ServletLogin extends HttpServlet implements Servlet {
	 
   static final long serialVersionUID = 132432L;
   
   /**
	 * @param pReq 
	 * @param pResp 
	 * @throws ServletException 
	 * @throws IOException 
	 * 
	 */
   public void service(HttpServletRequest pReq, HttpServletResponse pResp)	throws ServletException, IOException {
	   
		Vector<String> tErro = new Vector<String>();
		
		HttpSession session = null;

		String service = pReq.getParameter("service");
		
		if (service == null || service.equals("")) {

			tErro.add("Informar a ao a ser executada\n");

		} else if (service.equals("Entrar")) {
			
			//-----  Trava contra sql injections
			
			String loginUsuario	= pReq.getParameter("login").replace(";", "").replace("'", "");
			String senhaUsuario	= pReq.getParameter("senha").replace(";", "").replace("'", "");
			
			//----------------------------------
			
			ControlePrincipal controle = new ControlePrincipal();
			
			int idUsuario = new UsuarioDAO(controle).procuraUsuario(loginUsuario, senhaUsuario);
			
			if (idUsuario > 0){
				
				GerenteConsultaUsuario.usuarioPorCodigo(controle, idUsuario);
				
				Usuario user = controle.getUsuarios().get(0);
				
				session = pReq.getSession(true);
				session.setAttribute(Constantes.ATRIB_ID_USUARIO_LOGADO	, user.getIdUsuario());
				session.setAttribute(Constantes.ATRIB_USUARIO_LOGADO	, user.getLoginUsuario());
				session.setAttribute(Constantes.ATRIB_IP_LOGADO			, pReq.getRemoteAddr());
				session.setAttribute(Constantes.ATRIB_ACESSO_CADASTRO	, user.getCadastroUsuario());
				session.setAttribute(Constantes.ATRIB_ACESSO_FINANCEIRO	, user.getFinanceiroUsuario());
				session.setAttribute(Constantes.ATRIB_ACESSO_AGENDA		, user.getAgendaUsuario());
				session.setAttribute(Constantes.ATRIB_TIPO_ACESSO		, user.getTpAcessoUsuario());
				session.setAttribute(Constantes.ATRIB_DT_INI_SESSAO		, Constantes.HORA_ATUAL());
				
				ativarPagina(pReq, pResp, "/PaginaInicial.jsp");
			
			} else {
				
				int idPaciente = new PacienteDAO(controle).procuraUsuario(loginUsuario, senhaUsuario);
				
				if (idPaciente > 0){
					
					GerenteConsultaPaciente.pacientePorCodigo(controle, idPaciente);
					
					Paciente user = controle.getPacientes().get(0);
					
					session = pReq.getSession(true);
					session.setAttribute(Constantes.ATRIB_ID_USUARIO_LOGADO	, user.getIdPaciente());
					session.setAttribute("Nome"								, user.getNome());
					session.setAttribute("ContaUsuario"						, "conta: " + user.getEmail());
					session.setAttribute("DataLogin"						, Constantes.HORA_ATUAL().substring(0, 19));
					
					ativarPagina(pReq, pResp, "/user_home.jsp");
				
				} else {

					tErro.add("Login e senha incorretos!");
				}
			}
			
		} else if (service.equals("Logout")) {
			
			session = pReq.getSession(true);
			
			String loginUsuario = (String) session.getAttribute(Constantes.ATRIB_USUARIO_LOGADO);
			String ipUsuario 	= (String) session.getAttribute(Constantes.ATRIB_IP_LOGADO);
			String dataIni		= (String) session.getAttribute(Constantes.ATRIB_DT_INI_SESSAO);
			
			AuditLog audit		= new AuditLog(0, loginUsuario, ipUsuario, dataIni, Constantes.HORA_ATUAL(), Constantes.COD_SESSAO_ATIVA);
			
			new AuditLogDAO().incluiRegistro(audit);
			
			session.invalidate();
			
			pReq.setAttribute("pagina", "index.jsp");
			
			ativarPagina(pReq, pResp, "/redirecionar.jsp");
			
		}
		
		if(tErro.size() > 0){
			
			mostrarErro(pReq, pResp, tErro, "/index.jsp");
		}
   }

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param pErro
	 * @param pPag
	 * @throws ServletException
	 * @throws IOException
	 */

   private void mostrarErro(HttpServletRequest pReq, HttpServletResponse pResp, Vector<String> pErro, String pPag) throws ServletException, IOException {

		pReq.setAttribute("Erros", pErro);

		ativarPagina(pReq, pResp, pPag);
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param pPagina
	 * @throws ServletException
	 * @throws IOException
	 */

	private void ativarPagina(HttpServletRequest pReq, HttpServletResponse pResp, String pPagina) throws ServletException, IOException {

		ServletContext tContexto 		= getServletContext();
		RequestDispatcher tDespachante 	= tContexto.getRequestDispatcher(pPagina);
		tDespachante.forward(pReq, pResp);
	}
}