package br.ufpr.mityba.servlets;

import java.io.IOException;
import java.util.Vector;

import javax.servlet.RequestDispatcher;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import br.ufpr.mityba.controller.GerenteConsultaMedicamento;
import br.ufpr.mityba.controller.GerenteConsultaNomeGenerico;
import br.ufpr.mityba.dao.AuditLogDAO;
import br.ufpr.mityba.dao.MedicamentoDAO;
import br.ufpr.mityba.dao.NomeGenericoDAO;
import br.ufpr.mityba.model.AuditLog;
import br.ufpr.mityba.model.Medicamento;
import br.ufpr.mityba.model.NomeGenerico;
import br.ufpr.mityba.util.Constantes;
import br.ufpr.mityba.util.ControlePrincipal;

/**
 * Servlet implementation class ServletMedicamento
 * 
 * @author Mityba
 * @since 12/11/2008
 * @version 1.0 12/11/2008
 */
public class ServletMedicamento extends HttpServlet {

	static final long serialVersionUID = 1322132L;

	/**
	 * @param pReq 
	 * @param pResp 
	 * @throws ServletException 
	 * @throws IOException 
	 * 
	 */
	public void service(final HttpServletRequest pReq, final HttpServletResponse pResp) throws ServletException, IOException {

		Vector<String> tErro = new Vector<String>();

		HttpSession session = pReq.getSession(false);

		String service = pReq.getParameter("service");

		if (session == null) {

			tErro.add("Voc deve efetuar o login antes de acessar essa funcionalidade!");

		} else {

			if (service == null || service.equals("")) {

				tErro.add("Informar a ao a ser executada\n");

			} else if (service.equals("cadastroMedicamentos")) {
				
				if((Integer) session.getAttribute(Constantes.ATRIB_ACESSO_CADASTRO) == 3){

					session.setAttribute(Constantes.ATRIB_DT_INI_CAD_MEDICAMENTO, Constantes.HORA_ATUAL());
	
					ativarPagina(pReq, pResp, "/cadastroMedicamento.jsp");	
				
				} else {
					
					tErro.add("Voc no tem o nvel de privilgio necessrio para acessar essa funcionalidade");
				}
				
			} else if (service.equals("pesquisarMedicamentos")) {
				
				if((Integer) session.getAttribute(Constantes.ATRIB_ACESSO_CADASTRO) >= 2){
				
					ativarPagina(pReq, pResp, "/consultaMedicamento.jsp");
				
				} else {
					
					tErro.add("Voc no tem o nvel de privilgio necessrio para acessar essa funcionalidade");
				}
				
			} else if (service.equals("pesquisaPorNome")) {
				
				acaoPesquisarMedicamento(pReq, pResp, true);
				
			} else if (service.equals("pesquisaPorIndicacao")) {
				
				acaoPesquisarMedicamento(pReq, pResp, false);
				
			} else if (service.equals("salvarCadastro")) {
				
				acaoSalvarCadastro(pReq, pResp, session);
				
			} else if (service.equals("salvarAlteracao")) {
				
				acaoSalvarAlteracao(pReq, pResp, session);
				
			} else if (service.equals("adicionarNome")) {
				
				acaoAdicionarNome(pReq, pResp);
				
			} else if (service.equals("removerNome")) {
				
				acaoRemoverNome(pReq, pResp);
				
			} else if (service.equals("excluir")) {
				
				acaoExclusaoConfirmada(pReq, pResp, session);
				
			} else if (service.equals("exibirMedicamento")) {
				
				if((Integer) session.getAttribute(Constantes.ATRIB_ACESSO_CADASTRO) == 3){
					
					session.setAttribute(Constantes.ATRIB_DT_INI_ALT_MEDICAMENTO, Constantes.HORA_ATUAL());
					session.setAttribute(Constantes.ATRIB_DT_INI_EXC_MEDICAMENTO, Constantes.HORA_ATUAL());
					
					acaoExibirMedicamento(pReq, pResp);
				
				} else {
					
					tErro.add("Voc no tem o nvel de privilgio necessrio para acessar essa funcionalidade");
				}
				
			} else if (service.equals("excluir")) {
				
				acaoExclusaoConfirmada(pReq, pResp, session);
	
			} else if (service.equals("voltarConsultaMedicamento")) {
				
				ativarPagina(pReq, pResp, "/consultaMedicamento.jsp");

			} else if (service.equals("voltaTela")) {

				ativarPagina(pReq, pResp, "/PaginaInicial.jsp");
			}
		}

		if (tErro.size() > 0) {
			mostrarErro(pReq, pResp, tErro, "/PaginaInicial.jsp");
		}
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param pErro
	 * @param pPag
	 * @throws ServletException
	 * @throws IOException
	 */

	private void mostrarErro(HttpServletRequest pReq, HttpServletResponse pResp, Vector<String> pErro, String pPag) throws ServletException, IOException {
		pReq.setAttribute("Erros", pErro);
		ativarPagina(pReq, pResp, pPag);
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param pPagina
	 * @throws ServletException
	 * @throws IOException
	 */

	private void ativarPagina(HttpServletRequest pReq, HttpServletResponse pResp, String pPagina) throws ServletException, IOException {
		ServletContext tContexto 		= getServletContext();
		RequestDispatcher tDespachante 	= tContexto.getRequestDispatcher(pPagina);
		tDespachante.forward(pReq, pResp);
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoSalvarCadastro(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {
		
		Vector<String> tErro				= new Vector<String>();
		
		Vector<NomeGenerico> nomesGenericos	= null;
		
		ControlePrincipal controle			= new ControlePrincipal();
		
		String nomeComercialDigitado 		= pReq.getParameter("nomeComercial");
		String principioAtivoDigitado		= pReq.getParameter("principioAtivo");
		String indicaocaoDigitado			= pReq.getParameter("indicacao");
		String contraIndicacaoDigitado		= pReq.getParameter("contraIndicacao");
		String instrucoesIngestaoDigitado	= pReq.getParameter("instrucoesIngestao");
		String efeitosColateraisDigitado	= pReq.getParameter("efeitosColaterais");
		String alteracoesSanguineasDigitado	= pReq.getParameter("alteracoesSanguineas");
		String cuidadosGestacaoDigitado		= pReq.getParameter("cuidadosGestacao");
		String interacaoDietaDigitado 		= pReq.getParameter("interacaoDieta");
		String precaucoesDigitado 			= pReq.getParameter("precaucoes");
		String alteracoesDiversasDigitado 	= pReq.getParameter("alteracoesDiversas");
		String outrasOrientacoesDigitado	= pReq.getParameter("outrasOrientacoes");
		
		if(nomeComercialDigitado == null || nomeComercialDigitado.equals(""))
			tErro.add("O campo nome comercial deve ser preenchido!");
		
		if(tErro.size() > 0){
			mostrarErro(pReq, pResp, tErro, "/cadastroMedicamento.jsp");
			
		} else {
			
			Medicamento medicamento = new Medicamento(
					0,
					nomeComercialDigitado,
					principioAtivoDigitado,
					indicaocaoDigitado,
					contraIndicacaoDigitado,
					instrucoesIngestaoDigitado,
					efeitosColateraisDigitado,
					alteracoesSanguineasDigitado,
					cuidadosGestacaoDigitado,
					interacaoDietaDigitado,
					precaucoesDigitado,
					alteracoesDiversasDigitado,
					outrasOrientacoesDigitado
			);
			
			if(new MedicamentoDAO().incluiMedicamento(medicamento)){
				
				if(GerenteConsultaNomeGenerico.nomeGenericoPorCodigoMedicamento(controle, 0)){

					nomesGenericos = controle.getNomesGenericos();
					
					NomeGenericoDAO nomeGenerico = new NomeGenericoDAO();
					
					for(int i = 0; i < nomesGenericos.size(); i++){
						nomesGenericos.get(i).setIdMedicamento(new MedicamentoDAO().maxIdMedicamento());
						nomeGenerico.alteraNomeGenerico(nomesGenericos.get(i));
					}
				}
				
				String loginUsuario = (String) session.getAttribute(Constantes.ATRIB_USUARIO_LOGADO);
				String ipUsuario 	= (String) session.getAttribute(Constantes.ATRIB_IP_LOGADO);
				String dtIni 		= (String) session.getAttribute(Constantes.ATRIB_DT_INI_CAD_MEDICAMENTO);
				
				AuditLog audit 		= new AuditLog(0, loginUsuario, ipUsuario, dtIni, Constantes.HORA_ATUAL(), Constantes.COD_CADASTRO_MEDICAMENTO);
				
				new AuditLogDAO().incluiRegistro(audit);
				
				pReq.setAttribute("Msg", "Medicamento cadastrado com sucesso");
				
				session.setAttribute(Constantes.ATRIB_DT_INI_CAD_MEDICAMENTO, Constantes.HORA_ATUAL());
				
			} else {
				
				pReq.setAttribute("Msg", "Problemas ao cadastrar o medicamento");
			}
			
			ativarPagina(pReq, pResp, "/cadastroMedicamento.jsp");
		}
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoSalvarAlteracao(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {
		
		Vector<String> tErro				= new Vector<String>();
		
		Vector<NomeGenerico> nomesGenericos	= null;
		
		ControlePrincipal controle			= new ControlePrincipal();
		
		String nomeComercialDigitado 		= pReq.getParameter("nomeComercial");
		String principioAtivoDigitado		= pReq.getParameter("principioAtivo");
		String indicacaoDigitado			= pReq.getParameter("indicacao");
		String contraIndicacaoDigitado		= pReq.getParameter("contraIndicacao");
		String instrucoesIngestaoDigitado	= pReq.getParameter("instrucoesIngestao");
		String efeitosColateraisDigitado	= pReq.getParameter("efeitosColaterais");
		String alteracoesSanguineasDigitado	= pReq.getParameter("alteracoesSanguineas");
		String cuidadosGestacaoDigitado		= pReq.getParameter("cuidadosGestacao");
		String interacaoDietaDigitado 		= pReq.getParameter("interacaoDieta");
		String precaucoesDigitado 			= pReq.getParameter("precaucoes");
		String alteracoesDiversasDigitado 	= pReq.getParameter("alteracoesDiversas");
		String outrasOrientacoesDigitado	= pReq.getParameter("outrasOrientacoes");
		
		int codigoDigitado 					= 0;
		
		try{
			codigoDigitado					= Integer.parseInt(pReq.getParameter("codMedicamento"));
		}catch (NumberFormatException e) {
			codigoDigitado 					= 0;
		}
		
		if(nomeComercialDigitado == null || nomeComercialDigitado.equals(""))
			tErro.add("O campo nome comercial deve ser preenchido!");
		
		if(tErro.size() > 0){
			mostrarErro(pReq, pResp, tErro, "/visualizacaoMedicamento.jsp");
			
		} else {
			
			Medicamento medicamento = new Medicamento(
					codigoDigitado,
					nomeComercialDigitado,
					principioAtivoDigitado,
					indicacaoDigitado,
					contraIndicacaoDigitado,
					instrucoesIngestaoDigitado,
					efeitosColateraisDigitado,
					alteracoesSanguineasDigitado,
					cuidadosGestacaoDigitado,
					interacaoDietaDigitado,
					precaucoesDigitado,
					alteracoesDiversasDigitado,
					outrasOrientacoesDigitado
			);
			
			if(new MedicamentoDAO().alteraMedicamento(medicamento)){
				
				if(GerenteConsultaNomeGenerico.nomeGenericoPorCodigoMedicamento(controle, 0)){

					nomesGenericos = controle.getNomesGenericos();
					
					NomeGenericoDAO nomeGenerico = new NomeGenericoDAO();
					
					for(int i = 0; i < nomesGenericos.size(); i++){
						nomesGenericos.get(i).setIdMedicamento(codigoDigitado);
						nomeGenerico.alteraNomeGenerico(nomesGenericos.get(i));
					}
				}
				
				String loginUsuario = (String) session.getAttribute(Constantes.ATRIB_USUARIO_LOGADO);
				String ipUsuario 	= (String) session.getAttribute(Constantes.ATRIB_IP_LOGADO);
				String dtIni 		= (String) session.getAttribute(Constantes.ATRIB_DT_INI_ALT_MEDICAMENTO);
				
				AuditLog audit 		= new AuditLog(0, loginUsuario, ipUsuario, dtIni, Constantes.HORA_ATUAL(), Constantes.COD_ALTERACAO_MEDICAMENTO);
				
				new AuditLogDAO().incluiRegistro(audit);
				
				pReq.setAttribute("Msg", "Medicamento alterado com sucesso");				
				
			} else {
				
				pReq.setAttribute("Msg", "Problemas ao alterar o medicamento");
			}
			
			ativarPagina(pReq, pResp, "/consultaMedicamento.jsp");
		}
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoPesquisarMedicamento(HttpServletRequest pReq, HttpServletResponse pResp, boolean eNome) throws ServletException, IOException {
		
		ControlePrincipal controle = new ControlePrincipal();

		Vector<String> nomesGenericosMedicamentos 	= new Vector<String>();

		Vector<Integer> evitaRepeticoes 			= new Vector<Integer>();

		Vector<NomeGenerico> nomesGenericos;
		
		Vector<Medicamento> medicamentos;
		Vector<Medicamento> aux;
		
		String campo = "";
		
		if(eNome){
			
			campo = pReq.getParameter("nome");
			pReq.setAttribute("Nome", campo);
			
			if(GerenteConsultaMedicamento.medicamentoPorNome(controle, campo)
			&& GerenteConsultaNomeGenerico.nomeGenericoPorNome(controle, campo)){
				
				medicamentos = controle.getMedicamentos();
				
				for(int i = 0; i < medicamentos.size(); i++)
					evitaRepeticoes.add(medicamentos.get(i).getIdMedicamento());
				
				nomesGenericos = controle.getNomesGenericos();
				
				//-------------------- Evita repeties na pesquisa por nome comercial e genrico
				
				for(int i = 0; i < nomesGenericos.size(); i++){
					if(GerenteConsultaMedicamento.medicamentoPorCodigo(controle, nomesGenericos.get(i).getIdMedicamento())){
						aux = controle.getMedicamentos();
						for(int j = 0; j < aux.size(); j++){
							for(int k = 0; k < evitaRepeticoes.size(); k++){
								if(aux.get(j).getIdMedicamento() == evitaRepeticoes.get(k)){
									aux.removeElementAt(j);
									break;
								}
							}
						}
						for(int j = 0; j < aux.size(); j++){
							medicamentos.add(aux.get(j));
						}
					}
				}
				
				nomesGenericos.removeAllElements();
				
				StringBuffer nomes;
				
				//---------------------------- Agregando nomes genricos
				
				for(int i = 0; i < medicamentos.size(); i++){
					nomes = new StringBuffer(" ");
					if(GerenteConsultaNomeGenerico.nomeGenericoPorCodigoMedicamento(controle, medicamentos.get(i).getIdMedicamento())){
						nomesGenericos = controle.getNomesGenericos();
						for(int j = 0; j < nomesGenericos.size(); j++){
							nomes.append(nomesGenericos.get(j).getDescrGenerico());
							if(j != (nomesGenericos.size() - 1))
								nomes.append(", ");
						}
						nomesGenericosMedicamentos.add(nomes.toString());
					}
				}

				pReq.setAttribute("Medicamentos"	, medicamentos);
				pReq.setAttribute("NomesGenericos"	, nomesGenericosMedicamentos);
			
			} else {
				
				pReq.setAttribute("Msg", "Problemas ao realizar consulta de medicamentos");
			}
			
		} else {
			
			campo = pReq.getParameter("indicacao");
			pReq.setAttribute("Indicacao", campo);
			
			if(GerenteConsultaMedicamento.medicamentoPorIndicacao(controle, campo)){
				
				medicamentos = controle.getMedicamentos();
				
				StringBuffer nomes;
				
				//---------------------------- Agregando nomes genricos
				
				for(int i = 0; i < medicamentos.size(); i++){
					nomes = new StringBuffer(" ");
					if(GerenteConsultaNomeGenerico.nomeGenericoPorCodigoMedicamento(controle, medicamentos.get(i).getIdMedicamento())){
						nomesGenericos = controle.getNomesGenericos();
						for(int j = 0; j < nomesGenericos.size(); j++){
							nomes.append(nomesGenericos.get(j).getDescrGenerico());
							if(j != (nomesGenericos.size() - 1))
								nomes.append(", ");
						}
						nomesGenericosMedicamentos.add(nomes.toString());
					}
				}

				pReq.setAttribute("Medicamentos"	, medicamentos);
				pReq.setAttribute("NomesGenericos"	, nomesGenericosMedicamentos);
			
			} else {
				
				pReq.setAttribute("Msg", "Problemas ao realizar consulta de medicamentos");
			}
		}

		ativarPagina(pReq, pResp, "/consultaMedicamento.jsp");
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoExibirMedicamento(HttpServletRequest pReq, HttpServletResponse pResp) throws ServletException, IOException {

		ControlePrincipal controle	= new ControlePrincipal();

		Medicamento medicamento		= null;

		int codMedicamento			= 0;

		try{
			codMedicamento			= Integer.parseInt(pReq.getParameter("codMedicamento"));
		}catch (NumberFormatException e) {
			codMedicamento			= 0;
		}

		if(GerenteConsultaMedicamento.medicamentoPorCodigo(controle, codMedicamento)){

			medicamento = controle.getMedicamentos().get(0);

			pReq.setAttribute("CodMedicamento"			, String.valueOf(medicamento.getIdMedicamento()));
			pReq.setAttribute("NomeComercial"			, medicamento.getNomeComercialMedicamento());
			pReq.setAttribute("PrincipioAtivo"			, medicamento.getPrincipioAtivoMedicamento());
			pReq.setAttribute("Indicacao"				, medicamento.getIndicacaoMedicamento());
			pReq.setAttribute("ContraIndicacao"			, medicamento.getContraIndicacaoMedicamento());
			pReq.setAttribute("InstrucoesIngestao"		, medicamento.getInstrucoesIngestaoMedicamento());
			pReq.setAttribute("EfeitosColaterais"		, medicamento.getEfeitosColateraisMedicamento());
			pReq.setAttribute("AlteracoesSanguineas"	, medicamento.getAlteracoesSanguineasMedicamento());
			pReq.setAttribute("CuidadosGestacao"		, medicamento.getCuidadosGestacaoMedicamento());
			pReq.setAttribute("InteracaoDieta"			, medicamento.getInteracaoDietaMedicamento());
			pReq.setAttribute("Precaucoes"				, medicamento.getPrecaucoesMedicamento());
			pReq.setAttribute("AlteracoesDiversas"		, medicamento.getAlteracoesDiversasMedicamento());
			pReq.setAttribute("OutrasOrientacoes"		, medicamento.getOutrasOrientacoesMedicamento());
			
			if (GerenteConsultaNomeGenerico.nomeGenericoPorCodigoMedicamento(controle, medicamento.getIdMedicamento()))			
				pReq.setAttribute("NomesGenericos"		, controle.getNomesGenericos());
		
		} else {
			
			pReq.setAttribute("Msg", "Problemas ao carregar os dados do medicamento");
		}
			
		ativarPagina(pReq, pResp, "/visualizacaoMedicamento.jsp");
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoAdicionarNome(HttpServletRequest pReq, HttpServletResponse pResp) throws ServletException, IOException {
		
		ControlePrincipal controle 			= new ControlePrincipal();
		
		boolean eCadastro 					= pReq.getParameter("eCadastro").equals("sim");
		
		int codMedicamento 					= eCadastro ? 0 : Integer.parseInt(pReq.getParameter("codMedicamento"));

		String nomeComercialDigitado		= pReq.getParameter("nomeComercial");
		String nomeGenericoDigitado			= pReq.getParameter("nomeGenerico");
		String principioAtivoDigitado		= pReq.getParameter("principioAtivo");
		String indicacaoDigitado			= pReq.getParameter("indicacao");
		String contraIndicacaoDigitado		= pReq.getParameter("contraIndicacao");
		String instrucoesIngestaoDigitado	= pReq.getParameter("instrucoesIngestao");
		String efeitosColateraisDigitado	= pReq.getParameter("efeitosColaterais");
		String alteracoesSanguineasDigitado	= pReq.getParameter("alteracoesSanguineas");
		String cuidadosGestacaoDigitado		= pReq.getParameter("cuidadosGestacao");
		String interacaoDietaDigitado		= pReq.getParameter("interacaoDieta");
		String precaucoesDigitado			= pReq.getParameter("precaucoes");
		String alteracoesDiversasDigitado	= pReq.getParameter("alteracoesDiversas");
		String outrasOrientacoesDigitado	= pReq.getParameter("outrasOrientacoes");
		
		NomeGenerico nomeGenerico = new NomeGenerico(
				0,
				codMedicamento,
				nomeGenericoDigitado
		);

		if(new NomeGenericoDAO().incluiNomeGenerico(nomeGenerico)){

			pReq.setAttribute("CodMedicamento"			, String.valueOf(codMedicamento));
			pReq.setAttribute("NomeComercial"			, nomeComercialDigitado);
			pReq.setAttribute("PrincipioAtivo"			, principioAtivoDigitado);
			pReq.setAttribute("Indicacao"				, indicacaoDigitado);
			pReq.setAttribute("ContraIndicacao"			, contraIndicacaoDigitado);
			pReq.setAttribute("InstrucoesIngestao"		, instrucoesIngestaoDigitado);
			pReq.setAttribute("EfeitosColaterais"		, efeitosColateraisDigitado);
			pReq.setAttribute("AlteracoesSanguineas"	, alteracoesSanguineasDigitado);
			pReq.setAttribute("CuidadosGestacao"		, cuidadosGestacaoDigitado);
			pReq.setAttribute("InteracaoDieta"			, interacaoDietaDigitado);
			pReq.setAttribute("Precaucoes"				, precaucoesDigitado);
			pReq.setAttribute("AlteracoesDiversas"		, alteracoesDiversasDigitado);
			pReq.setAttribute("OutrasOrientacoes"		, outrasOrientacoesDigitado);

			if (GerenteConsultaNomeGenerico.nomeGenericoPorCodigoMedicamento(controle, codMedicamento))			
				pReq.setAttribute("NomesGenericos"		, controle.getNomesGenericos());
			
		} else {
			
			pReq.setAttribute("Msg", "Problemas ao cadastrar nome genrico");
		}
		
		ativarPagina(pReq, pResp, eCadastro ? "/cadastroMedicamento.jsp" : "/visualizacaoMedicamento.jsp");
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoRemoverNome(HttpServletRequest pReq, HttpServletResponse pResp) throws ServletException, IOException {
		
		ControlePrincipal controle			= new ControlePrincipal();
		
		boolean eCadastro 					= pReq.getParameter("eCadastro").equals("sim");

		int codNomeGenerico 				= Integer.parseInt(pReq.getParameter("codNomeGenerico"));
		int codMedicamento 					= eCadastro ? 0 : Integer.parseInt(pReq.getParameter("codMedicamento"));
		
		String nomeComercialDigitado		= pReq.getParameter("nomeComercial");
		String principioAtivoDigitado		= pReq.getParameter("principioAtivo");
		String indicacaoDigitado			= pReq.getParameter("indicacao");
		String contraIndicacaoDigitado		= pReq.getParameter("contraIndicacao");
		String instrucoesIngestaoDigitado	= pReq.getParameter("instrucoesIngestao");
		String efeitosColateraisDigitado	= pReq.getParameter("efeitosColaterais");
		String alteracoesSanguineasDigitado	= pReq.getParameter("alteracoesSanguineas");
		String cuidadosGestacaoDigitado		= pReq.getParameter("cuidadosGestacao");
		String interacaoDietaDigitado		= pReq.getParameter("interacaoDieta");
		String precaucoesDigitado			= pReq.getParameter("precaucoes");
		String alteracoesDiversasDigitado	= pReq.getParameter("alteracoesDiversas");
		String outrasOrientacoesDigitado	= pReq.getParameter("outrasOrientacoes");
				
		if(new NomeGenericoDAO().excluiNomeGenerico(codNomeGenerico)){
			
			pReq.setAttribute("CodMedicamento"			, String.valueOf(codMedicamento));
			pReq.setAttribute("NomeComercial"			, nomeComercialDigitado);
			pReq.setAttribute("PrincipioAtivo"			, principioAtivoDigitado);
			pReq.setAttribute("Indicacao"				, indicacaoDigitado);
			pReq.setAttribute("ContraIndicacao"			, contraIndicacaoDigitado);
			pReq.setAttribute("InstrucoesIngestao"		, instrucoesIngestaoDigitado);
			pReq.setAttribute("EfeitosColaterais"		, efeitosColateraisDigitado);
			pReq.setAttribute("AlteracoesSanguineas"	, alteracoesSanguineasDigitado);
			pReq.setAttribute("CuidadosGestacao"		, cuidadosGestacaoDigitado);
			pReq.setAttribute("InteracaoDieta"			, interacaoDietaDigitado);
			pReq.setAttribute("Precaucoes"				, precaucoesDigitado);
			pReq.setAttribute("AlteracoesDiversas"		, alteracoesDiversasDigitado);
			pReq.setAttribute("OutrasOrientacoes"		, outrasOrientacoesDigitado);

			if (GerenteConsultaNomeGenerico.nomeGenericoPorCodigoMedicamento(controle, codMedicamento))			
				pReq.setAttribute("NomesGenericos"		, controle.getNomesGenericos());
		
		} else {
			
			pReq.setAttribute("Msg", "Problemas ao remover nome genrico");
		}
		
		ativarPagina(pReq, pResp, eCadastro ? "/cadastroMedicamento.jsp" : "/visualizacaoMedicamento.jsp");
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoExclusaoConfirmada(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {
		
		int codMedicamento = Integer.parseInt(pReq.getParameter("codMedicamento"));
		
		new NomeGenericoDAO().excluiNomeGenericoPorMedicamento(codMedicamento);
		
		if (new MedicamentoDAO().excluiMedicamento(codMedicamento)){
			
			String loginUsuario = (String) session.getAttribute(Constantes.ATRIB_USUARIO_LOGADO);
			String ipUsuario 	= (String) session.getAttribute(Constantes.ATRIB_IP_LOGADO);
			String dtIni 		= (String) session.getAttribute(Constantes.ATRIB_DT_INI_EXC_MEDICAMENTO);
			
			AuditLog audit 		= new AuditLog(0, loginUsuario, ipUsuario, dtIni, Constantes.HORA_ATUAL(), Constantes.COD_EXCLUSAO_MEDICAMENTO);
			
			new AuditLogDAO().incluiRegistro(audit);
			
			pReq.setAttribute("Msg", "Medicamento excludo com sucesso");
	
		} else {				
		
			pReq.setAttribute("Msg", "Problemas ao remover medicamento");
		
		}
		
		ativarPagina(pReq, pResp, "/consultaMedicamento.jsp");
	}	
}