package br.ufpr.mityba.servlets;

import java.io.IOException;
import java.util.Vector;

import javax.servlet.RequestDispatcher;
import javax.servlet.Servlet;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import br.ufpr.mityba.controller.GerenteConsultaConvenio;
import br.ufpr.mityba.controller.GerenteConsultaEndereco;
import br.ufpr.mityba.controller.GerenteConsultaPaciente;
import br.ufpr.mityba.controller.GerenteConsultaProfissao;
import br.ufpr.mityba.dao.AuditLogDAO;
import br.ufpr.mityba.dao.PacienteDAO;
import br.ufpr.mityba.dao.ProfissaoDAO;
import br.ufpr.mityba.model.AuditLog;
import br.ufpr.mityba.model.Endereco;
import br.ufpr.mityba.model.Paciente;
import br.ufpr.mityba.model.Profissao;
import br.ufpr.mityba.util.Constantes;
import br.ufpr.mityba.util.ControlePrincipal;


/**
 * Servlet implementation class for Servlet: ServletPaciente
 * 
 * @author Mityba
 * @since 20/10/2008
 * @version 1.0 20/10/2008
 * @version 2.0 31/10/2008
 */
public class ServletPaciente extends HttpServlet implements Servlet {
	 
   static final long serialVersionUID = 13242132L;
   
   /**
    * @param pReq 
    * @param pResp 
    * @throws ServletException 
    * @throws IOException 
    * 
    */
   
   public void service(HttpServletRequest pReq, HttpServletResponse pResp)	throws ServletException, IOException {
	   
		Vector<String> tErro = new Vector<String>();
		
		HttpSession session = pReq.getSession(false);
		
		String service = pReq.getParameter("service");
		
		if (session == null){
			
			tErro.add("Voc deve efetuar o login antes de acessar essa funcionalidade!");
			
		} else {
		
			if (service == null || service.equals("")) {
	
				tErro.add("Informar a ao a ser executada\n");
				
			} else if (service.equals("procurarEndereco")) {
				
				acaoProcurarEndereco(pReq, pResp);
				
			} else if (service.equals("pesquisarPacientes")) {
				
				if((Integer) session.getAttribute(Constantes.ATRIB_ACESSO_CADASTRO) >= 2){
				
					ativarPagina(pReq, pResp, "/consultaPaciente.jsp");
				
				} else {
					
					tErro.add("Voc no tem o nvel de privilgio necessrio para acessar essa funcionalidade");
				}
				
			} else if (service.equals("pesquisaPorDtNasc")) {
				
				acaoPesquisarPaciente(pReq, pResp, false);
				
			} else if (service.equals("pesquisaPorNome")) {
				
				acaoPesquisarPaciente(pReq, pResp, true);
				
			} else if (service.equals("exibirPaciente")) {
				
				if((Integer) session.getAttribute(Constantes.ATRIB_ACESSO_CADASTRO) == 3){

					session.setAttribute(Constantes.ATRIB_DT_INI_ALT_PACIENTE, Constantes.HORA_ATUAL());
					session.setAttribute(Constantes.ATRIB_DT_INI_EXC_PACIENTE, Constantes.HORA_ATUAL());
					
					acaoExibirPaciente(pReq, pResp);
				
				} else {
					
					tErro.add("Voc no tem o nvel de privilgio necessrio para acessar essa funcionalidade");
				}
				
			} else if (service.equals("cadastroPacientes")) {
				
				if((Integer) session.getAttribute(Constantes.ATRIB_ACESSO_CADASTRO) >= 3){
				
					acaoAtivarPaginaCadastro(pReq, pResp, session);
				
				} else {
					
					tErro.add("Voc no tem o nvel de privilgio necessrio para acessar essa funcionalidade");
				}
				
			} else if (service.equals("salvarNovaProfissao")) {
				
				acaoNovaProfissao(pReq, pResp);
				
			} else if (service.equals("salvarCadastro")) {
				
				acaoCadastrarPaciente(pReq, pResp, session);
				
			} else if (service.equals("salvarAlteracao")) {
				
				acaoAlterarPaciente(pReq, pResp, session);
				
			} else if (service.equals("confirmaExclusao")) {
				
				acaoExclusaoConfirmada(pReq, pResp, session);
	
			} else if (service.equals("voltarConsultaPaciente")) {
				
				ativarPagina(pReq, pResp, "/consultaPaciente.jsp");
	
			} else if (service.equals("voltaTela")) {
				
				ativarPagina(pReq, pResp, "/PaginaInicial.jsp");
			}
		}
		
		if (tErro.size() > 0){		
			mostrarErro(pReq, pResp, tErro, "/PaginaInicial.jsp");
		}
   }

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param pErro
	 * @param pPag
	 * @throws ServletException
	 * @throws IOException
	 */

	private void mostrarErro(HttpServletRequest pReq, HttpServletResponse pResp, Vector<String> pErro, String pPag) throws ServletException, IOException {

		pReq.setAttribute("Erros", pErro);

		ativarPagina(pReq, pResp, pPag);
	}

	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param pPagina
	 * @throws ServletException
	 * @throws IOException
	 */

	private void ativarPagina(HttpServletRequest pReq, HttpServletResponse pResp, String pPagina) throws ServletException, IOException {

		ServletContext tContexto 		= getServletContext();
		RequestDispatcher tDespachante 	= tContexto.getRequestDispatcher(pPagina);
		tDespachante.forward(pReq, pResp);
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param eNome
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoPesquisarPaciente(HttpServletRequest pReq, HttpServletResponse pResp, boolean eNome) throws ServletException, IOException {
		
		ControlePrincipal controle = new ControlePrincipal();
		
		Vector<Paciente> pacientes;
		
		String campo = "";
		
		boolean ativos = false;
		
		String apenasAtivos = pReq.getParameter("apenasAtivos");
		
		if(apenasAtivos != null && apenasAtivos.equals("sim")){
			ativos = true;			
			pReq.setAttribute("apenasAtivos", "sim");
		}
		
		if(eNome){
			
			campo = pReq.getParameter("nome");
			pReq.setAttribute("Nome", campo);
			
			if(GerenteConsultaPaciente.pacientePorNome(controle, campo, ativos)){
				
				pacientes = controle.getPacientes();
				
				pReq.setAttribute("Pacientes", pacientes);
			
			} else {
				
				pReq.setAttribute("Msg", "Problemas ao realizar consulta de pacientes");
			}
			
		}else{
			
			campo = pReq.getParameter("dtNasc");
			pReq.setAttribute("DtNasc", campo);
			
			if(GerenteConsultaPaciente.pacientePorNascimento(controle, campo, ativos)){
				
				pacientes = controle.getPacientes();
				
				pReq.setAttribute("Pacientes", pacientes);
			
			} else {
				
				pReq.setAttribute("Msg", "Problemas ao realizar consulta de pacientes");
			}
		}

		ativarPagina(pReq, pResp, "/consultaPaciente.jsp");
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoProcurarEndereco(HttpServletRequest pReq, HttpServletResponse pResp) throws ServletException, IOException {
		
		Vector<String> tErro = new Vector<String>();

		String codPacienteDigitado 	= pReq.getParameter("codPaciente");
		String nomeDigitado 		= pReq.getParameter("nome");
		String dtNascDigitado 		= pReq.getParameter("dtNasc");
		String idadeDigitado		= pReq.getParameter("idade");
		String sexoDigitado 		= pReq.getParameter("sexo");
		String ativoDigitado 		= pReq.getParameter("ativo");
		String estadoCivilDigitado 	= pReq.getParameter("estadoCivil");
		String profissaoDigitado 	= pReq.getParameter("profissao");
		String cepDigitado 			= pReq.getParameter("cep");
		String numEnderecoDigitado	= pReq.getParameter("numEndereco");
		String complementoDigitado	= pReq.getParameter("complemento");
		String foneResDigitado		= pReq.getParameter("foneResidencial");
		String foneComDigitado 		= pReq.getParameter("foneComercial");
		String foneCelDigitado 		= pReq.getParameter("foneCelular");
		String emailDigitado 		= pReq.getParameter("email");
		String convenioDigitado 	= pReq.getParameter("convenio");
		String outroConvDigitado 	= pReq.getParameter("outroConvenio");
		String indicacaoDigitado 	= pReq.getParameter("indicacao");
		String indicacao1Digitado 	= pReq.getParameter("indicacaoMedico");
		String indicacao2Digitado 	= pReq.getParameter("indicacaoAmigo");
		String indicacao3Digitado 	= pReq.getParameter("indicacaoOutro");
		String acessoEmailDigitado 	= pReq.getParameter("acessoEmail");
		
		boolean eCadastro			= pReq.getParameter("eCadastro").equals("sim");
		
		Endereco endereco;
		
		if(cepDigitado == null || cepDigitado.equals("")){
			
			tErro.add("Digite o nmero do CEP!");
		
		} else {
			
			ControlePrincipal controle 	= new ControlePrincipal();
			
			GerenteConsultaEndereco.enderecoPorCep(controle, cepDigitado.replace("-", ""));
			
			try{
			
				endereco = controle.getEnderecos().get(0);
				
				pReq.setAttribute("Logradouro"	, endereco.getTipoLogradouro().trim() + " " + endereco.getNomeLogradouro());
				pReq.setAttribute("Bairro"		, endereco.getNomeBairro());
				pReq.setAttribute("Cidade"		, endereco.getNomeCidade());
				pReq.setAttribute("UF"			, endereco.getNomeUF());
				
				
			}catch (ArrayIndexOutOfBoundsException e) {
				
				pReq.setAttribute("Msg", "<font color='red'>No existe nenhum endereo para o CEP informado</font>");
			}
			
			//-------------------------------- Dados j digitados ----------------------------//

			pReq.setAttribute("CodPaciente"		, codPacienteDigitado);
			pReq.setAttribute("Nome"			, nomeDigitado);
			pReq.setAttribute("DtNasc"			, dtNascDigitado);
			pReq.setAttribute("Idade"			, idadeDigitado);
			pReq.setAttribute("Sexo"			, sexoDigitado);
			pReq.setAttribute("Ativo"			, ativoDigitado);
			pReq.setAttribute("CEP"				, cepDigitado);
			pReq.setAttribute("NumEndereco"		, numEnderecoDigitado);
			pReq.setAttribute("Complemento"		, complementoDigitado);
			pReq.setAttribute("FoneRes"			, foneResDigitado);
			pReq.setAttribute("FoneCom"			, foneComDigitado);
			pReq.setAttribute("FoneCel"			, foneCelDigitado);
			pReq.setAttribute("Email"			, emailDigitado);
			pReq.setAttribute("Convenio"		, convenioDigitado);
			pReq.setAttribute("OutroConv"		, outroConvDigitado);
			pReq.setAttribute("Indicacao"		, indicacaoDigitado);
			pReq.setAttribute("indicacaoMedico"	, indicacao1Digitado);
			pReq.setAttribute("indicacaoAmigo"	, indicacao2Digitado);
			pReq.setAttribute("indicacaoOutro"	, indicacao3Digitado);
			pReq.setAttribute("EstadoCivil"		, estadoCivilDigitado);
			pReq.setAttribute("AcessoEmail"		, acessoEmailDigitado);
			
			if(GerenteConsultaProfissao.todasProfissoes(controle)){
				pReq.setAttribute("Profissoes"	, controle.getProfissoes());
				pReq.setAttribute("Profissao"	, profissaoDigitado);
			} else {
				pReq.setAttribute("Msg", "Problemas ao carregar profisses");
			}
			
			if(GerenteConsultaConvenio.todosConvenios(controle)){
				pReq.setAttribute("Convenios"	, controle.getConvenios());
				pReq.setAttribute("Convenio"	, convenioDigitado);
			} else {
				pReq.setAttribute("Msg", "Problemas ao carregar convnios");
			}

			//--------------------------------------------------------------------------------//
		}
		
		if(tErro.size() > 0){
			
			mostrarErro(pReq, pResp, tErro, eCadastro? "/cadastroPaciente.jsp" : "/visualizacaoPaciente.jsp");
			
		} else {

			ativarPagina(pReq, pResp, eCadastro? "/cadastroPaciente.jsp" : "/visualizacaoPaciente.jsp");
		}
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoAtivarPaginaCadastro(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {
		
		session.setAttribute(Constantes.ATRIB_DT_INI_CAD_PACIENTE, Constantes.HORA_ATUAL());
		
		ControlePrincipal controle	= new ControlePrincipal();

		if(GerenteConsultaProfissao.todasProfissoes(controle)){
			pReq.setAttribute("Profissoes"	, controle.getProfissoes());
		}
		
		if(GerenteConsultaConvenio.todosConvenios(controle)){
			pReq.setAttribute("Convenios"	, controle.getConvenios());
		}
		
		ativarPagina(pReq, pResp, "/cadastroPaciente.jsp");
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @throws ServletException
	 * @throws IOException
	 */
		
	private void acaoNovaProfissao(HttpServletRequest pReq, HttpServletResponse pResp) throws ServletException, IOException {

		ControlePrincipal controle	= new ControlePrincipal();

		String novaProfDigitado 	= pReq.getParameter("novaProfissao");
		
		boolean eCadastro;
		
		eCadastro = pReq.getParameter("eCadastro").equals("sim");
		
		if(novaProfDigitado != null && ! novaProfDigitado.equals("")) {

			String codPacienteDigitado 	= pReq.getParameter("codPaciente");
			String nomeDigitado 		= pReq.getParameter("nome");
			String dtNascDigitado 		= pReq.getParameter("dtNasc");
			String idadeDigitado		= pReq.getParameter("idade");
			String sexoDigitado 		= pReq.getParameter("sexo");
			String ativoDigitado 		= pReq.getParameter("ativo");
			String estadoCivilDigitado 	= pReq.getParameter("estadoCivil");
			String cepDigitado 			= pReq.getParameter("cep");
			String numEnderecoDigitado	= pReq.getParameter("numEndereco");
			String complementoDigitado	= pReq.getParameter("complemento");
			String foneResDigitado		= pReq.getParameter("foneResidencial");
			String foneComDigitado 		= pReq.getParameter("foneComercial");
			String foneCelDigitado 		= pReq.getParameter("foneCelular");
			String emailDigitado 		= pReq.getParameter("email");
			String convenioDigitado 	= pReq.getParameter("convenio");
			String outroConvDigitado 	= pReq.getParameter("outroConvenio");
			String indicacaoDigitado 	= pReq.getParameter("indicacao");
			String indicacao1Digitado 	= pReq.getParameter("indicacaoMedico");
			String indicacao2Digitado 	= pReq.getParameter("indicacaoAmigo");
			String indicacao3Digitado 	= pReq.getParameter("indicacaoOutro");
			String logradouroDigitado 	= pReq.getParameter("rua");
			String bairroDigitado 		= pReq.getParameter("bairro");
			String cidadeDigitado 		= pReq.getParameter("cidade");
			String ufDigitado 			= pReq.getParameter("uf");
			String acessoEmailDigitado	= pReq.getParameter("acessoEmail");

			pReq.setAttribute("CodPaciente"		, codPacienteDigitado);
			pReq.setAttribute("Logradouro"		, logradouroDigitado);
			pReq.setAttribute("Bairro"			, bairroDigitado);
			pReq.setAttribute("Cidade"			, cidadeDigitado);
			pReq.setAttribute("UF"				, ufDigitado);
			pReq.setAttribute("Nome"			, nomeDigitado);
			pReq.setAttribute("DtNasc"			, dtNascDigitado);
			pReq.setAttribute("Idade"			, idadeDigitado);
			pReq.setAttribute("Sexo"			, sexoDigitado);
			pReq.setAttribute("Ativo"			, ativoDigitado);
			pReq.setAttribute("CEP"				, cepDigitado);
			pReq.setAttribute("NumEndereco"		, numEnderecoDigitado);
			pReq.setAttribute("Complemento"		, complementoDigitado);
			pReq.setAttribute("FoneRes"			, foneResDigitado);
			pReq.setAttribute("FoneCom"			, foneComDigitado);
			pReq.setAttribute("FoneCel"			, foneCelDigitado);
			pReq.setAttribute("Email"			, emailDigitado);
			pReq.setAttribute("Convenio"		, convenioDigitado);
			pReq.setAttribute("OutroConv"		, outroConvDigitado);
			pReq.setAttribute("Indicacao"		, indicacaoDigitado);
			pReq.setAttribute("IndicacaoMedico"	, indicacao1Digitado);
			pReq.setAttribute("IndicacaoAmigo"	, indicacao2Digitado);
			pReq.setAttribute("IndicacaoOutro"	, indicacao3Digitado);
			pReq.setAttribute("EstadoCivil"		, estadoCivilDigitado);
			pReq.setAttribute("AcessoEmail"		, acessoEmailDigitado);

			if(new ProfissaoDAO().incluiProfissao(new Profissao(0, novaProfDigitado))){
				if(GerenteConsultaProfissao.todasProfissoes(controle)){
					pReq.setAttribute("Profissoes"	, controle.getProfissoes());
					pReq.setAttribute("Profissao"	, "0");
				} else {
					pReq.setAttribute("Msg", "Problemas ao carregar profissoes");
				}
				if(GerenteConsultaConvenio.todosConvenios(controle)){
					pReq.setAttribute("Convenios"	, controle.getConvenios());
					pReq.setAttribute("Convenio"	, "0");
				} else {
					pReq.setAttribute("Msg", "Problemas ao carregar convenios");
				}
			} else {
				pReq.setAttribute("Msg", "Problemas ao incluir a nova profisso");
			}

			ativarPagina(pReq, pResp, eCadastro ? "/cadastroPaciente.jsp" : "/visualizacaoPaciente.jsp");
		}
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @param session
	 * @throws ServletException
	 * @throws IOException
	 */
	
	private void acaoExclusaoConfirmada(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {
				
		String codPaciente = pReq.getParameter("codPaciente");
		
		if(new PacienteDAO().excluiPaciente(Integer.parseInt(codPaciente))){
			
			String loginUsuario = (String) session.getAttribute(Constantes.ATRIB_USUARIO_LOGADO);
			String ipUsuario 	= (String) session.getAttribute(Constantes.ATRIB_IP_LOGADO);
			String dtIni 		= (String) session.getAttribute(Constantes.ATRIB_DT_INI_EXC_PACIENTE);
			
			AuditLog audit 		= new AuditLog(0, loginUsuario, ipUsuario, dtIni, Constantes.HORA_ATUAL(), Constantes.COD_EXCLUSAO_PACIENTE);
			
			new AuditLogDAO().incluiRegistro(audit);

			pReq.setAttribute("Msg", "Paciente excludo com sucesso");
			
		} else {
			
			pReq.setAttribute("Msg", "Problemas na excluso do paciente");
		}
		
		ativarPagina(pReq, pResp, "/consultaPaciente.jsp");
	}
	
	/**
	 * 
	 * @param req
	 * @param resp
	 * @throws ServletException
	 * @throws IOException
	 */

	private void acaoCadastrarPaciente(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {
		
		Vector<String> tErro 		= new Vector<String>();
		
		ControlePrincipal controle	= new ControlePrincipal();
		
		PacienteDAO pacienteDAO 	= new PacienteDAO();
		
		String idadeDigitado 		= pReq.getParameter("idade");
		String numEnderecoDigitado 	= pReq.getParameter("numEndereco");
		String foneResDigitado 		= pReq.getParameter("foneResidencial");
		String foneComDigitado 		= pReq.getParameter("foneComercial");
		String foneCelDigitado 		= pReq.getParameter("foneCelular");
		String nomeDigitado 		= pReq.getParameter("nome");
		String dtNascDigitado 		= pReq.getParameter("dtNasc");
		String sexoDigitado 		= pReq.getParameter("sexo");
		String ativoDigitado 		= pReq.getParameter("ativo");
		String estadoCivilDigitado 	= pReq.getParameter("estadoCivil");
		String profissaoDigitado 	= pReq.getParameter("profissao");
		String cepDigitado 			= pReq.getParameter("cep");
		String logradouroDigitado 	= pReq.getParameter("rua");
		String complementoDigitado	= pReq.getParameter("complemento");
		String bairroDigitado 		= pReq.getParameter("bairro");
		String cidadeDigitado 		= pReq.getParameter("cidade");
		String ufDigitado 			= pReq.getParameter("uf");
		String emailDigitado 		= pReq.getParameter("email");
		String convenioDigitado 	= pReq.getParameter("convenio");
		String acessoEmailDigitado	= pReq.getParameter("acessoEmail");
		
		int indicacaoDigitado 		= 0;
		
		try{
			indicacaoDigitado = Integer.parseInt(pReq.getParameter("indicacao"));
		}catch (NumberFormatException e) {
			indicacaoDigitado = 0;
		}
		
		String descrIndicDigitado	= "";
		
		switch(indicacaoDigitado){
			case 1: descrIndicDigitado	= pReq.getParameter("indicacaoMedico");	break;
			case 4: descrIndicDigitado	= pReq.getParameter("indicacaoAmigo"); 	break;
			case 5: descrIndicDigitado	= pReq.getParameter("indicacaoOutro");	break;
		}
		
		if(ativoDigitado == null || ativoDigitado.equals(""))
			ativoDigitado = "n";

		if(nomeDigitado == null || nomeDigitado.equals(""))
			tErro.add("O campo Nome deve ser preenchido!");

		try{
			Integer.parseInt(profissaoDigitado);
		}catch (NumberFormatException e) {
			profissaoDigitado = "0";
		}
		
		try{
			Integer.parseInt(convenioDigitado);
		}catch (NumberFormatException e) {
			convenioDigitado = "0";
		}
		
		if(tErro.size() > 0){			
			mostrarErro(pReq, pResp, tErro, "/cadastroPaciente.jsp");
			
		} else {
			
			Paciente paciente = new Paciente(0, Integer.parseInt(profissaoDigitado), Integer.parseInt(convenioDigitado), indicacaoDigitado, nomeDigitado, dtNascDigitado, idadeDigitado, 
					sexoDigitado, ativoDigitado, estadoCivilDigitado, cepDigitado, logradouroDigitado, numEnderecoDigitado, 
					complementoDigitado, bairroDigitado, cidadeDigitado, ufDigitado, foneResDigitado, 
					foneComDigitado, foneCelDigitado, emailDigitado, descrIndicDigitado, acessoEmailDigitado);
			
			if(pacienteDAO.incluiPaciente(paciente)) {
				
				String loginUsuario = (String) session.getAttribute(Constantes.ATRIB_USUARIO_LOGADO);
				String ipUsuario 	= (String) session.getAttribute(Constantes.ATRIB_IP_LOGADO);
				String dtIni 		= (String) session.getAttribute(Constantes.ATRIB_DT_INI_CAD_PACIENTE);
				
				AuditLog audit 		= new AuditLog(0, loginUsuario, ipUsuario, dtIni, Constantes.HORA_ATUAL(), Constantes.COD_CADASTRO_PACIENTE);
				
				new AuditLogDAO().incluiRegistro(audit);
				
				pReq.setAttribute("Msg", "Paciente cadastrado com sucesso!");
				
				ProfissaoDAO profissaoDAO	= new ProfissaoDAO(controle);
				
				if(profissaoDAO.carregaProfissoes("")){
					pReq.setAttribute("Profissoes"	, controle.getProfissoes());
				}
				if(GerenteConsultaConvenio.todosConvenios(controle)){
					pReq.setAttribute("Convenios"	, controle.getConvenios());
					pReq.setAttribute("Convenio"	, "0");
				}
				
				session.setAttribute(Constantes.ATRIB_DT_INI_CAD_PACIENTE, Constantes.HORA_ATUAL());
				
			} else {
				
				pReq.setAttribute("Msg", "Problemas ao cadastrar o paciente!");
			}
			
			ativarPagina(pReq, pResp, "/cadastroPaciente.jsp");
		}
	}

	/**
	 * 
	 * @param req
	 * @param resp
	 * @throws ServletException
	 * @throws IOException
	 */

	private void acaoAlterarPaciente(HttpServletRequest pReq, HttpServletResponse pResp, HttpSession session) throws ServletException, IOException {
		
		Vector<String> tErro = new Vector<String>();

		String codPaciente	 		= pReq.getParameter("codPaciente");
		String idadeDigitado 		= pReq.getParameter("idade");
		String numEnderecoDigitado 	= pReq.getParameter("numEndereco");
		String foneResDigitado 		= pReq.getParameter("foneResidencial");
		String foneComDigitado 		= pReq.getParameter("foneComercial");
		String foneCelDigitado 		= pReq.getParameter("foneCelular");
		String nomeDigitado 		= pReq.getParameter("nome");
		String dtNascDigitado 		= pReq.getParameter("dtNasc");
		String sexoDigitado 		= pReq.getParameter("sexo");
		String ativoDigitado 		= pReq.getParameter("ativo");
		String estadoCivilDigitado 	= pReq.getParameter("estadoCivil");
		String profissaoDigitado 	= pReq.getParameter("profissao");
		String cepDigitado 			= pReq.getParameter("cep");
		String logradouroDigitado 	= pReq.getParameter("rua");
		String complementoDigitado	= pReq.getParameter("complemento");
		String bairroDigitado 		= pReq.getParameter("bairro");
		String cidadeDigitado 		= pReq.getParameter("cidade");
		String ufDigitado 			= pReq.getParameter("uf");
		String emailDigitado 		= pReq.getParameter("email");
		String convenioDigitado 	= pReq.getParameter("convenio");
		String acessoEmailDigitado	= pReq.getParameter("acessoEmail");
		
		String descrIndicDigitado	= "";
		
		int indicacaoDigitado 		= 0;
		
		try{
			indicacaoDigitado		 = Integer.parseInt(pReq.getParameter("indicacao"));
		}catch (NumberFormatException e) {
			indicacaoDigitado 		= 0;
		}
		
		switch(indicacaoDigitado){
			case 1: descrIndicDigitado	= pReq.getParameter("indicacaoMedico");	break;
			case 4: descrIndicDigitado	= pReq.getParameter("indicacaoAmigo"); 	break;
			case 5: descrIndicDigitado	= pReq.getParameter("indicacaoOutro");	break;
		}
		
		PacienteDAO pacienteDAO = new PacienteDAO();

		if(nomeDigitado == null || nomeDigitado.equals(""))
			tErro.add("O campo Nome deve ser preenchido!");

		if(ativoDigitado == null || ativoDigitado.equals(""))
			ativoDigitado = "n";

		try{			
			Integer.parseInt(codPaciente);			
		} catch (NumberFormatException e) {
			codPaciente = "0";
		}
		
		try{			
			Integer.parseInt(profissaoDigitado);			
		} catch (NumberFormatException e) {
			profissaoDigitado = "0";
		}
		
		try{			
			Integer.parseInt(convenioDigitado);			
		} catch (NumberFormatException e) {
			convenioDigitado = "0";
		}
		
		if(tErro.size() > 0){			
			mostrarErro(pReq, pResp, tErro, "/visualizacaoPaciente.jsp");
			
		} else {
			
			Paciente paciente = new Paciente(Integer.parseInt(codPaciente), Integer.parseInt(profissaoDigitado), Integer.parseInt(convenioDigitado), indicacaoDigitado, nomeDigitado,  
					dtNascDigitado, idadeDigitado,sexoDigitado, ativoDigitado, estadoCivilDigitado, cepDigitado, logradouroDigitado, numEnderecoDigitado, 
					complementoDigitado, bairroDigitado, cidadeDigitado, ufDigitado, foneResDigitado,					
					foneComDigitado, foneCelDigitado, emailDigitado, descrIndicDigitado, acessoEmailDigitado);
			
			if(pacienteDAO.alteraPaciente(paciente)) {
				
				pReq.setAttribute("Msg", "Paciente alterado com sucesso!");
				
				String loginUsuario = (String) session.getAttribute(Constantes.ATRIB_USUARIO_LOGADO);
				String ipUsuario 	= (String) session.getAttribute(Constantes.ATRIB_IP_LOGADO);
				String dtIni 		= (String) session.getAttribute(Constantes.ATRIB_DT_INI_ALT_PACIENTE);
				
				AuditLog audit 		= new AuditLog(0, loginUsuario, ipUsuario, dtIni, Constantes.HORA_ATUAL(), Constantes.COD_ALTERACAO_PACIENTE);
				
				new AuditLogDAO().incluiRegistro(audit);
								
			} else {
				
				pReq.setAttribute("Msg", "Problemas ao alterar o paciente!");
			}
			
			ativarPagina(pReq, pResp, "/consultaPaciente.jsp");
		}
	}
	
	/**
	 * 
	 * @param pReq
	 * @param pResp
	 * @throws ServletException
	 * @throws IOException
	 */

	private void acaoExibirPaciente(HttpServletRequest pReq, HttpServletResponse pResp) throws ServletException, IOException {
				
		ControlePrincipal controle = new ControlePrincipal();
		
		Paciente paciente;
		
		int codPaciente = Integer.parseInt(pReq.getParameter("codPaciente"));
		
		if(GerenteConsultaPaciente.pacientePorCodigo(controle, codPaciente)){
			
			paciente = controle.getPacientes().get(0);

			pReq.setAttribute("CodPaciente"	, String.valueOf(paciente.getIdPaciente()));
			pReq.setAttribute("Nome"		, paciente.getNome().trim());
			pReq.setAttribute("DtNasc"		, paciente.getDtNasc());
			pReq.setAttribute("Idade"		, paciente.getIdade().trim());
			pReq.setAttribute("Sexo"		, paciente.getSexo());
			pReq.setAttribute("Ativo"		, paciente.getAtivo());
			pReq.setAttribute("Profissao"	, String.valueOf(paciente.getIdProfissao()));
			pReq.setAttribute("CEP"			, paciente.getCep().trim());
			pReq.setAttribute("NumEndereco"	, paciente.getNumEndereco().trim());
			pReq.setAttribute("Complemento"	, paciente.getComplemento().trim());
			pReq.setAttribute("FoneRes"		, paciente.getFoneRes().trim());
			pReq.setAttribute("FoneCom"		, paciente.getFoneCom().trim());
			pReq.setAttribute("FoneCel"		, paciente.getFoneCel().trim());
			pReq.setAttribute("Email"		, paciente.getEmail().trim());
			pReq.setAttribute("Convenio"	, String.valueOf(paciente.getIdConvenio()));
			pReq.setAttribute("Indicacao"	, String.valueOf(paciente.getIndicacao()));
			pReq.setAttribute("DescrIndic"	, paciente.getDescrIndicacao());
			pReq.setAttribute("Logradouro"	, paciente.getLogradouro().trim());
			pReq.setAttribute("Bairro"		, paciente.getBairro().trim());
			pReq.setAttribute("Cidade"		, paciente.getCidade().trim());
			pReq.setAttribute("UF"			, paciente.getUf().trim());
			pReq.setAttribute("EstadoCivil"	, paciente.getEstadoCivil());
			pReq.setAttribute("AcessoEmail"	, paciente.getAcessoEmail());

			switch(paciente.getIndicacao()){
				case 1: pReq.setAttribute("indicacaoMedico"	, paciente.getDescrIndicacao());	break;
				case 4: pReq.setAttribute("indicacaoAmigo"	, paciente.getDescrIndicacao()); 	break;
				case 5: pReq.setAttribute("indicacaoOutro"	, paciente.getDescrIndicacao());	break;
			}

			if(GerenteConsultaProfissao.todasProfissoes(controle)){
				pReq.setAttribute("Profissoes", controle.getProfissoes());
			}
			
			if(GerenteConsultaConvenio.todosConvenios(controle)){
				pReq.setAttribute("Convenios", controle.getConvenios());
			}
			
		} else {
			
			pReq.setAttribute("Msg", "Problemas ao exibir paciente");
		}
		
		ativarPagina(pReq, pResp, "/visualizacaoPaciente.jsp");
	}
}